/*!
 * ZUI: Standard edition - v1.5.0 - 2016-10-08
 * http://zui.sexy
 * GitHub: https://github.com/easysoft/zui.git 
 * Copyright (c) 2016 cnezsoft.com; Licensed MIT
 */

/*! Some code copy from Bootstrap v3.0.0 by @fat and @mdo. (Copyright 2013 Twitter, Inc. Licensed under http://www.apache.org/licenses/)*/

/*! normalize.css v2.1.3 | MIT License | git.io/normalize */
article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
main,
nav,
section,
summary {
  display: block;
  }
audio,
canvas,
video {
  display: inline-block;
  }
audio:not([controls]) {
  display: none;
  height: 0;
  }
[hidden],
template {
  display: none;
  }
html {
  font-family: sans-serif;

      -ms-text-size-adjust: 100%;
  -webkit-text-size-adjust: 100%;
  }
body {
  margin: 0;
  }
a {
  background: transparent;
  }
a:focus {
  outline: thin dotted;
  }
a:active,
a:hover {
  outline: 0;
  }
h1 {
  margin: .67em 0;
  font-size: 2em;
  }
abbr[title] {
  border-bottom: 1px dotted;
  }
b,
strong {
  font-weight: bold;
  }
dfn {
  font-style: italic;
  }
hr {
  height: 0;
  -webkit-box-sizing: content-box;
     -moz-box-sizing: content-box;
          box-sizing: content-box;
  }
mark {
  color: #000;
  background: #ff0;
  }
code,
kbd,
pre,
samp {
  font-family: monospace, serif;
  font-size: 1em;
  }
pre {
  white-space: pre-wrap;
  }
q {
  quotes: "\201C" "\201D" "\2018" "\2019";
  }
small {
  font-size: 80%;
  }
sub,
sup {
  position: relative;
  font-size: 75%;
  line-height: 0;
  vertical-align: baseline;
  }
sup {
  top: -.5em;
  }
sub {
  bottom: -.25em;
  }
img {
  border: 0;
  }
svg:not(:root) {
  overflow: hidden;
  }
figure {
  margin: 0;
  }
fieldset {
  padding: .35em .625em .75em;
  margin: 0 2px;
  border: 1px solid #c0c0c0;
  }
legend {
  padding: 0;
  border: 0;
  }
button,
input,
select,
textarea {
  margin: 0;
  font-family: inherit;
  font-size: 100%;
  }
button,
input {
  line-height: normal;
  }
button,
select {
  text-transform: none;
  }
button,
html input[type="button"],
input[type="reset"],
input[type="submit"] {
  -webkit-appearance: button;
  cursor: pointer;
  }
button[disabled],
html input[disabled] {
  cursor: default;
  }
input[type="checkbox"],
input[type="radio"] {
  -webkit-box-sizing: border-box;
     -moz-box-sizing: border-box;
          box-sizing: border-box;
  padding: 0;
  }
input[type="search"] {
  -webkit-box-sizing: content-box;
     -moz-box-sizing: content-box;
          box-sizing: content-box;
  -webkit-appearance: textfield;
  }
input[type="search"]::-webkit-search-cancel-button,
input[type="search"]::-webkit-search-decoration {
  -webkit-appearance: none;
  }
button::-moz-focus-inner,
input::-moz-focus-inner {
  padding: 0;
  border: 0;
  }
textarea {
  overflow: auto;
  vertical-align: top;
  }
table {
  border-spacing: 0;
  border-collapse: collapse;
  }
.clearfix:before,
.clearfix:after,
.container:before,
.container:after,
.container-fluid:before,
.container-fluid:after,
.container-fixed:before,
.container-fixed:after,
.container-fixed-md:before,
.container-fixed-md:after,
.container-fixed-sm:before,
.container-fixed-sm:after,
.container-fixed-xs:before,
.container-fixed-xs:after,
.row:before,
.row:after,
.dl-horizontal dd:before,
.dl-horizontal dd:after,
.btn-toolbar:before,
.btn-toolbar:after,
.btn-group-vertical > .btn-group:before,
.btn-group-vertical > .btn-group:after,
.form-horizontal .form-group:before,
.form-horizontal .form-group:after,
.panel-body:before,
.panel-body:after,
.pager-justify:before,
.pager-justify:after,
.pager-loose:before,
.pager-loose:after,
.nav:before,
.nav:after,
.navbar:before,
.navbar:after,
.navbar-header:before,
.navbar-header:after,
.navbar-collapse:before,
.navbar-collapse:after,
.modal-header:before,
.modal-header:after,
.modal-footer:before,
.modal-footer:after,
.cards:before,
.cards:after,
.btn-group-vertical > .btn-group-vertical:before,
.btn-group-vertical > .btn-group-vertical:after {
  /* 1 */
  display: table;
  content: " ";
  /* 2 */
  }
.clearfix:after,
.container:after,
.container-fluid:after,
.container-fixed:after,
.container-fixed-md:after,
.container-fixed-sm:after,
.container-fixed-xs:after,
.row:after,
.dl-horizontal dd:after,
.btn-toolbar:after,
.btn-group-vertical > .btn-group:after,
.form-horizontal .form-group:after,
.panel-body:after,
.pager-justify:after,
.pager-loose:after,
.nav:after,
.navbar:after,
.navbar-header:after,
.navbar-collapse:after,
.modal-header:after,
.modal-footer:after,
.cards:after,
.btn-group-vertical > .btn-group-vertical:after {
  clear: both;
  }
.center-block {
  display: block;
  margin-right: auto;
  margin-left: auto;
  }
.pull-right {
  float: right !important;
  }
.pull-left {
  float: left !important;
  }
.hide {
  display: none;
  }
.show {
  display: block;
  }
.hidden {
  display: none!important;
  visibility: hidden !important;
  }
.showing {
  display: block!important;
  visibility: visible !important;
  }
.invisible {
  visibility: hidden;
  }
.text-hide {
  font: 0/0 a;
  color: transparent;
  text-shadow: none;
  background-color: transparent;
  border: 0;
  }
.affix {
  position: fixed;
  }
.with-padding {
  padding: 5px 12px;
  }
.visible-xs,
.inline.visible-xs,
.inline-block.visible-xs,
tr.visible-xs,
th.visible-xs,
td.visible-xs {
  display: none !important;
  }
@media (max-width: 767px) {
  .visible-xs {
    display: block !important;
    }
  .inline.visible-xs {
    display: inline !important;
    }
  .inline-block.visible-xs {
    display: inline-block !important;
    }
  tr.visible-xs {
    display: table-row !important;
    }
  th.visible-xs,
  td.visible-xs {
    display: table-cell !important;
    }
  }
@media (min-width: 768px) and (max-width: 991px) {
  .visible-xs.visible-sm {
    display: block !important;
    }
  .inline.visible-xs.visible-sm {
    display: inline !important;
    }
  .inline-block.visible-xs.visible-sm {
    display: inline-block !important;
    }
  tr.visible-xs.visible-sm {
    display: table-row !important;
    }
  th.visible-xs.visible-sm,
  td.visible-xs.visible-sm {
    display: table-cell !important;
    }
  }
@media (min-width: 992px) and (max-width: 1199px) {
  .visible-xs.visible-md {
    display: block !important;
    }
  .inline.visible-xs.visible-md {
    display: inline !important;
    }
  .inline-block.visible-xs.visible-md {
    display: inline-block !important;
    }
  tr.visible-xs.visible-md {
    display: table-row !important;
    }
  th.visible-xs.visible-md,
  td.visible-xs.visible-md {
    display: table-cell !important;
    }
  }
@media (min-width: 1200px) {
  .visible-xs.visible-lg {
    display: block !important;
    }
  .inline.visible-xs.visible-lg {
    display: inline !important;
    }
  .inline-block.visible-xs.visible-lg {
    display: inline-block !important;
    }
  tr.visible-xs.visible-lg {
    display: table-row !important;
    }
  th.visible-xs.visible-lg,
  td.visible-xs.visible-lg {
    display: table-cell !important;
    }
  }
.visible-sm,
.inline.visible-sm,
.inline-block.visible-sm,
tr.visible-sm,
th.visible-sm,
td.visible-sm {
  display: none !important;
  }
@media (max-width: 767px) {
  .visible-sm.visible-xs {
    display: block !important;
    }
  .inline.visible-sm.visible-xs {
    display: inline !important;
    }
  .inline-block.visible-sm.visible-xs {
    display: inline-block !important;
    }
  tr.visible-sm.visible-xs {
    display: table-row !important;
    }
  th.visible-sm.visible-xs,
  td.visible-sm.visible-xs {
    display: table-cell !important;
    }
  }
@media (min-width: 768px) and (max-width: 991px) {
  .visible-sm {
    display: block !important;
    }
  .inline.visible-sm {
    display: inline !important;
    }
  .inline-block.visible-sm {
    display: inline-block !important;
    }
  tr.visible-sm {
    display: table-row !important;
    }
  th.visible-sm,
  td.visible-sm {
    display: table-cell !important;
    }
  }
@media (min-width: 992px) and (max-width: 1199px) {
  .visible-sm.visible-md {
    display: block !important;
    }
  .inline.visible-sm.visible-md {
    display: inline !important;
    }
  .inline-block.visible-sm.visible-md {
    display: inline-block !important;
    }
  tr.visible-sm.visible-md {
    display: table-row !important;
    }
  th.visible-sm.visible-md,
  td.visible-sm.visible-md {
    display: table-cell !important;
    }
  }
@media (min-width: 1200px) {
  .visible-sm.visible-lg {
    display: block !important;
    }
  .inline.visible-sm.visible-lg {
    display: inline !important;
    }
  .inline-block.visible-sm.visible-lg {
    display: inline-block !important;
    }
  tr.visible-sm.visible-lg {
    display: table-row !important;
    }
  th.visible-sm.visible-lg,
  td.visible-sm.visible-lg {
    display: table-cell !important;
    }
  }
.visible-md,
.inline.visible-md,
.inline-block.visible-md,
tr.visible-md,
th.visible-md,
td.visible-md {
  display: none !important;
  }
@media (max-width: 767px) {
  .visible-md.visible-xs {
    display: block !important;
    }
  .inline.visible-md.visible-xs {
    display: inline !important;
    }
  .inline-block.visible-md.visible-xs {
    display: inline-block !important;
    }
  tr.visible-md.visible-xs {
    display: table-row !important;
    }
  th.visible-md.visible-xs,
  td.visible-md.visible-xs {
    display: table-cell !important;
    }
  }
@media (min-width: 768px) and (max-width: 991px) {
  .visible-md.visible-sm {
    display: block !important;
    }
  .inline.visible-md.visible-sm {
    display: inline !important;
    }
  .inline-block.visible-md.visible-sm {
    display: inline-block !important;
    }
  tr.visible-md.visible-sm {
    display: table-row !important;
    }
  th.visible-md.visible-sm,
  td.visible-md.visible-sm {
    display: table-cell !important;
    }
  }
@media (min-width: 992px) and (max-width: 1199px) {
  .visible-md {
    display: block !important;
    }
  .inline.visible-md {
    display: inline !important;
    }
  .inline-block.visible-md {
    display: inline-block !important;
    }
  tr.visible-md {
    display: table-row !important;
    }
  th.visible-md,
  td.visible-md {
    display: table-cell !important;
    }
  }
@media (min-width: 1200px) {
  .visible-md.visible-lg {
    display: block !important;
    }
  .inline.visible-md.visible-lg {
    display: inline !important;
    }
  .inline-block.visible-md.visible-lg {
    display: inline-block !important;
    }
  tr.visible-md.visible-lg {
    display: table-row !important;
    }
  th.visible-md.visible-lg,
  td.visible-md.visible-lg {
    display: table-cell !important;
    }
  }
.visible-lg,
.inline.visible-lg,
.inline-block.visible-lg,
tr.visible-lg,
th.visible-lg,
td.visible-lg {
  display: none !important;
  }
@media (max-width: 767px) {
  .visible-lg.visible-xs {
    display: block !important;
    }
  .inline.visible-lg.visible-xs {
    display: inline !important;
    }
  .inline-block.visible-lg.visible-xs {
    display: inline-block !important;
    }
  tr.visible-lg.visible-xs {
    display: table-row !important;
    }
  th.visible-lg.visible-xs,
  td.visible-lg.visible-xs {
    display: table-cell !important;
    }
  }
@media (min-width: 768px) and (max-width: 991px) {
  .visible-lg.visible-sm {
    display: block !important;
    }
  .inline.visible-lg.visible-sm {
    display: inline !important;
    }
  .inline-block.visible-lg.visible-sm {
    display: inline-block !important;
    }
  tr.visible-lg.visible-sm {
    display: table-row !important;
    }
  th.visible-lg.visible-sm,
  td.visible-lg.visible-sm {
    display: table-cell !important;
    }
  }
@media (min-width: 992px) and (max-width: 1199px) {
  .visible-lg.visible-md {
    display: block !important;
    }
  .inline.visible-lg.visible-md {
    display: inline !important;
    }
  .inline-block.visible-lg.visible-md {
    display: inline-block !important;
    }
  tr.visible-lg.visible-md {
    display: table-row !important;
    }
  th.visible-lg.visible-md,
  td.visible-lg.visible-md {
    display: table-cell !important;
    }
  }
@media (min-width: 1200px) {
  .visible-lg {
    display: block !important;
    }
  .inline.visible-lg {
    display: inline !important;
    }
  .inline-block.visible-lg {
    display: inline-block !important;
    }
  tr.visible-lg {
    display: table-row !important;
    }
  th.visible-lg,
  td.visible-lg {
    display: table-cell !important;
    }
  }
.hidden-xs {
  display: block !important;
  }
.inline.hidden-xs {
  display: inline !important;
  }
.inline-block.hidden-xs {
  display: inline-block !important;
  }
tr.hidden-xs {
  display: table-row !important;
  }
th.hidden-xs,
td.hidden-xs {
  display: table-cell !important;
  }
@media (max-width: 767px) {
  .hidden-xs,
  .inline.hidden-xs,
  .inline-block.hidden-xs,
  tr.hidden-xs,
  th.hidden-xs,
  td.hidden-xs {
    display: none !important;
    }
  }
@media (min-width: 768px) and (max-width: 991px) {
  .hidden-xs.hidden-sm,
  .inline.hidden-xs.hidden-sm,
  .inline-block.hidden-xs.hidden-sm,
  tr.hidden-xs.hidden-sm,
  th.hidden-xs.hidden-sm,
  td.hidden-xs.hidden-sm {
    display: none !important;
    }
  }
@media (min-width: 992px) and (max-width: 1199px) {
  .hidden-xs.hidden-md,
  .inline.hidden-xs.hidden-md,
  .inline-block.hidden-xs.hidden-md,
  tr.hidden-xs.hidden-md,
  th.hidden-xs.hidden-md,
  td.hidden-xs.hidden-md {
    display: none !important;
    }
  }
@media (min-width: 1200px) {
  .hidden-xs.hidden-lg,
  .inline.hidden-xs.hidden-lg,
  .inline-block.hidden-xs.hidden-lg,
  tr.hidden-xs.hidden-lg,
  th.hidden-xs.hidden-lg,
  td.hidden-xs.hidden-lg {
    display: none !important;
    }
  }
.hidden-sm {
  display: block !important;
  }
.inline.hidden-sm {
  display: inline !important;
  }
.inline-block.hidden-sm {
  display: inline-block !important;
  }
tr.hidden-sm {
  display: table-row !important;
  }
th.hidden-sm,
td.hidden-sm {
  display: table-cell !important;
  }
@media (max-width: 767px) {
  .hidden-sm.hidden-xs,
  .inline.hidden-sm.hidden-xs,
  .inline-block.hidden-sm.hidden-xs,
  tr.hidden-sm.hidden-xs,
  th.hidden-sm.hidden-xs,
  td.hidden-sm.hidden-xs {
    display: none !important;
    }
  }
@media (min-width: 768px) and (max-width: 991px) {
  .hidden-sm,
  .inline.hidden-sm,
  .inline-block.hidden-sm,
  tr.hidden-sm,
  th.hidden-sm,
  td.hidden-sm {
    display: none !important;
    }
  }
@media (min-width: 992px) and (max-width: 1199px) {
  .hidden-sm.hidden-md,
  .inline.hidden-sm.hidden-md,
  .inline-block.hidden-sm.hidden-md,
  tr.hidden-sm.hidden-md,
  th.hidden-sm.hidden-md,
  td.hidden-sm.hidden-md {
    display: none !important;
    }
  }
@media (min-width: 1200px) {
  .hidden-sm.hidden-lg,
  .inline.hidden-sm.hidden-lg,
  .inline-block.hidden-sm.hidden-lg,
  tr.hidden-sm.hidden-lg,
  th.hidden-sm.hidden-lg,
  td.hidden-sm.hidden-lg {
    display: none !important;
    }
  }
.hidden-md {
  display: block !important;
  }
.inline.hidden-md {
  display: inline !important;
  }
.inline-block.hidden-md {
  display: inline-block !important;
  }
tr.hidden-md {
  display: table-row !important;
  }
th.hidden-md,
td.hidden-md {
  display: table-cell !important;
  }
@media (max-width: 767px) {
  .hidden-md.hidden-xs,
  .inline.hidden-md.hidden-xs,
  .inline-block.hidden-md.hidden-xs,
  tr.hidden-md.hidden-xs,
  th.hidden-md.hidden-xs,
  td.hidden-md.hidden-xs {
    display: none !important;
    }
  }
@media (min-width: 768px) and (max-width: 991px) {
  .hidden-md.hidden-sm,
  .inline.hidden-md.hidden-sm,
  .inline-block.hidden-md.hidden-sm,
  tr.hidden-md.hidden-sm,
  th.hidden-md.hidden-sm,
  td.hidden-md.hidden-sm {
    display: none !important;
    }
  }
@media (min-width: 992px) and (max-width: 1199px) {
  .hidden-md,
  .inline.hidden-md,
  .inline-block.hidden-md,
  tr.hidden-md,
  th.hidden-md,
  td.hidden-md {
    display: none !important;
    }
  }
@media (min-width: 1200px) {
  .hidden-md.hidden-lg,
  .inline.hidden-md.hidden-lg,
  .inline-block.hidden-md.hidden-lg,
  tr.hidden-md.hidden-lg,
  th.hidden-md.hidden-lg,
  td.hidden-md.hidden-lg {
    display: none !important;
    }
  }
.hidden-lg {
  display: block !important;
  }
.inline.hidden-lg {
  display: inline !important;
  }
.inline-block.hidden-lg {
  display: inline-block !important;
  }
tr.hidden-lg {
  display: table-row !important;
  }
th.hidden-lg,
td.hidden-lg {
  display: table-cell !important;
  }
@media (max-width: 767px) {
  .hidden-lg.hidden-xs,
  .inline.hidden-lg.hidden-xs,
  .inline-block.hidden-lg.hidden-xs,
  tr.hidden-lg.hidden-xs,
  th.hidden-lg.hidden-xs,
  td.hidden-lg.hidden-xs {
    display: none !important;
    }
  }
@media (min-width: 768px) and (max-width: 991px) {
  .hidden-lg.hidden-sm,
  .inline.hidden-lg.hidden-sm,
  .inline-block.hidden-lg.hidden-sm,
  tr.hidden-lg.hidden-sm,
  th.hidden-lg.hidden-sm,
  td.hidden-lg.hidden-sm {
    display: none !important;
    }
  }
@media (min-width: 992px) and (max-width: 1199px) {
  .hidden-lg.hidden-md,
  .inline.hidden-lg.hidden-md,
  .inline-block.hidden-lg.hidden-md,
  tr.hidden-lg.hidden-md,
  th.hidden-lg.hidden-md,
  td.hidden-lg.hidden-md {
    display: none !important;
    }
  }
@media (min-width: 1200px) {
  .hidden-lg,
  .inline.hidden-lg,
  .inline-block.hidden-lg,
  tr.hidden-lg,
  th.hidden-lg,
  td.hidden-lg {
    display: none !important;
    }
  }
.visible-print,
.inline.visible-print,
.inline-block.visible-print,
tr.visible-print,
th.visible-print,
td.visible-print {
  display: none !important;
  }
@media print {
  .visible-print {
    display: block !important;
    }
  .inline.visible-print {
    display: inline !important;
    }
  .inline-block.visible-print {
    display: inline-block !important;
    }
  tr.visible-print {
    display: table-row !important;
    }
  th.visible-print,
  td.visible-print {
    display: table-cell !important;
    }
  .hidden-print,
  .inline.hidden-print,
  .inline-block.hidden-print,
  tr.hidden-print,
  th.hidden-print,
  td.hidden-print {
    display: none !important;
    }
  }
*,
*:before,
*:after {
  -webkit-box-sizing: border-box;
     -moz-box-sizing: border-box;
          box-sizing: border-box;
  }
html {
  font-size: 10px;

  -webkit-tap-highlight-color: rgba(0, 0, 0, 0);
  }
body {
  font-family: "Helvetica Neue", Helvetica, Tahoma, Arial, 'Microsoft Yahei', 'Hiragino Sans GB', 'WenQuanYi Micro Hei', sans-serif;
  font-size: 13px;
  line-height: 1.53846154;
  color: #353535;
  background-color: #fff;
  }
input,
button,
select,
textarea {
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
  }
a {
  color: #145ccd;
  text-decoration: none;
  -webkit-transition: all .4s cubic-bezier(.175, .885, .32, 1);
       -o-transition: all .4s cubic-bezier(.175, .885, .32, 1);
          transition: all .4s cubic-bezier(.175, .885, .32, 1);
  }
a:hover,
a:focus {
  color: #0d3d88;
  text-decoration: underline;
  }
a:focus {
  outline: thin dotted #333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
  }
a.disabled,
a.disabled:hover,
a.disabled:focus,
a[disabled],
a[disabled]:hover,
a[disabled]:focus {
  color: #aaa;
  text-decoration: none;
  cursor: default;
  }
audio,
canvas,
img,
svg,
video {
  max-width: 100%;
  vertical-align: middle;
  }
.sr-only {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0 0 0 0);
  border: 0;
  }
::-moz-selection {
  text-shadow: none;
  background: #b3d4fc;
  }
::selection {
  text-shadow: none;
  background: #b3d4fc;
  }
fieldset {
  padding: 0;
  margin: 0;
  border: 0;
  }
textarea {
  resize: vertical;
  }
ol,
ul {
  padding-left: 20px;
  }
.container,
.container-fluid,
.container-fixed,
.container-fixed-md,
.container-fixed-sm,
.container-fixed-xs {
  padding-right: 10px;
  padding-left: 10px;
  margin-right: auto;
  margin-left: auto;
  }
@media (min-width: 768px) {
  .container {
    max-width: 740px;
    }
  }
@media (min-width: 992px) {
  .container {
    max-width: 960px;
    }
  }
@media (min-width: 1200px) {
  .container {
    max-width: 1160px;
    }
  }
.container-fixed {
  width: 1160px;
  }
.container-fixed-md {
  width: 960px;
  }
.container-fixed-sm {
  width: 740px;
  }
.container-fixed-xs {
  width: 440px;
  }
.row {
  margin-right: -10px;
  margin-left: -10px;
  }
.col,
.col-xs-1,
.col-xs-2,
.col-xs-3,
.col-xs-4,
.col-xs-5,
.col-xs-6,
.col-xs-7,
.col-xs-8,
.col-xs-9,
.col-xs-10,
.col-xs-11,
.col-xs-12,
.col-sm-1,
.col-sm-2,
.col-sm-3,
.col-sm-4,
.col-sm-5,
.col-sm-6,
.col-sm-7,
.col-sm-8,
.col-sm-9,
.col-sm-10,
.col-sm-11,
.col-sm-12,
.col-md-1,
.col-md-2,
.col-md-3,
.col-md-4,
.col-md-5,
.col-md-6,
.col-md-7,
.col-md-8,
.col-md-9,
.col-md-10,
.col-md-11,
.col-md-12,
.col-lg-1,
.col-lg-2,
.col-lg-3,
.col-lg-4,
.col-lg-5,
.col-lg-6,
.col-lg-7,
.col-lg-8,
.col-lg-9,
.col-lg-10,
.col-lg-11,
.col-lg-12 {
  position: relative;
  min-height: 1px;
  padding-right: 10px;
  padding-left: 10px;
  }
.col,
.col-xs,
.col-xs-1,
.col-xs-2,
.col-xs-3,
.col-xs-4,
.col-xs-5,
.col-xs-6,
.col-xs-7,
.col-xs-8,
.col-xs-9,
.col-xs-10,
.col-xs-11,
.col-xs-12 {
  float: left;
  }
.col-xs-1 {
  width: 8.33333333%;
  }
.col-xs-2 {
  width: 16.66666667%;
  }
.col-xs-3 {
  width: 25%;
  }
.col-xs-4 {
  width: 33.33333333%;
  }
.col-xs-5 {
  width: 41.66666667%;
  }
.col-xs-6 {
  width: 50%;
  }
.col-xs-7 {
  width: 58.33333333%;
  }
.col-xs-8 {
  width: 66.66666667%;
  }
.col-xs-9 {
  width: 75%;
  }
.col-xs-10 {
  width: 83.33333333%;
  }
.col-xs-11 {
  width: 91.66666667%;
  }
.col-xs-12 {
  width: 100%;
  }
@media (min-width: 768px) {
  .col-sm-1,
  .col-sm-2,
  .col-sm-3,
  .col-sm-4,
  .col-sm-5,
  .col-sm-6,
  .col-sm-7,
  .col-sm-8,
  .col-sm-9,
  .col-sm-10,
  .col-sm-11,
  .col-sm-12 {
    float: left;
    }
  .col-sm-1 {
    width: 8.33333333%;
    }
  .col-sm-2 {
    width: 16.66666667%;
    }
  .col-sm-3 {
    width: 25%;
    }
  .col-sm-4 {
    width: 33.33333333%;
    }
  .col-sm-5 {
    width: 41.66666667%;
    }
  .col-sm-6 {
    width: 50%;
    }
  .col-sm-7 {
    width: 58.33333333%;
    }
  .col-sm-8 {
    width: 66.66666667%;
    }
  .col-sm-9 {
    width: 75%;
    }
  .col-sm-10 {
    width: 83.33333333%;
    }
  .col-sm-11 {
    width: 91.66666667%;
    }
  .col-sm-12 {
    width: 100%;
    }
  .col-sm-push-1 {
    left: 8.33333333%;
    }
  .col-sm-push-2 {
    left: 16.66666667%;
    }
  .col-sm-push-3 {
    left: 25%;
    }
  .col-sm-push-4 {
    left: 33.33333333%;
    }
  .col-sm-push-5 {
    left: 41.66666667%;
    }
  .col-sm-push-6 {
    left: 50%;
    }
  .col-sm-push-7 {
    left: 58.33333333%;
    }
  .col-sm-push-8 {
    left: 66.66666667%;
    }
  .col-sm-push-9 {
    left: 75%;
    }
  .col-sm-push-10 {
    left: 83.33333333%;
    }
  .col-sm-push-11 {
    left: 91.66666667%;
    }
  .col-sm-pull-1 {
    right: 8.33333333%;
    }
  .col-sm-pull-2 {
    right: 16.66666667%;
    }
  .col-sm-pull-3 {
    right: 25%;
    }
  .col-sm-pull-4 {
    right: 33.33333333%;
    }
  .col-sm-pull-5 {
    right: 41.66666667%;
    }
  .col-sm-pull-6 {
    right: 50%;
    }
  .col-sm-pull-7 {
    right: 58.33333333%;
    }
  .col-sm-pull-8 {
    right: 66.66666667%;
    }
  .col-sm-pull-9 {
    right: 75%;
    }
  .col-sm-pull-10 {
    right: 83.33333333%;
    }
  .col-sm-pull-11 {
    right: 91.66666667%;
    }
  .col-sm-offset-1 {
    margin-left: 8.33333333%;
    }
  .col-sm-offset-2 {
    margin-left: 16.66666667%;
    }
  .col-sm-offset-3 {
    margin-left: 25%;
    }
  .col-sm-offset-4 {
    margin-left: 33.33333333%;
    }
  .col-sm-offset-5 {
    margin-left: 41.66666667%;
    }
  .col-sm-offset-6 {
    margin-left: 50%;
    }
  .col-sm-offset-7 {
    margin-left: 58.33333333%;
    }
  .col-sm-offset-8 {
    margin-left: 66.66666667%;
    }
  .col-sm-offset-9 {
    margin-left: 75%;
    }
  .col-sm-offset-10 {
    margin-left: 83.33333333%;
    }
  .col-sm-offset-11 {
    margin-left: 91.66666667%;
    }
  }
@media (min-width: 992px) {
  .col-md-1,
  .col-md-2,
  .col-md-3,
  .col-md-4,
  .col-md-5,
  .col-md-6,
  .col-md-7,
  .col-md-8,
  .col-md-9,
  .col-md-10,
  .col-md-11,
  .col-md-12 {
    float: left;
    }
  .col-md-1 {
    width: 8.33333333%;
    }
  .col-md-2 {
    width: 16.66666667%;
    }
  .col-md-3 {
    width: 25%;
    }
  .col-md-4 {
    width: 33.33333333%;
    }
  .col-md-5 {
    width: 41.66666667%;
    }
  .col-md-6 {
    width: 50%;
    }
  .col-md-7 {
    width: 58.33333333%;
    }
  .col-md-8 {
    width: 66.66666667%;
    }
  .col-md-9 {
    width: 75%;
    }
  .col-md-10 {
    width: 83.33333333%;
    }
  .col-md-11 {
    width: 91.66666667%;
    }
  .col-md-12 {
    width: 100%;
    }
  .col-md-push-0 {
    left: auto;
    }
  .col-md-push-1 {
    left: 8.33333333%;
    }
  .col-md-push-2 {
    left: 16.66666667%;
    }
  .col-md-push-3 {
    left: 25%;
    }
  .col-md-push-4 {
    left: 33.33333333%;
    }
  .col-md-push-5 {
    left: 41.66666667%;
    }
  .col-md-push-6 {
    left: 50%;
    }
  .col-md-push-7 {
    left: 58.33333333%;
    }
  .col-md-push-8 {
    left: 66.66666667%;
    }
  .col-md-push-9 {
    left: 75%;
    }
  .col-md-push-10 {
    left: 83.33333333%;
    }
  .col-md-push-11 {
    left: 91.66666667%;
    }
  .col-md-pull-0 {
    right: auto;
    }
  .col-md-pull-1 {
    right: 8.33333333%;
    }
  .col-md-pull-2 {
    right: 16.66666667%;
    }
  .col-md-pull-3 {
    right: 25%;
    }
  .col-md-pull-4 {
    right: 33.33333333%;
    }
  .col-md-pull-5 {
    right: 41.66666667%;
    }
  .col-md-pull-6 {
    right: 50%;
    }
  .col-md-pull-7 {
    right: 58.33333333%;
    }
  .col-md-pull-8 {
    right: 66.66666667%;
    }
  .col-md-pull-9 {
    right: 75%;
    }
  .col-md-pull-10 {
    right: 83.33333333%;
    }
  .col-md-pull-11 {
    right: 91.66666667%;
    }
  .col-md-offset-0 {
    margin-left: 0;
    }
  .col-md-offset-1 {
    margin-left: 8.33333333%;
    }
  .col-md-offset-2 {
    margin-left: 16.66666667%;
    }
  .col-md-offset-3 {
    margin-left: 25%;
    }
  .col-md-offset-4 {
    margin-left: 33.33333333%;
    }
  .col-md-offset-5 {
    margin-left: 41.66666667%;
    }
  .col-md-offset-6 {
    margin-left: 50%;
    }
  .col-md-offset-7 {
    margin-left: 58.33333333%;
    }
  .col-md-offset-8 {
    margin-left: 66.66666667%;
    }
  .col-md-offset-9 {
    margin-left: 75%;
    }
  .col-md-offset-10 {
    margin-left: 83.33333333%;
    }
  .col-md-offset-11 {
    margin-left: 91.66666667%;
    }
  }
@media (min-width: 1200px) {
  .col-lg-1,
  .col-lg-2,
  .col-lg-3,
  .col-lg-4,
  .col-lg-5,
  .col-lg-6,
  .col-lg-7,
  .col-lg-8,
  .col-lg-9,
  .col-lg-10,
  .col-lg-11,
  .col-lg-12 {
    float: left;
    }
  .col-lg-1 {
    width: 8.33333333%;
    }
  .col-lg-2 {
    width: 16.66666667%;
    }
  .col-lg-3 {
    width: 25%;
    }
  .col-lg-4 {
    width: 33.33333333%;
    }
  .col-lg-5 {
    width: 41.66666667%;
    }
  .col-lg-6 {
    width: 50%;
    }
  .col-lg-7 {
    width: 58.33333333%;
    }
  .col-lg-8 {
    width: 66.66666667%;
    }
  .col-lg-9 {
    width: 75%;
    }
  .col-lg-10 {
    width: 83.33333333%;
    }
  .col-lg-11 {
    width: 91.66666667%;
    }
  .col-lg-12 {
    width: 100%;
    }
  .col-lg-push-0 {
    left: auto;
    }
  .col-lg-push-1 {
    left: 8.33333333%;
    }
  .col-lg-push-2 {
    left: 16.66666667%;
    }
  .col-lg-push-3 {
    left: 25%;
    }
  .col-lg-push-4 {
    left: 33.33333333%;
    }
  .col-lg-push-5 {
    left: 41.66666667%;
    }
  .col-lg-push-6 {
    left: 50%;
    }
  .col-lg-push-7 {
    left: 58.33333333%;
    }
  .col-lg-push-8 {
    left: 66.66666667%;
    }
  .col-lg-push-9 {
    left: 75%;
    }
  .col-lg-push-10 {
    left: 83.33333333%;
    }
  .col-lg-push-11 {
    left: 91.66666667%;
    }
  .col-lg-pull-0 {
    right: auto;
    }
  .col-lg-pull-1 {
    right: 8.33333333%;
    }
  .col-lg-pull-2 {
    right: 16.66666667%;
    }
  .col-lg-pull-3 {
    right: 25%;
    }
  .col-lg-pull-4 {
    right: 33.33333333%;
    }
  .col-lg-pull-5 {
    right: 41.66666667%;
    }
  .col-lg-pull-6 {
    right: 50%;
    }
  .col-lg-pull-7 {
    right: 58.33333333%;
    }
  .col-lg-pull-8 {
    right: 66.66666667%;
    }
  .col-lg-pull-9 {
    right: 75%;
    }
  .col-lg-pull-10 {
    right: 83.33333333%;
    }
  .col-lg-pull-11 {
    right: 91.66666667%;
    }
  .col-lg-offset-0 {
    margin-left: 0;
    }
  .col-lg-offset-1 {
    margin-left: 8.33333333%;
    }
  .col-lg-offset-2 {
    margin-left: 16.66666667%;
    }
  .col-lg-offset-3 {
    margin-left: 25%;
    }
  .col-lg-offset-4 {
    margin-left: 33.33333333%;
    }
  .col-lg-offset-5 {
    margin-left: 41.66666667%;
    }
  .col-lg-offset-6 {
    margin-left: 50%;
    }
  .col-lg-offset-7 {
    margin-left: 58.33333333%;
    }
  .col-lg-offset-8 {
    margin-left: 66.66666667%;
    }
  .col-lg-offset-9 {
    margin-left: 75%;
    }
  .col-lg-offset-10 {
    margin-left: 83.33333333%;
    }
  .col-lg-offset-11 {
    margin-left: 91.66666667%;
    }
  }
p {
  margin: 0 0 10px;
  }
.lead {
  margin-bottom: 20px;
  font-size: 14px;
  line-height: 1.4;
  }
@media (min-width: 768px) {
  .lead {
    font-size: 19.5px;
    }
  }
small,
.small {
  font-size: 85%;
  }
cite {
  font-style: normal;
  }
.text-muted {
  color: #808080;
  }
.text-muted a {
  color: #737373;
  }
.text-muted a:hover,
.text-muted a:active {
  color: #145ccd;
  }
.text-primary {
  color: #3280fc;
  }
.text-primary:hover {
  color: #0462f7;
  }
.text-warning {
  color: #f1a325;
  }
.text-warning:hover {
  color: #d5890e;
  }
.text-danger {
  color: #ea644a;
  }
.text-danger:hover {
  color: #e53d1c;
  }
.text-success {
  color: #38b03f;
  }
.text-success:hover {
  color: #2c8931;
  }
.text-info {
  color: #03b8cf;
  }
.text-info:hover {
  color: #028b9d;
  }
.text-important {
  color: #bd7b46;
  }
.text-important:hover {
  color: #996337;
  }
.text-special {
  color: #8666b8;
  }
.text-special:hover {
  color: #6c4aa1;
  }
.text-link {
  color: #353535;
  }
.text-link:hover,
.text-link:active {
  color: #145ccd;
  }
.text-left {
  text-align: left;
  }
.text-right {
  text-align: right;
  }
.text-center {
  text-align: center;
  }
.text-nowrap,
.nobr {
  overflow: hidden;
  white-space: nowrap;
  }
.text-ellipsis {
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  }
ul,
ol {
  margin-top: 0;
  margin-bottom: 10px;
  }
ul ul,
ol ul,
ul ol,
ol ol {
  margin-bottom: 0;
  }
.list-unstyled {
  padding-left: 0;
  list-style: none;
  }
dl {
  margin-bottom: 20px;
  }
dt,
dd {
  line-height: 1.53846154;
  }
dt {
  font-weight: bold;
  }
dd {
  margin-left: 0;
  }
.dl-inline:before,
.dl-inline:after {
  /* 1 */
  display: table;
  content: " ";
  /* 2 */
  }
.dl-inline:after {
  clear: both;
  }
.dl-inline:before,
.dl-inline:after {
  /* 1 */
  display: table;
  content: " ";
  /* 2 */
  }
.dl-inline:after {
  clear: both;
  }
.dl-inline dt {
  display: inline-block;
  }
.dl-inline dd {
  display: inline-block;
  padding-right: 1em;
  }
.dl-inline dd:last-child {
  padding-right: 0;
  }
@media (min-width: 768px) {
  .dl-horizontal dt {
    float: left;
    width: 160px;
    overflow: hidden;
    clear: left;
    text-align: right;
    text-overflow: ellipsis;
    white-space: nowrap;
    }
  .dl-horizontal dd {
    margin-left: 180px;
    }
  }
blockquote {
  padding: 10px 20px;
  margin: 0 0 20px;
  font-size: 16.25px;
  border-left: 5px solid #e5e5e5;
  }
blockquote p,
blockquote ul,
blockquote ol {
  font-weight: 300;
  }
blockquote p:last-child,
blockquote ul:last-child,
blockquote ol:last-child {
  margin-bottom: 0;
  }
blockquote small {
  display: block;
  line-height: 1.53846154;
  color: #808080;
  }
blockquote small:before {
  content: '\2014 \00A0';
  }
blockquote.pull-right {
  padding-right: 15px;
  padding-left: 0;
  border-right: 5px solid #e5e5e5;
  border-left: 0;
  }
blockquote.pull-right p,
blockquote.pull-right small {
  text-align: right;
  }
blockquote.pull-right small:before {
  content: '';
  }
blockquote.pull-right small:after {
  content: '\00A0 \2014';
  }
.bg-default {
  color: #fff;
  background-color: #353535;
  }
a.bg-default:hover {
  background-color: #1c1c1c;
  }
.bg-primary {
  color: #fff;
  background-color: #3280fc;
  }
a.bg-primary:hover {
  background-color: #0462f7;
  }
.bg-success {
  color: #fff;
  background-color: #38b03f;
  }
a.bg-success:hover {
  background-color: #2c8931;
  }
.bg-info {
  color: #fff;
  background-color: #03b8cf;
  }
a.bg-info:hover {
  background-color: #028b9d;
  }
.bg-warning {
  color: #fff;
  background-color: #f1a325;
  }
a.bg-warning:hover {
  background-color: #d5890e;
  }
.bg-danger {
  color: #fff;
  background-color: #ea644a;
  }
a.bg-danger:hover {
  background-color: #e53d1c;
  }
.bg-important {
  color: #fff;
  background-color: #bd7b46;
  }
a.bg-important:hover {
  background-color: #996337;
  }
.bg-special {
  color: #fff;
  background-color: #8666b8;
  }
a.bg-special:hover {
  background-color: #6c4aa1;
  }
.hl-default {
  background-color: #f1f1f1;
  }
a.hl-default:hover {
  background-color: #d7d7d7;
  }
.hl-primary {
  background-color: #ebf2f9;
  }
a.hl-primary:hover {
  background-color: #c4d8ed;
  }
.hl-success {
  background-color: #ddf4df;
  }
a.hl-success:hover {
  background-color: #b6e8bb;
  }
.hl-info {
  background-color: #ddf3f5;
  }
a.hl-info:hover {
  background-color: #b6e5e9;
  }
.hl-warning {
  background-color: #fff0d5;
  }
a.hl-warning:hover {
  background-color: #ffdea2;
  }
.hl-danger {
  background-color: #ffe5e0;
  }
a.hl-danger:hover {
  background-color: #ffbaad;
  }
.hl-important {
  background-color: #f7ebe1;
  }
a.hl-important:hover {
  background-color: #ecd0b9;
  }
.hl-special {
  background-color: #f5eeff;
  }
a.hl-special:hover {
  background-color: #d7bbff;
  }
.page-header,
.header-dividing {
  padding-bottom: 9px;
  margin: 40px 0 20px;
  border-bottom: 1px solid #e5e5e5;
  }
h1,
h2,
h3,
h4,
h5,
h6 {
  font-family: "Helvetica Neue", Helvetica, Tahoma, Arial, 'Microsoft Yahei', 'Hiragino Sans GB', 'WenQuanYi Micro Hei', sans-serif;
  font-weight: bold;
  line-height: 1.1;
  color: inherit;
  }
h1 small,
h2 small,
h3 small,
h4 small,
h5 small,
h6 small {
  font-weight: normal;
  line-height: 1;
  color: #808080;
  }
h1,
h2,
h3 {
  margin-top: 20px;
  margin-bottom: 10px;
  }
h1 small,
h2 small,
h3 small {
  font-size: 65%;
  }
h4,
h5,
h6 {
  margin-top: 10px;
  margin-bottom: 10px;
  }
h4 small,
h5 small,
h6 small {
  font-size: 75%;
  }
h1 {
  font-size: 26px;
  }
h2 {
  font-size: 20px;
  }
h3 {
  font-size: 16px;
  }
h4 {
  font-size: 14px;
  }
h5 {
  font-size: 13px;
  }
h6 {
  font-size: 12px;
  }
.btn {
  display: inline-block;
  padding: 5px 12px;
  margin-bottom: 0;
  font-size: 13px;
  font-weight: normal;
  line-height: 1.53846154;
  text-align: center;
  white-space: nowrap;
  vertical-align: middle;
  cursor: pointer;
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;
  border: 1px solid transparent;
  border-radius: 4px;
  -webkit-transition: all .4s cubic-bezier(.175, .885, .32, 1);
       -o-transition: all .4s cubic-bezier(.175, .885, .32, 1);
          transition: all .4s cubic-bezier(.175, .885, .32, 1);
  }
.btn:focus {
  outline: thin dotted #333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
  }
.btn:hover,
.btn:focus {
  color: #353535;
  text-decoration: none;
  }
.btn:active,
.btn.active {
  background-image: none;
  outline: none;
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);
          box-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);
  }
.btn.disabled,
.btn[disabled],
fieldset[disabled] .btn {
  pointer-events: none;
  cursor: not-allowed;
  filter: alpha(opacity=65);
  -webkit-box-shadow: none;
          box-shadow: none;
  opacity: .65;
  }
.btn {
  color: #353535;
  text-shadow: 0 1px 0 #fff;
  background-color: #f2f2f2;
  border-color: #bfbfbf;
  }
.btn:hover,
.btn:focus,
.btn:active,
.btn.active,
.open .dropdown-toggle.btn {
  color: #353535;
  background-color: #dedede;
  border-color: #a1a1a1;
  -webkit-box-shadow: 0 2px 1px rgba(0, 0, 0, .1);
          box-shadow: 0 2px 1px rgba(0, 0, 0, .1);
  }
.btn:active,
.btn.active,
.open .dropdown-toggle.btn {
  background-color: #ccc;
  background-image: none;
  border-color: #a6a6a6;
  -webkit-box-shadow: inset 0 4px 6px rgba(0, 0, 0, .15);
          box-shadow: inset 0 4px 6px rgba(0, 0, 0, .15);
  }
.btn.disabled,
.btn[disabled],
fieldset[disabled] .btn,
.btn.disabled:hover,
.btn[disabled]:hover,
fieldset[disabled] .btn:hover,
.btn.disabled:focus,
.btn[disabled]:focus,
fieldset[disabled] .btn:focus,
.btn.disabled:active,
.btn[disabled]:active,
fieldset[disabled] .btn:active,
.btn.disabled.active,
.btn[disabled].active,
fieldset[disabled] .btn.active {
  background-color: #f2f2f2;
  border-color: #bfbfbf;
  }
.btn-primary {
  color: #fff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, .2);
  background-color: #3280fc;
  border-color: #1970fc;
  }
.btn-primary:hover,
.btn-primary:focus,
.btn-primary:active,
.btn-primary.active,
.open .dropdown-toggle.btn-primary {
  color: #fff;
  background-color: #0a67fb;
  border-color: #0354d4;
  -webkit-box-shadow: 0 2px 1px rgba(0, 0, 0, .1);
          box-shadow: 0 2px 1px rgba(0, 0, 0, .1);
  }
.btn-primary:active,
.btn-primary.active,
.open .dropdown-toggle.btn-primary {
  background-color: #0358de;
  background-image: none;
  border-color: #0358de;
  -webkit-box-shadow: inset 0 4px 6px rgba(0, 0, 0, .15);
          box-shadow: inset 0 4px 6px rgba(0, 0, 0, .15);
  }
.btn-primary.disabled,
.btn-primary[disabled],
fieldset[disabled] .btn-primary,
.btn-primary.disabled:hover,
.btn-primary[disabled]:hover,
fieldset[disabled] .btn-primary:hover,
.btn-primary.disabled:focus,
.btn-primary[disabled]:focus,
fieldset[disabled] .btn-primary:focus,
.btn-primary.disabled:active,
.btn-primary[disabled]:active,
fieldset[disabled] .btn-primary:active,
.btn-primary.disabled.active,
.btn-primary[disabled].active,
fieldset[disabled] .btn-primary.active {
  background-color: #3280fc;
  border-color: #1970fc;
  }
.btn-warning {
  color: #fff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, .2);
  background-color: #f1a325;
  border-color: #ed980f;
  }
.btn-warning:hover,
.btn-warning:focus,
.btn-warning:active,
.btn-warning.active,
.open .dropdown-toggle.btn-warning {
  color: #fff;
  background-color: #df8f0e;
  border-color: #b4730c;
  -webkit-box-shadow: 0 2px 1px rgba(0, 0, 0, .1);
          box-shadow: 0 2px 1px rgba(0, 0, 0, .1);
  }
.btn-warning:active,
.btn-warning.active,
.open .dropdown-toggle.btn-warning {
  background-color: #bd7a0c;
  background-image: none;
  border-color: #bd7a0c;
  -webkit-box-shadow: inset 0 4px 6px rgba(0, 0, 0, .15);
          box-shadow: inset 0 4px 6px rgba(0, 0, 0, .15);
  }
.btn-warning.disabled,
.btn-warning[disabled],
fieldset[disabled] .btn-warning,
.btn-warning.disabled:hover,
.btn-warning[disabled]:hover,
fieldset[disabled] .btn-warning:hover,
.btn-warning.disabled:focus,
.btn-warning[disabled]:focus,
fieldset[disabled] .btn-warning:focus,
.btn-warning.disabled:active,
.btn-warning[disabled]:active,
fieldset[disabled] .btn-warning:active,
.btn-warning.disabled.active,
.btn-warning[disabled].active,
fieldset[disabled] .btn-warning.active {
  background-color: #f1a325;
  border-color: #ed980f;
  }
.btn-danger {
  color: #fff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, .2);
  background-color: #ea644a;
  border-color: #e75033;
  }
.btn-danger:hover,
.btn-danger:focus,
.btn-danger:active,
.btn-danger.active,
.open .dropdown-toggle.btn-danger {
  color: #fff;
  background-color: #e64525;
  border-color: #c63317;
  -webkit-box-shadow: 0 2px 1px rgba(0, 0, 0, .1);
          box-shadow: 0 2px 1px rgba(0, 0, 0, .1);
  }
.btn-danger:active,
.btn-danger.active,
.open .dropdown-toggle.btn-danger {
  background-color: #cf3618;
  background-image: none;
  border-color: #cf3618;
  -webkit-box-shadow: inset 0 4px 6px rgba(0, 0, 0, .15);
          box-shadow: inset 0 4px 6px rgba(0, 0, 0, .15);
  }
.btn-danger.disabled,
.btn-danger[disabled],
fieldset[disabled] .btn-danger,
.btn-danger.disabled:hover,
.btn-danger[disabled]:hover,
fieldset[disabled] .btn-danger:hover,
.btn-danger.disabled:focus,
.btn-danger[disabled]:focus,
fieldset[disabled] .btn-danger:focus,
.btn-danger.disabled:active,
.btn-danger[disabled]:active,
fieldset[disabled] .btn-danger:active,
.btn-danger.disabled.active,
.btn-danger[disabled].active,
fieldset[disabled] .btn-danger.active {
  background-color: #ea644a;
  border-color: #e75033;
  }
.btn-success {
  color: #fff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, .2);
  background-color: #38b03f;
  border-color: #329d38;
  }
.btn-success:hover,
.btn-success:focus,
.btn-success:active,
.btn-success.active,
.open .dropdown-toggle.btn-success {
  color: #fff;
  background-color: #2e9134;
  border-color: #236e27;
  -webkit-box-shadow: 0 2px 1px rgba(0, 0, 0, .1);
          box-shadow: 0 2px 1px rgba(0, 0, 0, .1);
  }
.btn-success:active,
.btn-success.active,
.open .dropdown-toggle.btn-success {
  background-color: #26762a;
  background-image: none;
  border-color: #26762a;
  -webkit-box-shadow: inset 0 4px 6px rgba(0, 0, 0, .15);
          box-shadow: inset 0 4px 6px rgba(0, 0, 0, .15);
  }
.btn-success.disabled,
.btn-success[disabled],
fieldset[disabled] .btn-success,
.btn-success.disabled:hover,
.btn-success[disabled]:hover,
fieldset[disabled] .btn-success:hover,
.btn-success.disabled:focus,
.btn-success[disabled]:focus,
fieldset[disabled] .btn-success:focus,
.btn-success.disabled:active,
.btn-success[disabled]:active,
fieldset[disabled] .btn-success:active,
.btn-success.disabled.active,
.btn-success[disabled].active,
fieldset[disabled] .btn-success.active {
  background-color: #38b03f;
  border-color: #329d38;
  }
.btn-info {
  color: #fff;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, .2);
  background-color: #03b8cf;
  border-color: #03a2b6;
  }
.btn-info:hover,
.btn-info:focus,
.btn-info:active,
.btn-info.active,
.open .dropdown-toggle.btn-info {
  color: #fff;
  background-color: #0294a7;
  border-color: #026c7a;
  -webkit-box-shadow: 0 2px 1px rgba(0, 0, 0, .1);
          box-shadow: 0 2px 1px rgba(0, 0, 0, .1);
  }
.btn-info:active,
.btn-info.active,
.open .dropdown-toggle.btn-info {
  background-color: #027584;
  background-image: none;
  border-color: #027584;
  -webkit-box-shadow: inset 0 4px 6px rgba(0, 0, 0, .15);
          box-shadow: inset 0 4px 6px rgba(0, 0, 0, .15);
  }
.btn-info.disabled,
.btn-info[disabled],
fieldset[disabled] .btn-info,
.btn-info.disabled:hover,
.btn-info[disabled]:hover,
fieldset[disabled] .btn-info:hover,
.btn-info.disabled:focus,
.btn-info[disabled]:focus,
fieldset[disabled] .btn-info:focus,
.btn-info.disabled:active,
.btn-info[disabled]:active,
fieldset[disabled] .btn-info:active,
.btn-info.disabled.active,
.btn-info[disabled].active,
fieldset[disabled] .btn-info.active {
  background-color: #03b8cf;
  border-color: #03a2b6;
  }
.btn-link {
  font-weight: normal;
  color: #145ccd;
  text-shadow: none;
  cursor: pointer;
  background: none;
  -webkit-box-shadow: none;
          box-shadow: none;
  }
.btn-link,
.btn-link:active,
.btn-link[disabled],
fieldset[disabled] .btn-link,
.btn-link:hover,
.btn-link:focus {
  border-color: transparent;
  -webkit-box-shadow: none;
          box-shadow: none;
  }
.btn-link:hover,
.btn-link:focus {
  color: #0d3d88;
  }
.btn-link[disabled]:hover,
fieldset[disabled] .btn-link:hover,
.btn-link[disabled]:focus,
fieldset[disabled] .btn-link:focus {
  color: #ddd;
  text-decoration: none;
  }
.btn-lg {
  padding: 10px 16px;
  font-size: 17px;
  line-height: 1.25;
  border-radius: 4px;
  }
.btn-sm,
.btn-xs,
.btn-mini {
  padding: 2px 8px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 4px;
  }
.btn-xs,
.btn-mini {
  padding: 1px 5px;
  }
.btn-block {
  display: block;
  width: 100%;
  }
.btn-block + .btn-block {
  margin-top: 5px;
  }
input[type="submit"].btn-block,
input[type="reset"].btn-block,
input[type="button"].btn-block {
  width: 100%;
  }
.btn-group,
.btn-group-vertical {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  }
.btn-group > .btn,
.btn-group-vertical > .btn {
  position: relative;
  float: left;
  }
.btn-group > .btn:hover,
.btn-group > .btn:focus,
.btn-group > .btn:active,
.btn-group > .btn.active,
.btn-group-vertical > .btn:hover,
.btn-group-vertical > .btn:focus,
.btn-group-vertical > .btn:active,
.btn-group-vertical > .btn.active {
  z-index: 2;
  }
.btn-group > .btn:focus,
.btn-group-vertical > .btn:focus {
  outline: none;
  }
.btn-group .btn + .btn,
.btn-group .btn + .btn-group,
.btn-group .btn-group + .btn,
.btn-group .btn-group + .btn-group,
.btn-group-vertical .btn + .btn,
.btn-group-vertical .btn + .btn-group-vertical,
.btn-group-vertical .btn-group-vertical + .btn,
.btn-group-vertical .btn-group-vertical + .btn-group-vertical {
  margin-left: -1px;
  }
.btn-toolbar {
  margin-left: -5px;
  }
.btn-toolbar .btn,
.btn-toolbar .btn-group,
.btn-toolbar .input-group,
.btn-toolbar .btn-group-vertical {
  float: left;
  }
.btn-toolbar > .btn,
.btn-toolbar > .btn-group,
.btn-toolbar > .input-group,
.btn-toolbar > .btn-group-vertical {
  margin-left: 5px;
  }
.btn-group > .btn:not(:first-child):not(:last-child):not(.dropdown-toggle),
.btn-group-vertical > .btn:not(:first-child):not(:last-child):not(.dropdown-toggle) {
  border-radius: 0;
  }
.btn-group > .btn:first-child,
.btn-group-vertical > .btn:first-child {
  margin-left: 0;
  }
.btn-group > .btn:first-child:not(:last-child):not(.dropdown-toggle),
.btn-group-vertical > .btn:first-child:not(:last-child):not(.dropdown-toggle) {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  }
.btn-group > .btn:last-child:not(:first-child),
.btn-group > .dropdown-toggle:not(:first-child),
.btn-group-vertical > .btn:last-child:not(:first-child),
.btn-group-vertical > .dropdown-toggle:not(:first-child) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  }
.btn-group > .btn-group,
.btn-group-vertical > .btn-group-vertical {
  float: left;
  }
.btn-group > .btn-group:not(:first-child):not(:last-child) > .btn,
.btn-group-vertical > .btn-group-vertical:not(:first-child):not(:last-child) > .btn {
  border-radius: 0;
  }
.btn-group > .btn-group:first-child > .btn:last-child,
.btn-group > .btn-group:first-child > .dropdown-toggle,
.btn-group-vertical > .btn-group-vertical:first-child > .btn:last-child,
.btn-group-vertical > .btn-group-vertical:first-child > .dropdown-toggle {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  }
.btn-group > .btn-group:last-child > .btn:first-child,
.btn-group-vertical > .btn-group-vertical:last-child > .btn:first-child {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  }
.btn-group .dropdown-toggle:active,
.btn-group.open .dropdown-toggle,
.btn-group-vertical .dropdown-toggle:active,
.btn-group-vertical.open .dropdown-toggle {
  outline: 0;
  }
.btn-group-xs > .btn {
  padding: 2px 8px;
  padding: 1px 5px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 4px;
  }
.btn-group-sm > .btn {
  padding: 2px 8px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 4px;
  }
.btn-group-lg > .btn {
  padding: 10px 16px;
  font-size: 17px;
  line-height: 1.25;
  border-radius: 4px;
  }
.btn-group > .btn + .dropdown-toggle,
.btn-group-vertical > .btn + .dropdown-toggle {
  padding-right: 8px;
  padding-left: 8px;
  }
.btn-group > .btn-lg + .dropdown-toggle,
.btn-group-vertical > .btn-lg + .dropdown-toggle {
  padding-right: 12px;
  padding-left: 12px;
  }
.btn-group.open .dropdown-toggle,
.btn-group-vertical.open .dropdown-toggle {
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);
          box-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);
  }
.btn-group.open .dropdown-toggle.btn-link,
.btn-group-vertical.open .dropdown-toggle.btn-link {
  -webkit-box-shadow: none;
          box-shadow: none;
  }
.btn .caret {
  margin-left: 0;
  }
.btn-lg .caret {
  border-width: 5px 5px 0;
  border-bottom-width: 0;
  }
.dropup .btn-lg .caret {
  border-width: 0 5px 5px;
  }
.btn-group-justified {
  display: table;
  width: 100%;
  table-layout: fixed;
  border-collapse: separate;
  }
.btn-group-justified > .btn,
.btn-group-justified > .btn-group,
.btn-group-justified > .btn-group-vertical {
  display: table-cell;
  float: none;
  width: 1%;
  }
.btn-group-justified > .btn-group .btn,
.btn-group-justified > .btn-group-vertical .btn {
  width: 100%;
  }
.btn-group-justified > .btn-group .dropdown-menu,
.btn-group-justified > .btn-group-vertical .dropdown-menu {
  left: auto;
  }
[data-toggle="buttons"] > .btn input[type="radio"],
[data-toggle="buttons"] > .btn-group > .btn input[type="radio"],
[data-toggle="buttons"] > .btn input[type="checkbox"],
[data-toggle="buttons"] > .btn-group > .btn input[type="checkbox"],
[data-toggle="buttons"] > .btn-group-vertical > .btn input[type="radio"],
[data-toggle="buttons"] > .btn-group-vertical > .btn input[type="checkbox"] {
  position: absolute;
  clip: rect(0, 0, 0, 0);
  pointer-events: none;
  }
.btn-group-vertical > .btn,
.btn-group-vertical > .btn-group,
.btn-group-vertical > .btn-group > .btn,
.btn-group-vertical > .btn-group-vertical,
.btn-group-vertical > .btn-group-vertical > .btn {
  display: block;
  float: none;
  width: 100%;
  max-width: 100%;
  }
.btn-group-vertical > .btn-group > .btn,
.btn-group-vertical > .btn-group-vertical > .btn {
  float: none;
  }
.btn-group-vertical > .btn + .btn,
.btn-group-vertical > .btn + .btn-group,
.btn-group-vertical > .btn-group + .btn,
.btn-group-vertical > .btn-group + .btn-group,
.btn-group-vertical > .btn + .btn-group-vertical,
.btn-group-vertical > .btn-group-vertical + .btn,
.btn-group-vertical > .btn-group-vertical + .btn-group-vertical {
  margin-top: -1px;
  margin-left: 0;
  }
.btn-group-vertical > .btn:not(:first-child):not(:last-child) {
  border-radius: 0;
  }
.btn-group-vertical > .btn:first-child:not(:last-child) {
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
  }
.btn-group-vertical > .btn:last-child:not(:first-child) {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  border-bottom-right-radius: 4px;
  border-bottom-left-radius: 4px;
  }
.btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > .btn,
.btn-group-vertical > .btn-group-vertical:not(:first-child):not(:last-child) > .btn {
  border-radius: 0;
  }
.btn-group-vertical > .btn-group:first-child:not(:last-child) > .btn:last-child,
.btn-group-vertical > .btn-group:first-child:not(:last-child) > .dropdown-toggle,
.btn-group-vertical > .btn-group-vertical:first-child:not(:last-child) > .btn:last-child,
.btn-group-vertical > .btn-group-vertical:first-child:not(:last-child) > .dropdown-toggle {
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
  }
.btn-group-vertical > .btn-group:last-child:not(:first-child) > .btn:first-child,
.btn-group-vertical > .btn-group-vertical:last-child:not(:first-child) > .btn:first-child {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  }
@-webkit-keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
    }
  to {
    background-position: 0 0;
    }
  }
@-o-keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
    }
  to {
    background-position: 0 0;
    }
  }
@keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
    }
  to {
    background-position: 0 0;
    }
  }
.progress {
  height: 20px;
  margin-bottom: 20px;
  overflow: hidden;
  background-color: #e5e5e5;
  border-radius: 4px;
  }
.progress-bar {
  float: left;
  width: 0;
  height: 100%;
  font-size: 12px;
  color: #fff;
  text-align: center;
  background-color: #3280fc;
  -webkit-transition: width .6s ease;
       -o-transition: width .6s ease;
          transition: width .6s ease;
  }
.progress-striped .progress-bar {
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, .15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, .15) 50%, rgba(255, 255, 255, .15) 75%, transparent 75%, transparent);
  background-image:      -o-linear-gradient(45deg, rgba(255, 255, 255, .15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, .15) 50%, rgba(255, 255, 255, .15) 75%, transparent 75%, transparent);
  background-image:         linear-gradient(45deg, rgba(255, 255, 255, .15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, .15) 50%, rgba(255, 255, 255, .15) 75%, transparent 75%, transparent);
  -webkit-background-size: 40px 40px;
          background-size: 40px 40px;
  }
.progress.active .progress-bar {
  -webkit-animation: progress-bar-stripes 2s linear infinite;
       -o-animation: progress-bar-stripes 2s linear infinite;
          animation: progress-bar-stripes 2s linear infinite;
  }
.progress-bar-success {
  background-color: #38b03f;
  }
.progress-bar-info {
  background-color: #03b8cf;
  }
.progress-bar-warning {
  background-color: #f1a325;
  }
.progress-bar-danger {
  background-color: #ea644a;
  }
.img-responsive,
.carousel-inner > .item > img,
.carousel-inner > .item > a > img {
  display: block;
  max-width: 100%;
  height: auto;
  }
.img-rounded {
  border-radius: 6px;
  }
.img-thumbnail {
  display: inline-block;
  max-width: 100%;
  height: auto;
  padding: 4px;
  line-height: 1.53846154;
  background-color: #fff;
  border: 1px solid #ddd;
  border-radius: 4px;
  -webkit-transition: all .2s ease-in-out;
       -o-transition: all .2s ease-in-out;
          transition: all .2s ease-in-out;
  }
.img-circle {
  border-radius: 50%;
  }
hr {
  margin-top: 20px;
  margin-bottom: 20px;
  border: 0;
  border-top: 1px solid #e5e5e5;
  }
.label {
  display: inline;
  padding: .2em .6em .2em;
  font-size: 75%;
  line-height: 1;
  color: #fff;
  text-align: center;
  white-space: nowrap;
  vertical-align: middle;
  background-color: #808080;
  border-radius: .25em;
  }
.label[href]:hover,
.label[href]:focus {
  color: #fff;
  background-color: #666;
  }
.label.label-circle {
  color: #808080;
  background: none;
  border: 1px solid #808080;
  }
a.label:hover,
a.label:focus {
  color: #fff;
  text-decoration: none;
  cursor: pointer;
  }
.label:empty {
  display: none;
  }
.label-badge {
  display: inline-block;
  min-width: 18px;
  padding: 3px 7px;
  font-size: 12px;
  line-height: 1;
  border-radius: 9px;
  }
.label-dot {
  display: inline-block;
  width: 10px;
  height: 10px;
  padding: 0;
  line-height: 13px;
  text-indent: -9999em;
  border-radius: 5px;
  }
.label-dot:empty {
  display: inline-block;
  }
.label-primary {
  background-color: #3280fc;
  }
.label-primary[href]:hover,
.label-primary[href]:focus {
  color: #fff;
  background-color: #0462f7;
  }
.label-primary.label-circle {
  color: #3280fc;
  background: none;
  border: 1px solid #3280fc;
  }
.label-success {
  background-color: #38b03f;
  }
.label-success[href]:hover,
.label-success[href]:focus {
  color: #fff;
  background-color: #2c8931;
  }
.label-success.label-circle {
  color: #38b03f;
  background: none;
  border: 1px solid #38b03f;
  }
.label-info {
  background-color: #03b8cf;
  }
.label-info[href]:hover,
.label-info[href]:focus {
  color: #fff;
  background-color: #028b9d;
  }
.label-info.label-circle {
  color: #03b8cf;
  background: none;
  border: 1px solid #03b8cf;
  }
.label-warning {
  background-color: #f1a325;
  }
.label-warning[href]:hover,
.label-warning[href]:focus {
  color: #fff;
  background-color: #d5890e;
  }
.label-warning.label-circle {
  color: #f1a325;
  background: none;
  border: 1px solid #f1a325;
  }
.label-danger {
  background-color: #ea644a;
  }
.label-danger[href]:hover,
.label-danger[href]:focus {
  color: #fff;
  background-color: #e53d1c;
  }
.label-danger.label-circle {
  color: #ea644a;
  background: none;
  border: 1px solid #ea644a;
  }
.nav-primary > li > a > .label,
.btn .label {
  position: relative;
  top: -1px;
  }
.btn-primary .label,
.btn-success .label,
.btn-info .label,
.btn-danger .label,
.btn-warning .label {
  background-color: rgba(0, 0, 0, .2);
  }
.list-group-item.active > .label,
.nav-primary > .active > a > .label,
.nav-pills > .active > a > .label {
  color: #145ccd;
  background-color: #fff;
  }
.nav > li > a > .label {
  margin-left: 3px;
  }
.breadcrumb {
  padding: 8px 15px;
  margin-bottom: 20px;
  list-style: none;
  border-radius: 4px;
  }
.breadcrumb > li {
  display: inline-block;
  }
.breadcrumb > li + li:before {
  padding: 0 5px;
  color: #ccc;
  content: "/\00a0";
  }
.breadcrumb > .active {
  color: #808080;
  }
@font-face {
  font-family: ZenIcon;
  font-style: normal;
  font-weight: normal;

  src: url('../fonts/zenicon.eot?v=2.2.0');
  src: url('../fonts/zenicon.eot?#iefix&v=2.2.0') format('embedded-opentype'), url('../fonts/zenicon.woff?v=2.2.0') format('woff'), url('../fonts/zenicon.ttf?v=2.2.0') format('truetype'), url('../fonts/zenicon.svg#regular?v=2.2.0') format('svg');
  }
.icon,
[class^="icon-"],
[class*=" icon-"] {
  font-family: ZenIcon;
  font-size: 14px;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  line-height: 1;
  text-transform: none;

  speak: none;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  }
.icon:before {
  display: inline-block;
  min-width: 14px;
  text-align: center;
  }
a .icon,
a [class^="icon-"],
a [class*=" icon-"] {
  display: inline;
  }
.icon-lg:before {
  font-size: 1.33333333em;
  vertical-align: -10%;
  }
.icon-2x {
  font-size: 28px;
  }
.icon-3x {
  font-size: 42px;
  }
.icon-4x {
  font-size: 56px;
  }
.icon-5x {
  font-size: 70px;
  }
.icon-spin {
  display: inline-block;
  -webkit-animation: spin 2s infinite linear;
       -o-animation: spin 2s infinite linear;
          animation: spin 2s infinite linear;
  }
a .icon-spin {
  display: inline-block;
  text-decoration: none;
  }
@-webkit-keyframes spin {
  0% {
    -webkit-transform: rotate(0deg);
            transform: rotate(0deg);
    }
  100% {
    -webkit-transform: rotate(359deg);
            transform: rotate(359deg);
    }
  }
@-o-keyframes spin {
  0% {
    -o-transform: rotate(0deg);
       transform: rotate(0deg);
    }
  100% {
    -o-transform: rotate(359deg);
       transform: rotate(359deg);
    }
  }
@keyframes spin {
  0% {
    -webkit-transform: rotate(0deg);
         -o-transform: rotate(0deg);
            transform: rotate(0deg);
    }
  100% {
    -webkit-transform: rotate(359deg);
         -o-transform: rotate(359deg);
            transform: rotate(359deg);
    }
  }
.icon-rotate-90:before {
  -webkit-transform: rotate(90deg);
      -ms-transform: rotate(90deg);
       -o-transform: rotate(90deg);
          transform: rotate(90deg);

  ilter: progid:DXImageTransform.Microsoft.BasicImage(rotation=1);
  }
.icon-rotate-180:before {
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=2);
  -webkit-transform: rotate(180deg);
      -ms-transform: rotate(180deg);
       -o-transform: rotate(180deg);
          transform: rotate(180deg);
  }
.icon-rotate-270:before {
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=3);
  -webkit-transform: rotate(270deg);
      -ms-transform: rotate(270deg);
       -o-transform: rotate(270deg);
          transform: rotate(270deg);
  }
.icon-flip-horizontal:before {
  -webkit-transform: scale(-1, 1);
      -ms-transform: scale(-1, 1);
       -o-transform: scale(-1, 1);
          transform: scale(-1, 1);
  }
.icon-flip-vertical:before {
  -webkit-transform: scale(1, -1);
      -ms-transform: scale(1, -1);
       -o-transform: scale(1, -1);
          transform: scale(1, -1);
  }
.icon-rotate-90:before,
.icon-rotate-180:before,
.icon-rotate-270:before,
.icon-flip-horizontal:before,
.icon-flip-vertical:before {
  display: inline-block;
  }
.icon-resize:before {
  content: '\e667';
  }
.icon-expand-full:before {
  content: '\e6a3';
  }
.icon-arrows-alt:before {
  content: '\e6a3';
  }
.icon-fullscreen:before {
  content: '\e6a3';
  }
.icon-collapse-full:before {
  content: '\e682';
  }
.icon-yinyang:before {
  content: '\e687';
  }
.icon-taiji:before {
  content: '\e687';
  }
.icon-window:before {
  content: '\e68e';
  }
.icon-window-alt:before {
  content: '\e68f';
  }
.icon-carousel:before {
  content: '\e6b0';
  }
.icon-spinner-snake:before {
  content: '\e97b';
  }
.icon-spinner-indicator:before {
  content: '\e97c';
  }
.icon-check-board:before {
  content: '\e9b8';
  }
.icon-bar-chart:before {
  content: '\f080';
  }
.icon-bar-chart-o:before {
  content: '\f080';
  }
.icon-github:before {
  content: '\f09b';
  }
.icon-dot-circle:before {
  content: '\f192';
  }
.icon-dot-circle-o:before {
  content: '\f192';
  }
.icon-cube-alt:before {
  content: '\f1b2';
  }
.icon-cubes:before {
  content: '\f1b3';
  }
.icon-file-pdf:before {
  content: '\f1c1';
  }
.icon-file-word:before {
  content: '\f1c2';
  }
.icon-file-excel:before {
  content: '\f1c3';
  }
.icon-file-powerpoint:before {
  content: '\f1c4';
  }
.icon-file-image:before {
  content: '\f1c5';
  }
.icon-file-photo:before {
  content: '\f1c5';
  }
.icon-file-picture:before {
  content: '\f1c5';
  }
.icon-file-archive:before {
  content: '\f1c6';
  }
.icon-file-zip:before {
  content: '\f1c6';
  }
.icon-file-audio:before {
  content: '\f1c7';
  }
.icon-file-sound:before {
  content: '\f1c7';
  }
.icon-file-movie:before {
  content: '\f1c8';
  }
.icon-file-video:before {
  content: '\f1c8';
  }
.icon-file-code:before {
  content: '\f1c9';
  }
.icon-circle-o-notch:before {
  content: '\f1ce';
  }
.icon-qq:before {
  content: '\f600';
  }
.icon-wechat:before {
  content: '\f1d7';
  }
.icon-weixin:before {
  content: '\f1d7';
  }
.icon-history:before {
  content: '\f1da';
  }
.icon-circle-thin:before {
  content: '\f1db';
  }
.icon-sliders:before {
  content: '\f1de';
  }
.icon-newspaper-o:before {
  content: '\f1ea';
  }
.icon-calculator:before {
  content: '\f1ec';
  }
.icon-paint-brush:before {
  content: '\f1fc';
  }
.icon-area-chart:before {
  content: '\f1fe';
  }
.icon-pie-chart:before {
  content: '\f200';
  }
.icon-line-chart:before {
  content: '\f201';
  }
.icon-toggle-off:before {
  content: '\f204';
  }
.icon-toggle-on:before {
  content: '\f205';
  }
.icon-diamond:before {
  content: '\f219';
  }
.icon-venus:before {
  content: '\f221';
  }
.icon-mars:before {
  content: '\f222';
  }
.icon-server:before {
  content: '\f233';
  }
.icon-music:before {
  content: '\e602';
  }
.icon-search:before {
  content: '\e603';
  }
.icon-envelope:before {
  content: '\e604';
  }
.icon-heart:before {
  content: '\e605';
  }
.icon-star:before {
  content: '\e606';
  }
.icon-star-empty:before {
  content: '\e607';
  }
.icon-user:before {
  content: '\e608';
  }
.icon-film:before {
  content: '\e609';
  }
.icon-th-large:before {
  content: '\e60a';
  }
.icon-th:before {
  content: '\e60b';
  }
.icon-th-list:before {
  content: '\e60c';
  }
.icon-ok:before {
  content: '\e60d';
  }
.icon-check:before {
  content: '\e60d';
  }
.icon-remove:before {
  content: '\d7';
  }
.icon-times:before {
  content: '\d7';
  }
.icon-zoom-in:before {
  content: '\e60f';
  }
.icon-zoom-out:before {
  content: '\e610';
  }
.icon-off:before {
  content: '\e611';
  }
.icon-cog:before {
  content: '\e613';
  }
.icon-trash:before {
  content: '\e614';
  }
.icon-home:before {
  content: '\e615';
  }
.icon-file-o:before {
  content: '\e616';
  }
.icon-file-alt:before {
  content: '\e616';
  }
.icon-time:before {
  content: '\e617';
  }
.icon-download-alt:before {
  content: '\e618';
  }
.icon-download:before {
  content: '\e619';
  }
.icon-upload:before {
  content: '\e61a';
  }
.icon-inbox:before {
  content: '\e61b';
  }
.icon-play-circle:before {
  content: '\e61c';
  }
.icon-repeat:before {
  content: '\e61d';
  }
.icon-refresh:before {
  content: '\e61e';
  }
.icon-list-alt:before {
  content: '\e61f';
  }
.icon-lock:before {
  content: '\e620';
  }
.icon-flag:before {
  content: '\e621';
  }
.icon-headphones:before {
  content: '\e622';
  }
.icon-volume-off:before {
  content: '\e623';
  }
.icon-volume-up:before {
  content: '\e625';
  }
.icon-qrcode:before {
  content: '\e626';
  }
.icon-barcode:before {
  content: '\e627';
  }
.icon-tag:before {
  content: '\e628';
  }
.icon-tags:before {
  content: '\e629';
  }
.icon-book:before {
  content: '\e62a';
  }
.icon-bookmark:before {
  content: '\e62b';
  }
.icon-print:before {
  content: '\e62c';
  }
.icon-camera:before {
  content: '\e62d';
  }
.icon-font:before {
  content: '\e62e';
  }
.icon-bold:before {
  content: '\e62f';
  }
.icon-align-justify:before {
  content: '\e636';
  }
.icon-list:before {
  content: '\e637';
  }
.icon-picture:before {
  content: '\e63b';
  }
.icon-pencil:before {
  content: '\e63c';
  }
.icon-map-marker:before {
  content: '\e63d';
  }
.icon-adjust:before {
  content: '\e63e';
  }
.icon-tint:before {
  content: '\e63f';
  }
.icon-edit:before {
  content: '\e640';
  }
.icon-share:before {
  content: '\e641';
  }
.icon-checked:before {
  content: '\e642';
  }
.icon-move:before {
  content: '\e643';
  }
.icon-arrows:before {
  content: '\e643';
  }
.icon-step-backward:before {
  content: '\e644';
  }
.icon-fast-backward:before {
  content: '\e645';
  }
.icon-backward:before {
  content: '\e646';
  }
.icon-play:before {
  content: '\e647';
  }
.icon-pause:before {
  content: '\e648';
  }
.icon-stop:before {
  content: '\e649';
  }
.icon-forward:before {
  content: '\e64a';
  }
.icon-fast-forward:before {
  content: '\e64b';
  }
.icon-step-forward:before {
  content: '\e64c';
  }
.icon-eject:before {
  content: '\e64d';
  }
.icon-chevron-left:before {
  content: '\e64e';
  }
.icon-chevron-right:before {
  content: '\e64f';
  }
.icon-plus-sign:before {
  content: '\e650';
  }
.icon-minus-sign:before {
  content: '\e651';
  }
.icon-remove-sign:before {
  content: '\e652';
  }
.icon-ok-sign:before {
  content: '\e653';
  }
.icon-check-circle:before {
  content: '\e653';
  }
.icon-question-sign:before {
  content: '\e654';
  }
.icon-info-sign:before {
  content: '\e655';
  }
.icon-remove-circle:before {
  content: '\e657';
  }
.icon-ok-circle:before {
  content: '\e658';
  }
.icon-check-circle-o:before {
  content: '\e658';
  }
.icon-ban-circle:before {
  content: '\e659';
  }
.icon-arrow-left:before {
  content: '\e65a';
  }
.icon-arrow-right:before {
  content: '\e65b';
  }
.icon-arrow-up:before {
  content: '\e65c';
  }
.icon-arrow-down:before {
  content: '\e65d';
  }
.icon-share-alt:before {
  content: '\e65e';
  }
.icon-resize-full:before {
  content: '\e65f';
  }
.icon-resize-small:before {
  content: '\e660';
  }
.icon-plus:before {
  content: '\e661';
  }
.icon-minus:before {
  content: '\e662';
  }
.icon-asterisk:before {
  content: '\e663';
  }
.icon-exclamation-sign:before {
  content: '\e664';
  }
.icon-gift:before {
  content: '\e665';
  }
.icon-leaf:before {
  content: '\e666';
  }
.icon-eye-open:before {
  content: '\e668';
  }
.icon-eye-close:before {
  content: '\e669';
  }
.icon-warning-sign:before {
  content: '\e66a';
  }
.icon-plane:before {
  content: '\e66b';
  }
.icon-calendar:before {
  content: '\e66c';
  }
.icon-random:before {
  content: '\e66d';
  }
.icon-comment:before {
  content: '\e66e';
  }
.icon-chevron-up:before {
  content: '\e670';
  }
.icon-chevron-down:before {
  content: '\e671';
  }
.icon-shopping-cart:before {
  content: '\e673';
  }
.icon-folder-close:before {
  content: '\e674';
  }
.icon-folder-open:before {
  content: '\e675';
  }
.icon-resize-v:before {
  content: '\e676';
  }
.icon-resize-h:before {
  content: '\e677';
  }
.icon-bar-chart-alt:before {
  content: '\e678';
  }
.icon-camera-retro:before {
  content: '\e679';
  }
.icon-key:before {
  content: '\e67a';
  }
.icon-cogs:before {
  content: '\e67b';
  }
.icon-comments:before {
  content: '\e67c';
  }
.icon-thumbs-o-up:before {
  content: '\e67d';
  }
.icon-thumbs-o-down:before {
  content: '\e67e';
  }
.icon-star-half:before {
  content: '\e67f';
  }
.icon-heart-empty:before {
  content: '\e680';
  }
.icon-signout:before {
  content: '\e681';
  }
.icon-pushpin:before {
  content: '\e683';
  }
.icon-external-link:before {
  content: '\e684';
  }
.icon-signin:before {
  content: '\e685';
  }
.icon-trophy:before {
  content: '\e686';
  }
.icon-upload-alt:before {
  content: '\e688';
  }
.icon-lemon:before {
  content: '\e689';
  }
.icon-phone:before {
  content: '\e68a';
  }
.icon-check-empty:before {
  content: '\e68b';
  }
.icon-bookmark-empty:before {
  content: '\e68c';
  }
.icon-phone-sign:before {
  content: '\e68d';
  }
.icon-credit:before {
  content: '\e690';
  }
.icon-rss:before {
  content: '\e691';
  }
.icon-hdd:before {
  content: '\e692';
  }
.icon-bullhorn:before {
  content: '\e693';
  }
.icon-bell:before {
  content: '\e694';
  }
.icon-certificate:before {
  content: '\e695';
  }
.icon-hand-right:before {
  content: '\e696';
  }
.icon-hand-left:before {
  content: '\e697';
  }
.icon-hand-up:before {
  content: '\e698';
  }
.icon-hand-down:before {
  content: '\e699';
  }
.icon-circle-arrow-left:before {
  content: '\e69a';
  }
.icon-circle-arrow-right:before {
  content: '\e69b';
  }
.icon-circle-arrow-up:before {
  content: '\e69c';
  }
.icon-circle-arrow-down:before {
  content: '\e69d';
  }
.icon-globe:before {
  content: '\e69e';
  }
.icon-wrench:before {
  content: '\e69f';
  }
.icon-tasks:before {
  content: '\e6a0';
  }
.icon-filter:before {
  content: '\e6a1';
  }
.icon-group:before {
  content: '\e6a4';
  }
.icon-link:before {
  content: '\e6a5';
  }
.icon-cloud:before {
  content: '\e6a6';
  }
.icon-beaker:before {
  content: '\e6a7';
  }
.icon-cut:before {
  content: '\e6a8';
  }
.icon-copy:before {
  content: '\e6a9';
  }
.icon-paper-clip:before {
  content: '\e6aa';
  }
.icon-save:before {
  content: '\e6ab';
  }
.icon-sign-blank:before {
  content: '\e6ac';
  }
.icon-bars:before {
  content: '\e6ad';
  }
.icon-reorder:before {
  content: '\e6ad';
  }
.icon-list-ul:before {
  content: '\e6ae';
  }
.icon-list-ol:before {
  content: '\e6af';
  }
.icon-table:before {
  content: '\e6b2';
  }
.icon-magic:before {
  content: '\e6b3';
  }
.icon-caret-down:before {
  content: '\e6b8';
  }
.icon-caret-up:before {
  content: '\e6b9';
  }
.icon-caret-left:before {
  content: '\e6ba';
  }
.icon-caret-right:before {
  content: '\e6bb';
  }
.icon-columns:before {
  content: '\e6bc';
  }
.icon-sort:before {
  content: '\e6bd';
  }
.icon-sort-down:before {
  content: '\e6be';
  }
.icon-sort-up:before {
  content: '\e6bf';
  }
.icon-envelope-alt:before {
  content: '\e6c0';
  }
.icon-undo:before {
  content: '\e6c1';
  }
.icon-dashboard:before {
  content: '\e6c3';
  }
.icon-comment-alt:before {
  content: '\e6c4';
  }
.icon-comments-alt:before {
  content: '\e6c5';
  }
.icon-bolt:before {
  content: '\e6c6';
  }
.icon-sitemap:before {
  content: '\e6c7';
  }
.icon-umbrella:before {
  content: '\e6c8';
  }
.icon-paste:before {
  content: '\e6c9';
  }
.icon-lightbulb:before {
  content: '\e6ca';
  }
.icon-exchange:before {
  content: '\e6cb';
  }
.icon-cloud-download:before {
  content: '\e6cc';
  }
.icon-cloud-upload:before {
  content: '\e6cd';
  }
.icon-bell-alt:before {
  content: '\e6d1';
  }
.icon-coffee:before {
  content: '\e6d2';
  }
.icon-file-text-o:before {
  content: '\e6d4';
  }
.icon-file-text-alt:before {
  content: '\e6d4';
  }
.icon-building:before {
  content: '\e6d5';
  }
.icon-double-angle-left:before {
  content: '\e6dc';
  }
.icon-double-angle-right:before {
  content: '\e6dd';
  }
.icon-double-angle-up:before {
  content: '\e6de';
  }
.icon-double-angle-down:before {
  content: '\e6df';
  }
.icon-angle-left:before {
  content: '\e6e0';
  }
.icon-angle-right:before {
  content: '\e6e1';
  }
.icon-angle-up:before {
  content: '\e6e2';
  }
.icon-angle-down:before {
  content: '\e6e3';
  }
.icon-desktop:before {
  content: '\e6e4';
  }
.icon-laptop:before {
  content: '\e6e5';
  }
.icon-tablet:before {
  content: '\e6e6';
  }
.icon-mobile:before {
  content: '\e6e7';
  }
.icon-circle-blank:before {
  content: '\e6e8';
  }
.icon-quote-left:before {
  content: '\e6e9';
  }
.icon-quote-right:before {
  content: '\e6ea';
  }
.icon-spinner:before {
  content: '\e6eb';
  }
.icon-circle:before {
  content: '\e6ec';
  }
.icon-reply:before {
  content: '\e6ed';
  }
.icon-folder-close-alt:before {
  content: '\e6ef';
  }
.icon-folder-open-alt:before {
  content: '\e6f0';
  }
.icon-expand-alt:before {
  content: '\e6f1';
  }
.icon-collapse-alt:before {
  content: '\e6f2';
  }
.icon-smile:before {
  content: '\e6f3';
  }
.icon-frown:before {
  content: '\e6f4';
  }
.icon-meh:before {
  content: '\e6f5';
  }
.icon-gamepad:before {
  content: '\e6f6';
  }
.icon-keyboard:before {
  content: '\e6f7';
  }
.icon-flag-alt:before {
  content: '\e6f8';
  }
.icon-flag-checkered:before {
  content: '\e6f9';
  }
.icon-terminal:before {
  content: '\e6fa';
  }
.icon-code:before {
  content: '\e6fb';
  }
.icon-reply-all:before {
  content: '\e6fc';
  }
.icon-star-half-full:before {
  content: '\e6fd';
  }
.icon-location-arrow:before {
  content: '\e6fe';
  }
.icon-crop:before {
  content: '\e6ff';
  }
.icon-code-fork:before {
  content: '\e700';
  }
.icon-unlink:before {
  content: '\e701';
  }
.icon-question:before {
  content: '\e702';
  }
.icon-info:before {
  content: '\e703';
  }
.icon-shield:before {
  content: '\e70b';
  }
.icon-calendar-empty:before {
  content: '\e70c';
  }
.icon-rocket:before {
  content: '\e70e';
  }
.icon-chevron-sign-left:before {
  content: '\e70f';
  }
.icon-chevron-sign-right:before {
  content: '\e710';
  }
.icon-chevron-sign-up:before {
  content: '\e711';
  }
.icon-chevron-sign-down:before {
  content: '\e712';
  }
.icon-html5:before {
  content: '\e713';
  }
.icon-anchor:before {
  content: '\e714';
  }
.icon-unlock-alt:before {
  content: '\e715';
  }
.icon-bullseye:before {
  content: '\e716';
  }
.icon-ellipsis-h:before {
  content: '\e717';
  }
.icon-ellipsis-v:before {
  content: '\e718';
  }
.icon-rss-sign:before {
  content: '\e719';
  }
.icon-play-sign:before {
  content: '\e71a';
  }
.icon-minus-sign-alt:before {
  content: '\e71c';
  }
.icon-check-minus:before {
  content: '\e71d';
  }
.icon-level-up:before {
  content: '\e71e';
  }
.icon-level-down:before {
  content: '\e71f';
  }
.icon-check-sign:before {
  content: '\e720';
  }
.icon-edit-sign:before {
  content: '\e721';
  }
.icon-external-link-sign:before {
  content: '\e722';
  }
.icon-share-sign:before {
  content: '\e723';
  }
.icon-compass:before {
  content: '\e724';
  }
.icon-collapse:before {
  content: '\e725';
  }
.icon-collapse-top:before {
  content: '\e726';
  }
.icon-expand:before {
  content: '\e727';
  }
.icon-dollar:before {
  content: '\e728';
  }
.icon-yen:before {
  content: '\e729';
  }
.icon-file:before {
  content: '\e72b';
  }
.icon-file-text:before {
  content: '\e72c';
  }
.icon-sort-by-alphabet:before {
  content: '\e72d';
  }
.icon-sort-by-alphabet-alt:before {
  content: '\e72e';
  }
.icon-sort-by-attributes:before {
  content: '\e72f';
  }
.icon-sort-by-attributes-alt:before {
  content: '\e730';
  }
.icon-sort-by-order:before {
  content: '\e731';
  }
.icon-sort-by-order-alt:before {
  content: '\e732';
  }
.icon-thumbs-up:before {
  content: '\e733';
  }
.icon-thumbs-down:before {
  content: '\e734';
  }
.icon-long-arrow-down:before {
  content: '\e736';
  }
.icon-long-arrow-up:before {
  content: '\e737';
  }
.icon-long-arrow-left:before {
  content: '\e738';
  }
.icon-long-arrow-right:before {
  content: '\e739';
  }
.icon-apple:before {
  content: '\e73a';
  }
.icon-windows:before {
  content: '\e73b';
  }
.icon-android:before {
  content: '\e73c';
  }
.icon-linux:before {
  content: '\e73d';
  }
.icon-sun:before {
  content: '\e742';
  }
.icon-moon:before {
  content: '\e743';
  }
.icon-archive:before {
  content: '\e744';
  }
.icon-bug:before {
  content: '\e745';
  }
.icon-zhifubao:before,
.icon-alipay:before {
  content: '\e901';
  }
.icon-zhifubao-square:before,
.icon-alipay-square:before {
  content: '\e900';
  }
.icon-taobao:before {
  content: '\e902';
  }
.icon-weibo:before {
  content: '\e746';
  }
.icon-renren:before {
  content: '\e747';
  }
.icon-chrome:before {
  content: '\e76c';
  }
.icon-firefox:before {
  content: '\e76d';
  }
.icon-ie:before {
  content: '\e76e';
  }
.icon-opera:before {
  content: '\e76f';
  }
.icon-safari:before {
  content: '\e770';
  }
.icon-node:before {
  content: '\e76a';
  }
.icon-layout:before {
  content: '\e768';
  }
.icon-usecase:before {
  content: '\e74a';
  }
.icon-stack:before {
  content: '\e769';
  }
.icon-branch:before {
  content: '\e74b';
  }
.icon-chat:before {
  content: '\e74c';
  }
.icon-chat-line:before {
  content: '\e74f';
  }
.icon-comment-line:before {
  content: '\e74f';
  }
.icon-chat-dot:before {
  content: '\e750';
  }
.icon-cube:before {
  content: '\e751';
  }
.icon-align-left:before {
  content: '\e633';
  }
fieldset {
  padding: 0;
  margin: 0;
  border: 0;
  }
legend {
  display: block;
  width: 100%;
  padding: 0;
  margin-bottom: 20px;
  font-size: 19.5px;
  line-height: inherit;
  color: #333;
  border: 0;
  border-bottom: 1px solid #e5e5e5;
  }
label {
  display: inline-block;
  margin-bottom: 5px;
  font-weight: bold;
  }
input[type="search"] {
  -webkit-box-sizing: border-box;
     -moz-box-sizing: border-box;
          box-sizing: border-box;
  }
input[type="radio"],
input[type="checkbox"] {
  margin: 5px 0 0;
  margin-top: 0 \9;
  /* IE8-9 */
  line-height: normal;
  }
input[type="file"] {
  display: block;
  }
select[multiple],
select[size] {
  height: auto;
  }
select:-moz-focusring {
  color: transparent;
  text-shadow: 0 0 0 #000;
  }
select optgroup {
  font-family: inherit;
  font-size: inherit;
  font-style: inherit;
  }
input[type="file"]:focus,
input[type="radio"]:focus,
input[type="checkbox"]:focus {
  outline: thin dotted #333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
  }
input[type="number"]::-webkit-outer-spin-button,
input[type="number"]::-webkit-inner-spin-button {
  height: auto;
  }
.form-control::-webkit-input-placeholder {
  color: #808080;
  }
.form-control::-moz-placeholder {
  color: #808080;
  }
.form-control:-ms-input-placeholder {
  color: #808080;
  }
.form-control::placeholder {
  color: #808080;
  }
.form-control {
  display: block;
  width: 100%;
  height: 32px;
  padding: 5px 8px;
  font-size: 13px;
  line-height: 1.53846154;
  color: #222;
  vertical-align: middle;
  background-color: #fff;
  border: 1px solid #ccc;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075);
          box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075);
  -webkit-transition: border-color ease-in-out .15s, -webkit-box-shadow ease-in-out .15s;
       -o-transition: border-color ease-in-out .15s, box-shadow ease-in-out .15s;
          transition: border-color ease-in-out .15s, -webkit-box-shadow ease-in-out .15s;
          transition: border-color ease-in-out .15s, box-shadow ease-in-out .15s;
          transition: border-color ease-in-out .15s, box-shadow ease-in-out .15s, -webkit-box-shadow ease-in-out .15s;
  }
.form-control:focus {
  border-color: #145ccd;
  outline: 0;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075), 0 0 8px rgba(20, 92, 205, .6);
          box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075), 0 0 8px rgba(20, 92, 205, .6);
  }
.form-control[disabled],
.form-control[readonly],
fieldset[disabled] .form-control {
  cursor: not-allowed;
  background-color: #e5e5e5;
  }
.form-control[readonly] {
  cursor: default;
  }
textarea.form-control {
  height: auto;
  }
.form-group {
  margin-bottom: 15px;
  }
.radio,
.checkbox {
  position: relative;
  display: block;
  margin-top: 10px;
  margin-bottom: 10px;
  }
.radio label,
.checkbox label {
  min-height: 20px;
  padding-left: 20px;
  margin-bottom: 0;
  font-weight: normal;
  cursor: pointer;
  }
.radio input[type="radio"],
.radio-inline input[type="radio"],
.checkbox input[type="checkbox"],
.checkbox-inline input[type="checkbox"] {
  position: absolute;
  margin-top: 3px;
  margin-top: 4px \9;
  margin-left: -20px;
  }
.radio + .radio,
.checkbox + .checkbox {
  margin-top: -5px;
  }
.radio-inline,
.checkbox-inline {
  position: relative;
  display: inline-block;
  padding-left: 20px;
  margin-bottom: 0;
  font-weight: normal;
  vertical-align: middle;
  cursor: pointer;
  }
.radio-inline + .radio-inline,
.checkbox-inline + .checkbox-inline {
  margin-top: 0;
  margin-left: 10px;
  }
input[type="radio"][disabled],
input[type="checkbox"][disabled],
input[type="radio"].disabled,
input[type="checkbox"].disabled,
fieldset[disabled] input[type="radio"],
fieldset[disabled] input[type="checkbox"] {
  cursor: not-allowed;
  }
.radio-inline.disabled,
.checkbox-inline.disabled,
fieldset[disabled] .radio-inline,
fieldset[disabled] .checkbox-inline {
  cursor: not-allowed;
  }
.radio.disabled label,
.checkbox.disabled label,
fieldset[disabled] .radio label,
fieldset[disabled] .checkbox label {
  cursor: not-allowed;
  }
.input-sm {
  height: 24px;
  padding: 2px 8px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
  }
select.input-sm {
  height: 24px;
  line-height: 24px;
  }
textarea.input-sm {
  height: auto;
  }
.input-lg {
  height: 43px;
  padding: 10px 16px;
  font-size: 17px;
  line-height: 1.25;
  border-radius: 6px;
  }
select.input-lg {
  height: 43px;
  line-height: 43px;
  }
textarea.input-lg {
  height: auto;
  }
.has-warning .help-block,
.has-warning > label {
  color: #f1a325;
  }
.has-warning .form-control {
  border-color: #f1a325;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075);
          box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075);
  }
.has-warning .form-control:focus {
  border-color: #d5890e;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075), 0 0 6px #f7cb85;
          box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075), 0 0 6px #f7cb85;
  }
.has-warning .input-group-addon {
  color: #f1a325;
  background-color: #fff0d5;
  border-color: #f1a325;
  }
.has-error .help-block,
.has-error > label {
  color: #ea644a;
  }
.has-error .form-control {
  border-color: #ea644a;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075);
          box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075);
  }
.has-error .form-control:focus {
  border-color: #e53d1c;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075), 0 0 6px #f5b2a5;
          box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075), 0 0 6px #f5b2a5;
  }
.has-error .input-group-addon {
  color: #ea644a;
  background-color: #ffe5e0;
  border-color: #ea644a;
  }
.has-success .help-block,
.has-success > label {
  color: #38b03f;
  }
.has-success .form-control {
  border-color: #38b03f;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075);
          box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075);
  }
.has-success .form-control:focus {
  border-color: #2c8931;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075), 0 0 6px #79d57f;
          box-shadow: inset 0 1px 1px rgba(0, 0, 0, .075), 0 0 6px #79d57f;
  }
.has-success .input-group-addon {
  color: #38b03f;
  background-color: #ddf4df;
  border-color: #38b03f;
  }
.form-control-static {
  min-height: 33px;
  padding-top: 6px;
  padding-bottom: 6px;
  margin-bottom: 0;
  }
.help-block {
  display: block;
  margin-top: 5px;
  margin-bottom: 10px;
  color: #757575;
  }
@media (min-width: 768px) {
  .form-inline .form-group {
    display: inline-block;
    margin-bottom: 0;
    vertical-align: middle;
    }
  .form-inline .form-control {
    display: inline-block;
    width: auto;
    vertical-align: middle;
    }
  .form-inline .radio,
  .form-inline .checkbox {
    display: inline-block;
    padding-left: 0;
    margin-top: 0;
    margin-bottom: 0;
    }
  .form-inline .radio input[type="radio"],
  .form-inline .checkbox input[type="checkbox"] {
    float: none;
    margin-left: 0;
    }
  }
.form-horizontal .form-group > label,
.form-horizontal .radio,
.form-horizontal .checkbox,
.form-horizontal .radio-inline,
.form-horizontal .checkbox-inline {
  padding-top: 6px;
  margin-top: 0;
  margin-bottom: 0;
  }
.form-horizontal .form-group {
  margin-right: -10px;
  margin-left: -10px;
  }
@media (min-width: 768px) {
  .form-horizontal .form-group > label {
    text-align: right;
    }
  }
.required {
  position: relative;
  }
.required:after {
  position: absolute;
  top: 0;
  right: -10px;
  display: inline-block;
  font-size: 17px;
  color: #ea644a;
  content: '*';
  }
.form-horizontal .required:after {
  top: 5px;
  right: -1px;
  }
.form-condensed .form-group {
  margin-bottom: 10px;
  }
.form-condensed .form-control {
  height: 24px;
  padding: 2px 8px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
  }
select.form-condensed .form-control {
  height: 24px;
  line-height: 24px;
  }
textarea.form-condensed .form-control {
  height: auto;
  }
.form-condensed textarea.form-control {
  height: auto;
  }
.form-condensed .btn {
  padding: 2px 8px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 4px;
  }
.form-condensed .input-group > .form-control,
.form-condensed .input-group > .input-group-addon,
.form-condensed .input-group > .input-group-btn > .btn {
  padding: 2px 8px;
  font-size: 12px;
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
  }
.form-condensed.form-horizontal .form-group > label,
.form-condensed.form-horizontal .radio,
.form-condensed.form-horizontal .checkbox,
.form-condensed.form-horizontal .radio-inline,
.form-condensed.form-horizontal .checkbox-inline {
  padding-top: 1px;
  }
.close {
  float: right;
  font-size: 19.5px;
  font-weight: bold;
  line-height: 1;
  color: #000;
  text-shadow: 0 1px 0 #fff;
  filter: alpha(opacity=20);
  opacity: .2;
  }
.close:hover,
.close:focus {
  color: #000;
  text-decoration: none;
  cursor: pointer;
  filter: alpha(opacity=50);
  opacity: .5;
  }
button.close {
  -webkit-appearance: none;
  padding: 0;
  cursor: pointer;
  background: transparent;
  border: 0;
  }
@media (min-width: 768px) {
  ::-webkit-scrollbar {
    width: 10px;
    height: 10px;
    }
  ::-webkit-scrollbar-button {
    width: 0;
    height: 0;
    }
  ::-webkit-scrollbar-button:start:decrement,
  ::-webkit-scrollbar-button:end:increment {
    display: block;
    }
  ::-webkit-scrollbar-button:vertical:start:increment,
  ::-webkit-scrollbar-button:vertical:end:decrement {
    display: none;
    }
  ::-webkit-scrollbar-track:vertical,
  ::-webkit-scrollbar-track:horizontal,
  ::-webkit-scrollbar-thumb:vertical,
  ::-webkit-scrollbar-thumb:horizontal,
  ::-webkit-scrollbar-track:vertical,
  ::-webkit-scrollbar-track:horizontal,
  ::-webkit-scrollbar-thumb:vertical,
  ::-webkit-scrollbar-thumb:horizontal {
    border-color: transparent;
    border-style: solid;
    }
  ::-webkit-scrollbar-track:vertical::-webkit-scrollbar-track:horizontal {
    background-color: #fff;
    -webkit-background-clip: padding-box;
            background-clip: padding-box;
    }
  ::-webkit-scrollbar-thumb {
    min-height: 28px;
    padding-top: 100;
    background-color: rgba(0, 0, 0, .2);
    -webkit-background-clip: padding-box;
            background-clip: padding-box;
    border-radius: 5px;
    -webkit-box-shadow: inset 1px 1px 0 rgba(0, 0, 0, .1), inset 0 -1px 0 rgba(0, 0, 0, .07);
    }
  ::-webkit-scrollbar-thumb:hover {
    background-color: rgba(0, 0, 0, .4);
    -webkit-box-shadow: inset 1px 1px 1px rgba(0, 0, 0, .25);
    }
  ::-webkit-scrollbar-thumb:active {
    background-color: rgba(0, 0, 0, .5);
    -webkit-box-shadow: inset 1px 1px 3px rgba(0, 0, 0, .35);
    }
  ::-webkit-scrollbar-track:vertical,
  ::-webkit-scrollbar-track:horizontal,
  ::-webkit-scrollbar-thumb:vertical,
  ::-webkit-scrollbar-thumb:horizontal {
    border-width: 0;
    }
  ::-webkit-scrollbar-track:hover {
    background-color: rgba(0, 0, 0, .05);
    -webkit-box-shadow: inset 1px 0 0 rgba(0, 0, 0, .1);
    }
  ::-webkit-scrollbar-track:active {
    background-color: rgba(0, 0, 0, .05);
    -webkit-box-shadow: inset 1px 0 0 rgba(0, 0, 0, .14), inset -1px -1px 0 rgba(0, 0, 0, .07);
    }
  .scrollbar-hover::-webkit-scrollbar,
  .scrollbar-hover::-webkit-scrollbar-button,
  .scrollbar-hover::-webkit-scrollbar-track,
  .scrollbar-hover::-webkit-scrollbar-thumb {
    visibility: hidden;
    }
  .scrollbar-hover:hover::-webkit-scrollbar,
  .scrollbar-hover:hover::-webkit-scrollbar-button,
  .scrollbar-hover:hover::-webkit-scrollbar-track,
  .scrollbar-hover:hover::-webkit-scrollbar-thumb {
    visibility: visible;
    }
  }
table {
  max-width: 100%;
  background-color: transparent;
  }
caption {
  padding-top: 8px;
  padding-bottom: 8px;
  color: #808080;
  text-align: left;
  }
th {
  text-align: left;
  }
.table {
  width: 100%;
  margin-bottom: 20px;
  }
.table th,
.table td {
  padding: 8px;
  line-height: 1.53846154;
  vertical-align: top;
  border-bottom: 1px solid #ddd;
  -webkit-transition: background .2s cubic-bezier(.175, .885, .32, 1);
       -o-transition: background .2s cubic-bezier(.175, .885, .32, 1);
          transition: background .2s cubic-bezier(.175, .885, .32, 1);
  }
.table > thead > tr > th {
  vertical-align: bottom;
  background-color: #f1f1f1;
  border-bottom: 1px solid #ddd;
  }
.table > tbody + tbody {
  border-top: 2px solid #ddd;
  }
.table-fixed {
  table-layout: fixed;
  }
.table-fixed th,
.table-fixed td {
  overflow: hidden;
  white-space: nowrap;
  }
.table-fixed tfoot > tr > th,
.table-fixed tfoot > tr > td,
.table-fixed .nofixed,
.table-fixed .nofixed {
  overflow: visible;
  }
.table-borderless thead > tr > th,
.table-borderless th,
.table-borderless td {
  border: none;
  }
.table-auto {
  width: auto;
  max-width: 100%;
  }
.table-condensed th,
.table-condensed td {
  padding: 5px;
  }
.table-bordered {
  border: 1px solid #ddd;
  }
.table-bordered th,
.table-bordered td {
  border: 1px solid #ddd;
  }
.table-striped > tbody > tr:nth-child(odd) > td,
.table-striped > tbody > tr:nth-child(odd) > th {
  background-color: #f9f9f9;
  }
.table-hover > tbody > tr:hover > td,
.table-hover > tbody > tr:hover > th {
  background-color: #ebf2f9;
  }
table col[class*="col-"] {
  display: table-column;
  float: none;
  }
table td[class*="col-"],
table th[class*="col-"] {
  display: table-cell;
  float: none;
  }
.table tr > td.active,
.table tr > th.active,
.table tr.active > td,
.table tr.active > th {
  background-color: #ffe7bc;
  }
.table > thead > tr > td.success,
.table > tbody > tr > td.success,
.table > tfoot > tr > td.success,
.table > thead > tr > th.success,
.table > tbody > tr > th.success,
.table > tfoot > tr > th.success,
.table > thead > tr.success > td,
.table > tbody > tr.success > td,
.table > tfoot > tr.success > td,
.table > thead > tr.success > th,
.table > tbody > tr.success > th,
.table > tfoot > tr.success > th {
  background-color: #ddf4df;
  border-color: #bae8b6;
  }
.table-hover > tbody > tr > td.success:hover,
.table-hover > tbody > tr > th.success:hover,
.table-hover > tbody > tr.success:hover > td,
.table-hover > tbody > tr.success:hover > th {
  background-color: #caeecd;
  border-color: #a8e1a3;
  }
.table > thead > tr > td.danger,
.table > tbody > tr > td.danger,
.table > tfoot > tr > td.danger,
.table > thead > tr > th.danger,
.table > tbody > tr > th.danger,
.table > tfoot > tr > th.danger,
.table > thead > tr.danger > td,
.table > tbody > tr.danger > td,
.table > tfoot > tr.danger > td,
.table > thead > tr.danger > th,
.table > tbody > tr.danger > th,
.table > tfoot > tr.danger > th {
  background-color: #ffe5e0;
  border-color: #ffc6c7;
  }
.table-hover > tbody > tr > td.danger:hover,
.table-hover > tbody > tr > th.danger:hover,
.table-hover > tbody > tr.danger:hover > td,
.table-hover > tbody > tr.danger:hover > th {
  background-color: #ffd0c6;
  border-color: #ffadad;
  }
.table > thead > tr > td.warning,
.table > tbody > tr > td.warning,
.table > tfoot > tr > td.warning,
.table > thead > tr > th.warning,
.table > tbody > tr > th.warning,
.table > tfoot > tr > th.warning,
.table > thead > tr.warning > td,
.table > tbody > tr.warning > td,
.table > tfoot > tr.warning > td,
.table > thead > tr.warning > th,
.table > tbody > tr.warning > th,
.table > tfoot > tr.warning > th {
  background-color: #fff0d5;
  border-color: #ffdcbc;
  }
.table-hover > tbody > tr > td.warning:hover,
.table-hover > tbody > tr > th.warning:hover,
.table-hover > tbody > tr.warning:hover > td,
.table-hover > tbody > tr.warning:hover > th {
  background-color: #ffe7bc;
  border-color: #ffcea2;
  }
.table-responsive {
  min-height: .01%;
  overflow-x: auto;
  }
@media screen and (max-width: 767px) {
  .table-responsive {
    width: 100%;
    margin-bottom: 15px;
    overflow-y: hidden;
    -ms-overflow-style: -ms-autohiding-scrollbar;
    border: 1px solid #ddd;
    }
  .table-responsive > .table {
    margin-bottom: 0;
    }
  .table-responsive > .table > thead > tr > th,
  .table-responsive > .table > tbody > tr > th,
  .table-responsive > .table > tfoot > tr > th,
  .table-responsive > .table > thead > tr > td,
  .table-responsive > .table > tbody > tr > td,
  .table-responsive > .table > tfoot > tr > td {
    white-space: nowrap;
    }
  .table-responsive > .table-bordered {
    border: 0;
    }
  .table-responsive > .table-bordered th {
    border-top: none;
    }
  .table-responsive > .table-bordered > thead > tr > th:first-child,
  .table-responsive > .table-bordered > tbody > tr > th:first-child,
  .table-responsive > .table-bordered > tfoot > tr > th:first-child,
  .table-responsive > .table-bordered > thead > tr > td:first-child,
  .table-responsive > .table-bordered > tbody > tr > td:first-child,
  .table-responsive > .table-bordered > tfoot > tr > td:first-child {
    border-left: 0;
    }
  .table-responsive > .table-bordered > thead > tr > th:last-child,
  .table-responsive > .table-bordered > tbody > tr > th:last-child,
  .table-responsive > .table-bordered > tfoot > tr > th:last-child,
  .table-responsive > .table-bordered > thead > tr > td:last-child,
  .table-responsive > .table-bordered > tbody > tr > td:last-child,
  .table-responsive > .table-bordered > tfoot > tr > td:last-child {
    border-right: 0;
    }
  .table-responsive > .table-bordered > tbody > tr:last-child > th,
  .table-responsive > .table-bordered > tfoot > tr:last-child > th,
  .table-responsive > .table-bordered > tbody > tr:last-child > td,
  .table-responsive > .table-bordered > tfoot > tr:last-child > td {
    border-bottom: 0;
    }
  }
.list-group {
  padding-left: 0;
  margin-bottom: 20px;
  }
.list-group-item {
  position: relative;
  display: block;
  padding: 10px 15px;
  margin-bottom: -1px;
  background-color: #fff;
  border: 1px solid #ddd;
  }
.list-group-item:first-child {
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
  }
.list-group-item:last-child {
  margin-bottom: 0;
  border-bottom-right-radius: 4px;
  border-bottom-left-radius: 4px;
  }
.list-group-item > .label-badge {
  float: right;
  }
.list-group-item > .label-badge + .label-badge {
  margin-right: 5px;
  }
a.list-group-item {
  color: #555;
  }
a.list-group-item .list-group-item-heading {
  color: #333;
  }
a.list-group-item:hover,
a.list-group-item:focus {
  color: #353535;
  text-decoration: none;
  background-color: #ebf2f9;
  }
.list-group-item.active,
.list-group-item.active:hover,
.list-group-item.active:focus {
  z-index: 2;
  color: #fff;
  background-color: #3280fc;
  border-color: #3280fc;
  }
.list-group-item.active .list-group-item-heading,
.list-group-item.active:hover .list-group-item-heading,
.list-group-item.active:focus .list-group-item-heading {
  color: inherit;
  }
.list-group-item.active .list-group-item-text,
.list-group-item.active:hover .list-group-item-text,
.list-group-item.active:focus .list-group-item-text {
  color: #e6e6e6;
  }
.list-group-item-heading {
  margin-top: 0;
  margin-bottom: 5px;
  color: #333;
  }
.list-group-item-text {
  margin-bottom: 0;
  line-height: 1.3;
  }
.panel {
  margin-bottom: 20px;
  background-color: #fff;
  border: 1px solid transparent;
  border-color: #ddd;
  border-radius: 4px;
  -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, .05);
          box-shadow: 0 1px 1px rgba(0, 0, 0, .05);
  }
.panel > .panel-heading {
  color: #333;
  background-color: #f5f5f5;
  border-color: #ddd;
  }
.panel > .panel-heading + .panel-collapse .panel-body {
  border-top-color: #ddd;
  }
.panel > .panel-footer + .panel-collapse .panel-body {
  border-bottom-color: #ddd;
  }
.panel-body {
  padding: 15px;
  }
.panel > .table {
  margin-bottom: 0;
  }
.panel > .panel-body + .table {
  border-top: 1px solid #ddd;
  }
.panel-heading {
  padding: 8px 15px;
  border-bottom: 1px solid transparent;
  border-top-left-radius: 3px;
  border-top-right-radius: 3px;
  }
.panel-title {
  margin-top: 0;
  margin-bottom: 0;
  font-size: 15px;
  }
.panel-title > a {
  color: inherit;
  }
.panel-footer {
  padding: 10px 15px;
  background-color: #f5f5f5;
  border-top: 1px solid #ddd;
  border-bottom-right-radius: 3px;
  border-bottom-left-radius: 3px;
  }
.panel-primary {
  border-color: #3280fc;
  }
.panel-primary > .panel-heading {
  color: #fff;
  background-color: #3280fc;
  border-color: #3280fc;
  }
.panel-primary > .panel-heading + .panel-collapse .panel-body {
  border-top-color: #3280fc;
  }
.panel-primary > .panel-footer + .panel-collapse .panel-body {
  border-bottom-color: #3280fc;
  }
.panel-success {
  border-color: #bae8b6;
  }
.panel-success > .panel-heading {
  color: #38b03f;
  background-color: #ddf4df;
  border-color: #bae8b6;
  }
.panel-success > .panel-heading + .panel-collapse .panel-body {
  border-top-color: #bae8b6;
  }
.panel-success > .panel-footer + .panel-collapse .panel-body {
  border-bottom-color: #bae8b6;
  }
.panel-warning {
  border-color: #ffdcbc;
  }
.panel-warning > .panel-heading {
  color: #f1a325;
  background-color: #fff0d5;
  border-color: #ffdcbc;
  }
.panel-warning > .panel-heading + .panel-collapse .panel-body {
  border-top-color: #ffdcbc;
  }
.panel-warning > .panel-footer + .panel-collapse .panel-body {
  border-bottom-color: #ffdcbc;
  }
.panel-danger {
  border-color: #ffc6c7;
  }
.panel-danger > .panel-heading {
  color: #ea644a;
  background-color: #ffe5e0;
  border-color: #ffc6c7;
  }
.panel-danger > .panel-heading + .panel-collapse .panel-body {
  border-top-color: #ffc6c7;
  }
.panel-danger > .panel-footer + .panel-collapse .panel-body {
  border-bottom-color: #ffc6c7;
  }
.panel-info {
  border-color: #a2e4de;
  }
.panel-info > .panel-heading {
  color: #03b8cf;
  background-color: #ddf3f5;
  border-color: #a2e4de;
  }
.panel-info > .panel-heading + .panel-collapse .panel-body {
  border-top-color: #a2e4de;
  }
.panel-info > .panel-footer + .panel-collapse .panel-body {
  border-bottom-color: #a2e4de;
  }
.panel-group {
  margin-bottom: 20px;
  }
.panel-group .panel {
  margin-bottom: 0;
  border-radius: 4px;
  }
.panel-group .panel + .panel {
  margin-top: 5px;
  }
.panel-group .panel-heading {
  border-bottom: 0;
  }
.panel-group .panel-heading + .panel-collapse > .panel-body,
.panel-group .panel-heading + .panel-collapse > .list-group {
  border-top: 1px solid #ddd;
  }
.panel-group .panel-footer {
  border-top: 0;
  }
.panel-group .panel-footer + .panel-collapse .panel-body {
  border-bottom: 1px solid #ddd;
  }
.panel > .list-group,
.panel > .panel-collapse > .list-group {
  margin-bottom: 0;
  }
.panel > .list-group .list-group-item,
.panel > .panel-collapse > .list-group .list-group-item {
  border-width: 1px 0;
  border-radius: 0;
  }
.panel > .list-group:first-child .list-group-item:first-child,
.panel > .panel-collapse > .list-group:first-child .list-group-item:first-child {
  border-top: 0;
  border-top-left-radius: 3px;
  border-top-right-radius: 3px;
  }
.panel > .list-group:last-child .list-group-item:last-child,
.panel > .panel-collapse > .list-group:last-child .list-group-item:last-child {
  border-bottom: 0;
  border-bottom-right-radius: 3px;
  border-bottom-left-radius: 3px;
  }
.panel > .panel-heading + .panel-collapse > .list-group .list-group-item:first-child {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  }
.panel-heading + .list-group .list-group-item:first-child {
  border-top-width: 0;
  }
.list-group + .panel-footer {
  border-top-width: 0;
  }
.alert {
  padding: 15px;
  margin-bottom: 20px;
  color: #282828;
  background-color: #f1f1f1;
  border-radius: 3px;
  -webkit-transition: all .4s cubic-bezier(.175, .885, .32, 1);
       -o-transition: all .4s cubic-bezier(.175, .885, .32, 1);
          transition: all .4s cubic-bezier(.175, .885, .32, 1);
  }
.alert hr {
  border-top-color: #e4e4e4;
  }
.alert .alert-link {
  color: #161616;
  }
.alert h4 {
  margin-top: 0;
  color: inherit;
  }
.alert hr {
  margin: 10px 0;
  }
.alert p,
.alert ul {
  margin-bottom: 0;
  }
.alert p + p {
  margin-top: 5px;
  }
.alert-link {
  font-weight: bold;
  }
.alert > [class*="icon-"] {
  float: left;
  margin-top: -5px;
  font-size: 42px;
  opacity: .6;
  -webkit-transition: opacity .2s cubic-bezier(.175, .885, .32, 1);
       -o-transition: opacity .2s cubic-bezier(.175, .885, .32, 1);
          transition: opacity .2s cubic-bezier(.175, .885, .32, 1);
  }
.alert > [class*="icon-"] + .content {
  min-height: 30px;
  margin-left: 64px;
  }
.alert.with-icon {
  display: table;
  width: 100%;
  }
.alert.with-icon > [class*="icon-"],
.alert.with-icon > [class*="icon-"] + .content {
  display: table-cell;
  float: none;
  min-height: 0;
  margin: 0;
  vertical-align: middle;
  }
.alert.with-icon > [class*="icon-"] {
  width: 48px;
  text-align: center;
  }
.alert.with-icon > [class*="icon-"] + .content {
  padding-left: 1em;
  }
.alert-block {
  margin: 0;
  border-radius: 0;
  }
.alert-dismissable {
  padding-right: 35px;
  }
.alert-dismissable .close {
  position: relative;
  top: -6px;
  right: -21px;
  color: inherit;
  }
.alert-primary {
  color: #282828;
  background-color: #ebf2f9;
  }
.alert-primary hr {
  border-top-color: #d0e0f1;
  }
.alert-primary .alert-link {
  color: #161616;
  }
.alert-success {
  color: #329d38;
  background-color: #ddf4df;
  }
.alert-success hr {
  border-top-color: #bae8b6;
  }
.alert-success .alert-link {
  color: #29822e;
  }
.alert-info {
  color: #03a2b6;
  background-color: #ddf3f5;
  }
.alert-info hr {
  border-top-color: #a2e4de;
  }
.alert-info .alert-link {
  color: #028293;
  }
.alert-warning {
  color: #ed980f;
  background-color: #fff0d5;
  }
.alert-warning hr {
  border-top-color: #ffdcbc;
  }
.alert-warning .alert-link {
  color: #cc830d;
  }
.alert-danger {
  color: #e75033;
  background-color: #ffe5e0;
  }
.alert-danger hr {
  border-top-color: #ffc6c7;
  }
.alert-danger .alert-link {
  color: #dd391a;
  }
.alert-inverse {
  color: #fff;
  background-color: #353535;
  border-color: #353535;
  }
.alert-inverse hr {
  border-top-color: #ddd;
  border-top-color: rgba(221, 221, 221, .25);
  }
.alert-inverse .alert-link {
  color: rgba(255, 255, 255, .8);
  }
.alert-primary-inverse {
  color: #fff;
  background-color: #3280fc;
  border-color: #3280fc;
  }
.alert-primary-inverse hr {
  border-top-color: #ddd;
  border-top-color: rgba(221, 221, 221, .25);
  }
.alert-primary-inverse .alert-link {
  color: rgba(255, 255, 255, .8);
  }
.alert-success-inverse {
  color: #fff;
  background-color: #38b03f;
  border-color: #38b03f;
  }
.alert-success-inverse hr {
  border-top-color: #ddd;
  border-top-color: rgba(221, 221, 221, .25);
  }
.alert-success-inverse .alert-link {
  color: rgba(255, 255, 255, .8);
  }
.alert-info-inverse {
  color: #fff;
  background-color: #03b8cf;
  border-color: #03b8cf;
  }
.alert-info-inverse hr {
  border-top-color: #ddd;
  border-top-color: rgba(221, 221, 221, .25);
  }
.alert-info-inverse .alert-link {
  color: rgba(255, 255, 255, .8);
  }
.alert-warning-inverse {
  color: #fff;
  background-color: #f1a325;
  border-color: #f1a325;
  }
.alert-warning-inverse hr {
  border-top-color: #ddd;
  border-top-color: rgba(221, 221, 221, .25);
  }
.alert-warning-inverse .alert-link {
  color: rgba(255, 255, 255, .8);
  }
.alert-danger-inverse {
  color: #fff;
  background-color: #ea644a;
  border-color: #ea644a;
  }
.alert-danger-inverse hr {
  border-top-color: #ddd;
  border-top-color: rgba(221, 221, 221, .25);
  }
.alert-danger-inverse .alert-link {
  color: rgba(255, 255, 255, .8);
  }
.input-group {
  position: relative;
  display: table;
  border-collapse: separate;
  }
.input-group[class*="col-"] {
  float: none;
  padding-right: 0;
  padding-left: 0;
  }
.input-group .form-control {
  position: relative;
  z-index: 2;
  float: left;
  width: 100%;
  margin-bottom: 0;
  }
.input-group-addon,
.input-group-btn,
.input-group .form-control {
  display: table-cell;
  }
.input-group-addon:not(:first-child):not(:last-child),
.input-group-btn:not(:first-child):not(:last-child),
.input-group .form-control:not(:first-child):not(:last-child) {
  border-radius: 0;
  }
.input-group-addon,
.input-group-btn {
  width: 1%;
  white-space: nowrap;
  vertical-align: middle;
  }
.input-group-addon {
  padding: 5px 12px;
  font-size: 13px;
  font-weight: normal;
  line-height: 1;
  color: #222;
  text-align: center;
  background-color: #e5e5e5;
  border: 1px solid #ccc;
  border-radius: 4px;
  }
.input-group-addon input[type="radio"],
.input-group-addon input[type="checkbox"] {
  margin-top: 0;
  }
.input-group-addon.fix-border {
  border-right: 0;
  border-left: 0;
  }
.input-group-addon:empty,
.input-group-addon.fix-padding {
  width: 1px;
  padding: 0;
  }
.input-group-btn.fix-border > .btn {
  border-right: 0;
  border-left: 0;
  border-radius: 0;
  }
.input-group .form-control:first-child,
.input-group-addon:first-child,
.input-group-btn:first-child > .btn,
.input-group-btn:first-child > .btn-group > .btn,
.input-group-btn:first-child > .dropdown-toggle,
.input-group-btn:last-child > .btn:not(:last-child):not(.dropdown-toggle),
.input-group-btn:last-child > .btn-group:not(:last-child) > .btn,
.input-group-btn:first-child > .btn-group-vertical > .btn,
.input-group-btn:last-child > .btn-group-vertical:not(:last-child) > .btn {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  }
.input-group-addon:first-child {
  border-right: 0;
  }
.input-group .form-control:last-child,
.input-group-addon:last-child,
.input-group-btn:last-child > .btn,
.input-group-btn:last-child > .btn-group > .btn,
.input-group-btn:last-child > .dropdown-toggle,
.input-group-btn:first-child > .btn:not(:first-child),
.input-group-btn:first-child > .btn-group:not(:first-child) > .btn,
.input-group-btn:last-child > .btn-group-vertical > .btn,
.input-group-btn:first-child > .btn-group-vertical:not(:first-child) > .btn {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  }
.input-group-addon:last-child {
  border-left: 0;
  }
.input-group-btn {
  position: relative;
  font-size: 0;
  white-space: nowrap;
  }
.input-group-btn > .btn {
  position: relative;
  }
.input-group-btn > .btn + .btn {
  margin-left: -1px;
  }
.input-group-btn > .btn:hover,
.input-group-btn > .btn:focus,
.input-group-btn > .btn:active {
  z-index: 2;
  }
.input-group-btn:first-child > .btn,
.input-group-btn:first-child > .btn-group,
.input-group-btn:first-child > .btn-group-vertical {
  margin-right: -1px;
  }
.input-group-btn:last-child > .btn,
.input-group-btn:last-child > .btn-group,
.input-group-btn:last-child > .btn-group-vertical {
  margin-left: -1px;
  }
.input-group-lg > .form-control,
.input-group-lg > .input-group-addon,
.input-group-lg > .input-group-btn > .btn {
  height: 43px;
  padding: 10px 16px;
  font-size: 17px;
  line-height: 1.25;
  border-radius: 6px;
  }
select.input-group-lg > .form-control,
select.input-group-lg > .input-group-addon,
select.input-group-lg > .input-group-btn > .btn {
  height: 43px;
  line-height: 43px;
  }
textarea.input-group-lg > .form-control,
textarea.input-group-lg > .input-group-addon,
textarea.input-group-lg > .input-group-btn > .btn {
  height: auto;
  }
.input-group-sm > .form-control,
.input-group-sm > .input-group-addon,
.input-group-sm > .input-group-btn > .btn {
  height: 24px;
  padding: 2px 8px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
  }
select.input-group-sm > .form-control,
select.input-group-sm > .input-group-addon,
select.input-group-sm > .input-group-btn > .btn {
  height: 24px;
  line-height: 24px;
  }
textarea.input-group-sm > .form-control,
textarea.input-group-sm > .input-group-addon,
textarea.input-group-sm > .input-group-btn > .btn {
  height: auto;
  }
.input-group-addon.input-sm {
  padding: 2px 8px;
  font-size: 12px;
  border-radius: 3px;
  }
.input-group-addon.input-lg {
  padding: 10px 16px;
  font-size: 17px;
  border-radius: 6px;
  }
.code,
code,
kbd,
pre,
samp {
  font-family: Monaco, Menlo, Consolas, "Courier New", monospace;
  }
kbd,
code {
  padding: 2px 4px;
  font-size: 90%;
  color: #ea644a;
  background-color: #f9f2f4;
  border-radius: 4px;
  }
kbd {
  padding: 1px 4px;
  font-weight: bold;
  color: #666;
  background-color: #f1f1f1;
  border: 1px solid #d7d7d7;
  border-bottom-width: 2px;
  }
pre {
  display: block;
  padding: 9.5px;
  margin: 0 0 10px;
  font-size: 12px;
  line-height: 1.38461538;
  color: #333;
  word-break: break-all;
  word-wrap: break-word;
  background-color: #f5f5f5;
  border: 1px solid #ccc;
  border-radius: 4px;
  }
pre code {
  padding: 0;
  margin: 0;
  font-size: inherit;
  color: inherit;
  white-space: pre-wrap;
  background-color: transparent;
  border: 0;
  }
.pre-scrollable {
  max-height: 340px;
  overflow-y: scroll;
  }
.com {
  color: #93a1a1;
  }
.lit {
  color: #195f91;
  }
.pun,
.opn,
.clo {
  color: #93a1a1;
  }
.fun {
  color: #dc322f;
  }
.str,
.atv {
  color: #d14;
  }
.kwd,
.prettyprint .tag {
  color: #1e347b;
  }
.typ,
.atn,
.dec,
.var {
  color: teal;
  }
.pln {
  color: #48484c;
  }
.prettyprint.linenums {
  -webkit-box-shadow: inset 40px 0 0 #fbfbfc, inset 41px 0 0 #ececf0;
          box-shadow: inset 40px 0 0 #fbfbfc, inset 41px 0 0 #ececf0;
  }
.prettyprint ol.linenums {
  padding-left: 35px;
  margin-bottom: 0;
  line-height: 20px;
  color: #bebec5;
  text-shadow: 0 1px 0 #fff;
  }
.pager {
  display: inline-block;
  padding-left: 0;
  margin: 20px 0;
  list-style: none;
  }
.pager > li {
  display: inline;
  }
.pager > li > a,
.pager > li > span {
  position: relative;
  float: left;
  padding: 5px 12px;
  margin-left: -1px;
  line-height: 1.53846154;
  text-decoration: none;
  background-color: #fff;
  border: 1px solid #ddd;
  }
.pager > li:first-child > a,
.pager > li:first-child > span {
  margin-left: 0;
  border-top-left-radius: 4px;
  border-bottom-left-radius: 4px;
  }
.pager > li:last-child > a,
.pager > li:last-child > span {
  border-top-right-radius: 4px;
  border-bottom-right-radius: 4px;
  }
.pager > li > a:hover,
.pager > li > span:hover,
.pager > li > a:focus,
.pager > li > span:focus {
  z-index: 2;
  background-color: #e5e5e5;
  }
.pager > li.active > a,
.pager > li.active > span,
.pager > li.active > a:hover,
.pager > li.active > span:hover {
  z-index: 3;
  color: #fff;
  cursor: default;
  background-color: #3280fc;
  border-color: #3280fc;
  }
.pager > li.disabled > span,
.pager > li.disabled > span:hover,
.pager > li.disabled > span:focus,
.pager > li.disabled > a,
.pager > li.disabled > a:hover,
.pager > li.disabled > a:focus {
  color: #ddd;
  pointer-events: none;
  cursor: not-allowed;
  background-color: #fff;
  border-color: #ddd;
  }
.pager-justify {
  display: block;
  }
.pager-justify .next > a,
.pager-justify .next > span {
  float: right;
  border-radius: 4px;
  }
.pager-justify .previous > a,
.pager-justify .previous > span {
  float: left;
  border-radius: 4px;
  }
.pager-lg > li > a,
.pager-lg > li > span {
  padding: 10px 16px;
  font-size: 17px;
  }
.pager-lg > li:first-child > a,
.pager-lg > li:first-child > span {
  border-top-left-radius: 6px;
  border-bottom-left-radius: 6px;
  }
.pager-lg > li:last-child > a,
.pager-lg > li:last-child > span {
  border-top-right-radius: 6px;
  border-bottom-right-radius: 6px;
  }
.pager-sm > li > a,
.pager-sm > li > span {
  padding: 2px 8px;
  font-size: 12px;
  }
.pager-sm > li:first-child > a,
.pager-sm > li:first-child > span {
  border-top-left-radius: 3px;
  border-bottom-left-radius: 3px;
  }
.pager-sm > li:last-child > a,
.pager-sm > li:last-child > span {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
  }
.pager-pills > li:first-child > a,
.pager-pills > li:first-child > span {
  border-radius: 16px 0 0 16px;
  }
.pager-pills > li:last-child > a,
.pager-pills > li:last-child > span {
  border-radius: 0 16px 16px 0;
  }
.pager-pills.pager-justify > li > a,
.pager-pills.pager-justify > li > span {
  border-radius: 16px;
  }
.pager-loose {
  display: block;
  margin: 20px 0;
  }
.pager-loose.pager-pills > li > a,
.pager-loose.pager-pills > li > span {
  border-radius: 16px;
  }
.pager-loose > li > a,
.pager-loose > li > span {
  margin-left: 5px;
  border-radius: 4px;
  }
.pager-loose > li:first-child > a,
.pager-loose > li:first-child > span {
  margin-left: 0;
  }
.nav {
  padding-left: 0;
  margin-bottom: 0;
  list-style: none;
  }
.nav > .nav-heading {
  padding: 8px 15px;
  font-weight: bold;
  color: #808080;
  }
.nav > li {
  position: relative;
  display: block;
  }
.nav > li > a {
  position: relative;
  display: block;
  padding: 8px 15px;
  color: #353535;
  }
.nav > li > a:hover,
.nav > li > a:focus {
  color: #0d3d88;
  text-decoration: none;
  background-color: #f1f1f1;
  }
.nav > li.disabled > a {
  color: #ddd;
  }
.nav > li.disabled > a:hover,
.nav > li.disabled > a:focus {
  color: #ddd;
  text-decoration: none;
  cursor: not-allowed;
  background-color: transparent;
  }
.nav .open > a,
.nav .open > a:hover,
.nav .open > a:focus {
  background-color: #f1f1f1;
  border-color: #145ccd;
  }
.nav > li > a > img {
  max-width: none;
  }
.nav-pills > li {
  float: left;
  }
.nav-pills > li > a {
  border-radius: 20px;
  }
.nav-pills > li + li {
  margin-left: 2px;
  }
.nav-pills > li.active > a,
.nav-pills > li.active > a:hover,
.nav-pills > li.active > a:focus {
  color: #fff;
  background-color: #3280fc;
  }
.nav-primary > li {
  float: left;
  margin-left: -1px;
  }
.nav-primary > li:first-child > a {
  margin-left: 0;
  border-top-left-radius: 4px;
  border-bottom-left-radius: 4px;
  }
.nav-primary > li:last-child > a {
  border-top-right-radius: 4px;
  border-bottom-right-radius: 4px;
  }
.nav-primary > li > a {
  border: 1px solid #ddd;
  }
.nav-primary > li.active > a,
.nav-primary > li.active > a:hover,
.nav-primary > li.active > a:focus {
  color: #fff;
  background-color: #3280fc;
  border-color: #3280fc;
  }
.nav-secondary > li {
  float: left;
  }
.nav-secondary > li > a {
  border-bottom: 2px solid #e5e5e5;
  }
.nav-secondary > li.active > a,
.nav-secondary > li.active > a:hover,
.nav-secondary > li.active > a:focus {
  color: #3280fc;
  border-bottom-color: #3280fc;
  }
.nav-secondary > li.nav-heading {
  border-bottom: 2px solid #e5e5e5;
  }
.nav-stacked > li {
  float: none;
  }
.nav-stacked > li + li {
  margin-top: 2px;
  margin-left: 0;
  }
.nav-stacked.nav-primary > li,
.nav-stacked.nav-primary > li > a {
  margin-left: 0;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
  }
.nav-stacked.nav-primary > li + li {
  margin-top: -1px;
  }
.nav-stacked.nav-primary > li:first-child {
  margin-top: 0;
  }
.nav-stacked.nav-primary > li:first-child > a,
.nav-stacked.nav-primary > li:first-child.nav-heading {
  margin-left: 0;
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
  }
.nav-stacked.nav-primary > li:last-child > a {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  border-bottom-right-radius: 4px;
  border-bottom-left-radius: 4px;
  }
.nav-stacked.nav-primary > li.nav-heading {
  background-color: #f1f1f1;
  border: 1px solid #ddd;
  }
.nav-stacked.nav-secondary > li > a {
  border: none;
  border-top-right-radius: 4px;
  border-bottom-right-radius: 4px;
  -webkit-box-shadow: inset 2px 0 0 #f5f5f5;
          box-shadow: inset 2px 0 0 #f5f5f5;
  }
.nav-stacked.nav-secondary > li > a:hover {
  -webkit-box-shadow: inset 2px 0 0 #e5e5e5;
          box-shadow: inset 2px 0 0 #e5e5e5;
  }
.nav-stacked.nav-secondary > li + li {
  margin-top: -1px;
  }
.nav-stacked.nav-secondary > li:first-child {
  margin-top: 0;
  }
.nav-stacked.nav-secondary > li.active > a,
.nav-stacked.nav-secondary > li.active > a:hover,
.nav-stacked.nav-secondary > li.active > a:focus {
  background-color: #f5f5f5;
  -webkit-box-shadow: inset 2px 0 0 #3280fc;
          box-shadow: inset 2px 0 0 #3280fc;
  }
.nav-stacked.nav-secondary > li.nav-heading {
  border-bottom: 1px solid #ddd;
  }
.nav-justified {
  width: 100%;
  }
.nav-justified > li {
  float: none;
  }
.nav-justified > li > a {
  margin-bottom: 5px;
  text-align: center;
  }
@media (min-width: 768px) {
  .nav-justified > li {
    display: table-cell;
    width: 1%;
    }
  .nav-justified > li > a {
    margin-bottom: 0;
    }
  .nav-justified.nav-primary > li + li > a {
    border-left: 0;
    }
  }
.nav-tabs .dropdown-menu {
  margin-top: -1px;
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  }
.nav-tabs {
  border-bottom: 1px solid #ddd;
  }
.nav-tabs > li {
  float: left;
  margin-bottom: -1px;
  }
.nav-tabs > li > a {
  margin-right: 2px;
  line-height: 1.53846154;
  border: 1px solid transparent;
  border-radius: 4px 4px 0 0;
  }
.nav-tabs > li > a:hover {
  border-color: #e5e5e5 #e5e5e5 #ddd;
  }
.nav-tabs > li.active > a,
.nav-tabs > li.active > a:hover,
.nav-tabs > li.active > a:focus {
  color: #808080;
  cursor: default;
  background-color: #fff;
  border: 1px solid #ddd;
  border-bottom-color: transparent;
  }
.nav-tabs.nav-justified {
  width: 100%;
  border-bottom: 0;
  }
.nav-tabs.nav-justified > li {
  float: none;
  }
.nav-tabs.nav-justified > li > a {
  margin-bottom: 5px;
  text-align: center;
  }
@media (min-width: 768px) {
  .nav-tabs.nav-justified > li {
    display: table-cell;
    width: 1%;
    }
  .nav-tabs.nav-justified > li > a {
    margin-bottom: 0;
    }
  .nav-tabs.nav-justified.nav-primary > li + li > a {
    border-left: 0;
    }
  }
.nav-tabs.nav-justified > li > a {
  margin-right: 0;
  border-radius: 4px;
  }
.nav-tabs.nav-justified > .active > a,
.nav-tabs.nav-justified > .active > a:hover,
.nav-tabs.nav-justified > .active > a:focus {
  border: 1px solid #ddd;
  }
@media (min-width: 768px) {
  .nav-tabs.nav-justified > li > a {
    border-bottom: 1px solid #ddd;
    border-radius: 4px 4px 0 0;
    }
  .nav-tabs.nav-justified > .active > a,
  .nav-tabs.nav-justified > .active > a:hover,
  .nav-tabs.nav-justified > .active > a:focus {
    border-bottom-color: #fff;
    }
  }
@-moz-document url-prefix() {
  .nav-tabs > li.active > a:focus .nav-tabs > li > a:focus {
    outline: 0;
    }
  }
.nav-tabs-justified {
  border-bottom: 0;
  }
.nav-tabs-justified > li > a {
  margin-right: 0;
  border-radius: 4px;
  }
.nav-tabs-justified > .active > a,
.nav-tabs-justified > .active > a:hover,
.nav-tabs-justified > .active > a:focus {
  border: 1px solid #ddd;
  }
@media (min-width: 768px) {
  .nav-tabs-justified > li > a {
    border-bottom: 1px solid #ddd;
    border-radius: 4px 4px 0 0;
    }
  .nav-tabs-justified > .active > a,
  .nav-tabs-justified > .active > a:hover,
  .nav-tabs-justified > .active > a:focus {
    border-bottom-color: #fff;
    }
  }
.tab-content > .tab-pane {
  display: none;
  }
.tab-content > .active {
  display: block;
  }
.nav-tabs .dropdown-menu {
  margin-top: -1px;
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  }
.navbar {
  position: relative;
  min-height: 40px;
  margin-bottom: 20px;
  border: 1px solid transparent;
  }
@media (min-width: 768px) {
  .navbar {
    border-radius: 4px;
    }
  }
@media (min-width: 768px) {
  .navbar-header {
    float: left;
    }
  }
.navbar-collapse {
  padding-right: 10px;
  padding-left: 10px;
  overflow-x: visible;
  -webkit-overflow-scrolling: touch;
  border-top: 1px solid transparent;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, .1);
          box-shadow: inset 0 1px 0 rgba(255, 255, 255, .1);
  }
.navbar-collapse.in {
  overflow-y: auto;
  }
@media (min-width: 768px) {
  .navbar-collapse {
    width: auto;
    border-top: 0;
    -webkit-box-shadow: none;
            box-shadow: none;
    }
  .navbar-collapse.collapse {
    display: block !important;
    height: auto !important;
    padding-bottom: 0;
    overflow: visible !important;
    }
  .navbar-collapse.in {
    overflow-y: visible;
    }
  .navbar-fixed-top .navbar-collapse,
  .navbar-static-top .navbar-collapse,
  .navbar-fixed-bottom .navbar-collapse {
    padding-right: 0;
    padding-left: 0;
    }
  }
.navbar-fixed-top .navbar-collapse,
.navbar-fixed-bottom .navbar-collapse {
  max-height: 340px;
  }
@media (max-device-width: 480px) and (orientation: landscape) {
  .navbar-fixed-top .navbar-collapse,
  .navbar-fixed-bottom .navbar-collapse {
    max-height: 200px;
    }
  }
.container > .navbar-header,
.container-fluid > .navbar-header,
.container > .navbar-collapse,
.container-fluid > .navbar-collapse {
  margin-right: -10px;
  margin-left: -10px;
  }
@media (min-width: 768px) {
  .container > .navbar-header,
  .container-fluid > .navbar-header,
  .container > .navbar-collapse,
  .container-fluid > .navbar-collapse {
    margin-right: 0;
    margin-left: 0;
    }
  }
.navbar-static-top {
  z-index: 1000;
  border-width: 0 0 1px;
  }
@media (min-width: 768px) {
  .navbar-static-top {
    border-radius: 0;
    }
  }
.navbar-fixed-top,
.navbar-fixed-bottom {
  position: fixed;
  right: 0;
  left: 0;
  z-index: 1030;
  }
@media (min-width: 768px) {
  .navbar-fixed-top,
  .navbar-fixed-bottom {
    border-radius: 0;
    }
  }
.navbar-fixed-top {
  top: 0;
  border-width: 0 0 1px;
  }
.navbar-fixed-bottom {
  bottom: 0;
  margin-bottom: 0;
  border-width: 1px 0 0;
  }
.navbar-brand {
  float: left;
  height: 40px;
  padding: 10px 15px;
  font-size: 17px;
  line-height: 20px;
  }
.navbar-brand:hover,
.navbar-brand:focus {
  text-decoration: none;
  }
.navbar-brand > img {
  display: block;
  }
@media (min-width: 768px) {
  .navbar > .container .navbar-brand,
  .navbar > .container-fluid .navbar-brand {
    margin-left: -10px;
    }
  }
.navbar-toggle {
  position: relative;
  float: right;
  padding: 9px 10px;
  margin-top: 3px;
  margin-right: 3px;
  margin-bottom: 3px;
  background-color: transparent;
  background-image: none;
  border: 1px solid transparent;
  border-radius: 4px;
  }
.navbar-toggle:focus {
  outline: 0;
  }
.navbar-toggle .icon-bar {
  display: block;
  width: 22px;
  height: 2px;
  border-radius: 1px;
  }
.navbar-toggle .icon-bar + .icon-bar {
  margin-top: 4px;
  }
@media (min-width: 768px) {
  .navbar-toggle {
    display: none;
    }
  }
.navbar-nav {
  margin: 5px -10px;
  }
.navbar-nav > li > a {
  padding-top: 10px;
  padding-bottom: 10px;
  line-height: 20px;
  }
@media (max-width: 767px) {
  .navbar-nav .open .dropdown-menu {
    position: static;
    float: none;
    width: auto;
    margin-top: 0;
    background-color: transparent;
    border: 0;
    -webkit-box-shadow: none;
            box-shadow: none;
    }
  .navbar-nav .open .dropdown-menu > li > a,
  .navbar-nav .open .dropdown-menu .dropdown-header {
    padding: 5px 15px 5px 25px;
    }
  .navbar-nav .open .dropdown-menu > li > a {
    line-height: 20px;
    }
  .navbar-nav .open .dropdown-menu > li > a:hover,
  .navbar-nav .open .dropdown-menu > li > a:focus {
    background-image: none;
    }
  }
@media (min-width: 768px) {
  .navbar-nav {
    float: left;
    margin: 0;
    }
  .navbar-nav > li {
    float: left;
    }
  .navbar-nav > li > a {
    padding-top: 10px;
    padding-bottom: 10px;
    }
  .navbar-nav.nav-justified > li {
    float: none;
    }
  }
.navbar-nav > li > .dropdown-menu {
  margin-top: 0;
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  }
.navbar-fixed-bottom .navbar-nav > li > .dropdown-menu {
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
  }
.navbar-nav.pull-right > li > .dropdown-menu,
.navbar-nav > li > .dropdown-menu.pull-right {
  right: 0;
  left: auto;
  }
.navbar-btn {
  margin-top: 4px;
  margin-bottom: 4px;
  }
.navbar-text {
  float: left;
  margin-top: 10px;
  margin-bottom: 10px;
  }
@media (min-width: 768px) {
  .navbar-text {
    margin-right: 10px;
    margin-left: 10px;
    }
  }
@media (min-width: 768px) {
  .navbar-left {
    float: left !important;
    }
  .navbar-right {
    float: right !important;
    margin-right: -10px;
    }
  .navbar-right ~ .navbar-right {
    margin-right: 0;
    }
  }
.navbar-default {
  background-color: #f7f7f7;
  border-color: #dedede;
  }
.navbar-default .navbar-brand {
  color: #333;
  }
.navbar-default .navbar-brand:hover,
.navbar-default .navbar-brand:focus {
  color: #1a1a1a;
  background-color: transparent;
  }
.navbar-default .navbar-text {
  color: #333;
  }
.navbar-default .navbar-nav > li > a {
  color: #333;
  }
.navbar-default .navbar-nav > li > a:hover,
.navbar-default .navbar-nav > li > a:focus {
  color: #222;
  background-color: #e5e5e5;
  }
.navbar-default .navbar-nav > .active > a,
.navbar-default .navbar-nav > .active > a:hover,
.navbar-default .navbar-nav > .active > a:focus {
  color: #555;
  background-color: #e7e7e7;
  }
.navbar-default .navbar-nav > .disabled > a,
.navbar-default .navbar-nav > .disabled > a:hover,
.navbar-default .navbar-nav > .disabled > a:focus {
  color: #ccc;
  background-color: transparent;
  }
.navbar-default .navbar-toggle:hover,
.navbar-default .navbar-toggle:focus {
  background-color: #ddd;
  }
.navbar-default .navbar-toggle .icon-bar {
  background-color: #808080;
  }
.navbar-default .navbar-collapse,
.navbar-default .navbar-form {
  border-color: #dedede;
  }
.navbar-default .navbar-nav > .open > a,
.navbar-default .navbar-nav > .open > a:hover,
.navbar-default .navbar-nav > .open > a:focus {
  color: #555;
  background-color: #e7e7e7;
  }
@media (max-width: 767px) {
  .navbar-default .navbar-nav .open .dropdown-menu > li > a {
    color: #333;
    }
  .navbar-default .navbar-nav .open .dropdown-menu > li > a:hover,
  .navbar-default .navbar-nav .open .dropdown-menu > li > a:focus {
    color: #222;
    background-color: #e5e5e5;
    }
  .navbar-default .navbar-nav .open .dropdown-menu > .active > a,
  .navbar-default .navbar-nav .open .dropdown-menu > .active > a:hover,
  .navbar-default .navbar-nav .open .dropdown-menu > .active > a:focus {
    color: #555;
    background-color: #e7e7e7;
    }
  .navbar-default .navbar-nav .open .dropdown-menu > .disabled > a,
  .navbar-default .navbar-nav .open .dropdown-menu > .disabled > a:hover,
  .navbar-default .navbar-nav .open .dropdown-menu > .disabled > a:focus {
    color: #ccc;
    background-color: transparent;
    }
  }
.navbar-default .navbar-link {
  color: #333;
  }
.navbar-default .navbar-link:hover {
  color: #222;
  }
.navbar-default .btn-link {
  color: #333;
  }
.navbar-default .btn-link:hover,
.navbar-default .btn-link:focus {
  color: #222;
  }
.navbar-default .btn-link[disabled]:hover,
fieldset[disabled] .navbar-default .btn-link:hover,
.navbar-default .btn-link[disabled]:focus,
fieldset[disabled] .navbar-default .btn-link:focus {
  color: #ccc;
  }
.navbar-inverse {
  background-color: #145ccd;
  border-color: #10479f;
  }
.navbar-inverse .navbar-brand {
  color: #ddd;
  }
.navbar-inverse .navbar-brand:hover,
.navbar-inverse .navbar-brand:focus {
  color: #fff;
  background-color: transparent;
  }
.navbar-inverse .navbar-text {
  color: #ddd;
  }
.navbar-inverse .navbar-nav > li > a {
  color: #ddd;
  }
.navbar-inverse .navbar-nav > li > a:hover,
.navbar-inverse .navbar-nav > li > a:focus {
  color: #fff;
  background-color: #1868e8;
  }
.navbar-inverse .navbar-nav > .active > a,
.navbar-inverse .navbar-nav > .active > a:hover,
.navbar-inverse .navbar-nav > .active > a:focus {
  color: #fff;
  background-color: #2a74ea;
  }
.navbar-inverse .navbar-nav > .disabled > a,
.navbar-inverse .navbar-nav > .disabled > a:hover,
.navbar-inverse .navbar-nav > .disabled > a:focus {
  color: #444;
  background-color: transparent;
  }
.navbar-inverse .navbar-toggle:hover,
.navbar-inverse .navbar-toggle:focus {
  background-color: #1251b6;
  }
.navbar-inverse .navbar-toggle .icon-bar {
  background-color: #fff;
  }
.navbar-inverse .navbar-collapse,
.navbar-inverse .navbar-form {
  border-color: #114dad;
  }
.navbar-inverse .navbar-nav > .open > a,
.navbar-inverse .navbar-nav > .open > a:hover,
.navbar-inverse .navbar-nav > .open > a:focus {
  color: #fff;
  background-color: #2a74ea;
  }
@media (max-width: 767px) {
  .navbar-inverse .navbar-nav .open .dropdown-menu > .dropdown-header {
    border-color: #10479f;
    }
  .navbar-inverse .navbar-nav .open .dropdown-menu .divider {
    background-color: #10479f;
    }
  .navbar-inverse .navbar-nav .open .dropdown-menu > li > a {
    color: #ddd;
    }
  .navbar-inverse .navbar-nav .open .dropdown-menu > li > a:hover,
  .navbar-inverse .navbar-nav .open .dropdown-menu > li > a:focus {
    color: #fff;
    background-color: #1868e8;
    }
  .navbar-inverse .navbar-nav .open .dropdown-menu > .active > a,
  .navbar-inverse .navbar-nav .open .dropdown-menu > .active > a:hover,
  .navbar-inverse .navbar-nav .open .dropdown-menu > .active > a:focus {
    color: #fff;
    background-color: #2a74ea;
    }
  .navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a,
  .navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a:hover,
  .navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a:focus {
    color: #444;
    background-color: transparent;
    }
  }
.navbar-inverse .navbar-link {
  color: #ddd;
  }
.navbar-inverse .navbar-link:hover {
  color: #fff;
  }
.navbar-form {
  padding: 10px 10px;
  margin-top: 4px;
  margin-right: -10px;
  margin-bottom: 4px;
  margin-left: -10px;
  border-top: 1px solid transparent;
  border-bottom: 1px solid transparent;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, .1), 0 1px 0 rgba(255, 255, 255, .1);
          box-shadow: inset 0 1px 0 rgba(255, 255, 255, .1), 0 1px 0 rgba(255, 255, 255, .1);
  }
@media (min-width: 768px) {
  .navbar-form .form-group {
    display: inline-block;
    margin-bottom: 0;
    vertical-align: middle;
    }
  .navbar-form .form-control {
    display: inline-block;
    width: auto;
    vertical-align: middle;
    }
  .navbar-form .radio,
  .navbar-form .checkbox {
    display: inline-block;
    padding-left: 0;
    margin-top: 0;
    margin-bottom: 0;
    }
  .navbar-form .radio input[type="radio"],
  .navbar-form .checkbox input[type="checkbox"] {
    float: none;
    margin-left: 0;
    }
  }
@media (max-width: 767px) {
  .navbar-form .form-group {
    margin-bottom: 5px;
    }
  .navbar-form .form-group:last-child {
    margin-bottom: 0;
    }
  }
@media (min-width: 768px) {
  .navbar-form {
    width: auto;
    padding-top: 0;
    padding-bottom: 0;
    margin-right: 0;
    margin-left: 0;
    border: 0;
    -webkit-box-shadow: none;
            box-shadow: none;
    }
  }
.fade {
  opacity: 0;
  -webkit-transition: opacity .15s linear;
       -o-transition: opacity .15s linear;
          transition: opacity .15s linear;
  }
.fade.in {
  opacity: 1;
  }
.scale {
  -webkit-transition: all .15s ease;
       -o-transition: all .15s ease;
          transition: all .15s ease;
  -webkit-transform: scale(.8);
      -ms-transform: scale(.8);
       -o-transform: scale(.8);
          transform: scale(.8);
  }
.scale.in {
  -webkit-transform: scale(1);
      -ms-transform: scale(1);
       -o-transform: scale(1);
          transform: scale(1);
  }
.collapse {
  display: none;
  }
.collapse.in {
  display: block;
  }
tr.collapse.in {
  display: table-row;
  }
tbody.collapse.in {
  display: table-row-group;
  }
.collapsing {
  position: relative;
  height: 0;
  overflow: hidden;
  -webkit-transition: height .35s ease;
       -o-transition: height .35s ease;
          transition: height .35s ease;
  }
.modal-open {
  overflow: hidden;
  }
.modal {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1050;
  display: none;
  overflow: hidden;
  -webkit-overflow-scrolling: touch;
  outline: 0;
  }
.modal.fade .modal-dialog {
  -webkit-transition: -webkit-transform .3s ease-out;
       -o-transition:      -o-transform .3s ease-out;
          transition: -webkit-transform .3s ease-out;
          transition:         transform .3s ease-out;
          transition:         transform .3s ease-out, -webkit-transform .3s ease-out, -o-transform .3s ease-out;
  -webkit-transform: translate(0, -25%);
      -ms-transform: translate(0, -25%);
       -o-transform: translate(0, -25%);
          transform: translate(0, -25%);
  }
.modal.in .modal-dialog {
  -webkit-transform: translate(0, 0);
      -ms-transform: translate(0, 0);
       -o-transform: translate(0, 0);
          transform: translate(0, 0);
  }
.modal > .loader {
  display: none;
  }
.modal.modal-loading .modal-dialog {
  opacity: 0;
  }
.modal.modal-loading .loader {
  position: absolute;
  top: 35%;
  left: 50%;
  display: block;
  width: 80px;
  margin-left: -40px;
  font-size: 56px;
  color: #fff;
  text-align: center;
  }
.modal-open .modal {
  overflow-x: hidden;
  overflow-y: auto;
  }
.modal-iframe .modal-body > iframe {
  border-radius: 0 0 6px 6px;
  }
.modal-dialog {
  position: relative;
  width: auto;
  background-color: #fff;
  -webkit-background-clip: padding-box;
          background-clip: padding-box;
  border: 1px solid #999;
  border: 1px solid rgba(0, 0, 0, .2);
  border-radius: 6px;
  outline: 0;
  -webkit-box-shadow: 0 3px 9px rgba(0, 0, 0, .5);
          box-shadow: 0 3px 9px rgba(0, 0, 0, .5);
  }
.modal-dialog.modal-moveable {
  position: absolute;
  margin: 0;
  }
.modal-dialog.modal-moveable .modal-header {
  cursor: move;
  }
.modal-backdrop {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1040;
  background-color: #000;
  }
.modal-backdrop.fade {
  filter: alpha(opacity=0);
  opacity: 0;
  }
.modal-backdrop.in {
  filter: alpha(opacity=50);
  opacity: .5;
  }
.modal-header {
  min-height: 16.53846154px;
  padding: 15px;
  border-bottom: 1px solid #e5e5e5;
  }
.modal-header .close {
  margin-top: -2px;
  }
.modal-title {
  margin: 0;
  line-height: 1.53846154;
  }
.modal-body {
  position: relative;
  padding: 15px;
  }
.modal-footer {
  padding: 15px;
  text-align: right;
  border-top: 1px solid #e5e5e5;
  }
.modal-footer .btn + .btn {
  margin-bottom: 0;
  margin-left: 5px;
  }
.modal-footer .btn-group .btn + .btn,
.modal-footer .btn-group-vertical .btn + .btn {
  margin-left: -1px;
  }
.modal-footer .btn-block + .btn-block {
  margin-left: 0;
  }
.modal-scrollbar-measure {
  position: absolute;
  top: -9999px;
  width: 50px;
  height: 50px;
  overflow: scroll;
  }
@media (min-width: 768px) {
  .modal-dialog {
    width: 600px;
    margin: 30px auto;
    -webkit-box-shadow: 0 5px 15px rgba(0, 0, 0, .5);
            box-shadow: 0 5px 15px rgba(0, 0, 0, .5);
    }
  .modal-sm {
    width: 300px;
    }
  }
@media (min-width: 992px) {
  .modal-lg {
    width: 900px;
    }
  }
/* full screen modal */
.modal-fullscreen {
  position: relative;
  width: 100%!important;
  height: 100%!important;
  margin: 0;
  border-radius: 0;
  }
.modal-fullscreen .modal-body {
  position: absolute;
  top: 52px;
  right: 0;
  bottom: 0;
  left: 0;
  overflow-y: auto;
  }
.tooltip {
  position: absolute;
  z-index: 1030;
  display: block;
  font-size: 12px;
  line-height: 1.4;
  visibility: visible;
  filter: alpha(opacity=0);
  opacity: 0;
  }
.tooltip.in {
  filter: alpha(opacity=100);
  opacity: 1;
  }
.tooltip.top {
  padding: 5px 0;
  margin-top: -3px;
  }
.tooltip.right {
  padding: 0 5px;
  margin-left: 3px;
  }
.tooltip.bottom {
  padding: 5px 0;
  margin-top: 3px;
  }
.tooltip.left {
  padding: 0 5px;
  margin-left: -3px;
  }
.tooltip-inner {
  max-width: 200px;
  padding: 3px 8px;
  color: #fff;
  text-align: center;
  text-decoration: none;
  background-color: #353535;
  border-radius: 4px;
  }
.tooltip-arrow {
  position: absolute;
  width: 0;
  height: 0;
  border-color: transparent;
  border-style: solid;
  }
.tooltip.top .tooltip-arrow {
  bottom: 0;
  left: 50%;
  margin-left: -5px;
  border-width: 5px 5px 0;
  border-top-color: #353535;
  }
.tooltip.top-left .tooltip-arrow {
  bottom: 0;
  left: 5px;
  border-width: 5px 5px 0;
  border-top-color: #353535;
  }
.tooltip.top-right .tooltip-arrow {
  right: 5px;
  bottom: 0;
  border-width: 5px 5px 0;
  border-top-color: #353535;
  }
.tooltip.right .tooltip-arrow {
  top: 50%;
  left: 0;
  margin-top: -5px;
  border-width: 5px 5px 5px 0;
  border-right-color: #353535;
  }
.tooltip.left .tooltip-arrow {
  top: 50%;
  right: 0;
  margin-top: -5px;
  border-width: 5px 0 5px 5px;
  border-left-color: #353535;
  }
.tooltip.bottom .tooltip-arrow {
  top: 0;
  left: 50%;
  margin-left: -5px;
  border-width: 0 5px 5px;
  border-bottom-color: #353535;
  }
.tooltip.bottom-left .tooltip-arrow {
  top: 0;
  left: 5px;
  border-width: 0 5px 5px;
  border-bottom-color: #353535;
  }
.tooltip.bottom-right .tooltip-arrow {
  top: 0;
  right: 5px;
  border-width: 0 5px 5px;
  border-bottom-color: #353535;
  }
.tooltip-primary .tooltip-inner {
  background-color: #3280fc;
  }
.tooltip-primary.tooltip.top .tooltip-arrow {
  border-top-color: #3280fc;
  }
.tooltip-primary.tooltip.top-left .tooltip-arrow {
  border-top-color: #3280fc;
  }
.tooltip-primary.tooltip.top-right .tooltip-arrow {
  border-top-color: #3280fc;
  }
.tooltip-primary.tooltip.right .tooltip-arrow {
  border-right-color: #3280fc;
  }
.tooltip-primary.tooltip.left .tooltip-arrow {
  border-left-color: #3280fc;
  }
.tooltip-primary.tooltip.bottom .tooltip-arrow {
  border-bottom-color: #3280fc;
  }
.tooltip-primary.tooltip.bottom-left .tooltip-arrow {
  border-bottom-color: #3280fc;
  }
.tooltip-primary.tooltip.bottom-right .tooltip-arrow {
  border-bottom-color: #3280fc;
  }
.tooltip-success .tooltip-inner {
  background-color: #38b03f;
  }
.tooltip-success.tooltip.top .tooltip-arrow {
  border-top-color: #38b03f;
  }
.tooltip-success.tooltip.top-left .tooltip-arrow {
  border-top-color: #38b03f;
  }
.tooltip-success.tooltip.top-right .tooltip-arrow {
  border-top-color: #38b03f;
  }
.tooltip-success.tooltip.right .tooltip-arrow {
  border-right-color: #38b03f;
  }
.tooltip-success.tooltip.left .tooltip-arrow {
  border-left-color: #38b03f;
  }
.tooltip-success.tooltip.bottom .tooltip-arrow {
  border-bottom-color: #38b03f;
  }
.tooltip-success.tooltip.bottom-left .tooltip-arrow {
  border-bottom-color: #38b03f;
  }
.tooltip-success.tooltip.bottom-right .tooltip-arrow {
  border-bottom-color: #38b03f;
  }
.tooltip-info .tooltip-inner {
  background-color: #03b8cf;
  }
.tooltip-info.tooltip.top .tooltip-arrow {
  border-top-color: #03b8cf;
  }
.tooltip-info.tooltip.top-left .tooltip-arrow {
  border-top-color: #03b8cf;
  }
.tooltip-info.tooltip.top-right .tooltip-arrow {
  border-top-color: #03b8cf;
  }
.tooltip-info.tooltip.right .tooltip-arrow {
  border-right-color: #03b8cf;
  }
.tooltip-info.tooltip.left .tooltip-arrow {
  border-left-color: #03b8cf;
  }
.tooltip-info.tooltip.bottom .tooltip-arrow {
  border-bottom-color: #03b8cf;
  }
.tooltip-info.tooltip.bottom-left .tooltip-arrow {
  border-bottom-color: #03b8cf;
  }
.tooltip-info.tooltip.bottom-right .tooltip-arrow {
  border-bottom-color: #03b8cf;
  }
.tooltip-warning .tooltip-inner {
  background-color: #f1a325;
  }
.tooltip-warning.tooltip.top .tooltip-arrow {
  border-top-color: #f1a325;
  }
.tooltip-warning.tooltip.top-left .tooltip-arrow {
  border-top-color: #f1a325;
  }
.tooltip-warning.tooltip.top-right .tooltip-arrow {
  border-top-color: #f1a325;
  }
.tooltip-warning.tooltip.right .tooltip-arrow {
  border-right-color: #f1a325;
  }
.tooltip-warning.tooltip.left .tooltip-arrow {
  border-left-color: #f1a325;
  }
.tooltip-warning.tooltip.bottom .tooltip-arrow {
  border-bottom-color: #f1a325;
  }
.tooltip-warning.tooltip.bottom-left .tooltip-arrow {
  border-bottom-color: #f1a325;
  }
.tooltip-warning.tooltip.bottom-right .tooltip-arrow {
  border-bottom-color: #f1a325;
  }
.tooltip-danger .tooltip-inner {
  background-color: #ea644a;
  }
.tooltip-danger.tooltip.top .tooltip-arrow {
  border-top-color: #ea644a;
  }
.tooltip-danger.tooltip.top-left .tooltip-arrow {
  border-top-color: #ea644a;
  }
.tooltip-danger.tooltip.top-right .tooltip-arrow {
  border-top-color: #ea644a;
  }
.tooltip-danger.tooltip.right .tooltip-arrow {
  border-right-color: #ea644a;
  }
.tooltip-danger.tooltip.left .tooltip-arrow {
  border-left-color: #ea644a;
  }
.tooltip-danger.tooltip.bottom .tooltip-arrow {
  border-bottom-color: #ea644a;
  }
.tooltip-danger.tooltip.bottom-left .tooltip-arrow {
  border-bottom-color: #ea644a;
  }
.tooltip-danger.tooltip.bottom-right .tooltip-arrow {
  border-bottom-color: #ea644a;
  }
.popover {
  position: absolute;
  top: 0;
  left: 0;
  z-index: 1010;
  display: none;
  max-width: 300px;
  padding: 1px;
  text-align: left;
  white-space: normal;
  background-color: #fff;
  -webkit-background-clip: padding-box;
          background-clip: padding-box;
  border: 1px solid #ccc;
  border: 1px solid rgba(0, 0, 0, .2);
  border-radius: 4px;
  -webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, .2);
          box-shadow: 0 5px 10px rgba(0, 0, 0, .2);
  }
.popover.top {
  margin-top: -10px;
  }
.popover.right {
  margin-left: 10px;
  }
.popover.bottom {
  margin-top: 10px;
  }
.popover.left {
  margin-left: -10px;
  }
.popover.no-arrow.top {
  margin-top: 0;
  }
.popover.no-arrow.right {
  margin-left: 0;
  }
.popover.no-arrow.bottom {
  margin-top: 0;
  }
.popover.no-arrow.left {
  margin-left: 0;
  }
.popover-title {
  padding: 8px 14px;
  margin: 0;
  font-size: 13px;
  font-weight: normal;
  line-height: 18px;
  background-color: #f7f7f7;
  border-bottom: 1px solid #ebebeb;
  border-radius: 5px 5px 0 0;
  }
.popover-content {
  padding: 9px 14px;
  }
.popover .arrow,
.popover .arrow:after {
  position: absolute;
  display: block;
  width: 0;
  height: 0;
  border-color: transparent;
  border-style: solid;
  }
.popover .arrow {
  border-width: 11px;
  }
.popover .arrow:after {
  content: "";
  border-width: 10px;
  }
.popover.top .arrow {
  bottom: -11px;
  left: 50%;
  margin-left: -11px;
  border-top-color: #999;
  border-top-color: rgba(0, 0, 0, .25);
  border-bottom-width: 0;
  }
.popover.top .arrow:after {
  bottom: 1px;
  margin-left: -10px;
  content: " ";
  border-top-color: #fff;
  border-bottom-width: 0;
  }
.popover.right .arrow {
  top: 50%;
  left: -11px;
  margin-top: -11px;
  border-right-color: #999;
  border-right-color: rgba(0, 0, 0, .25);
  border-left-width: 0;
  }
.popover.right .arrow:after {
  bottom: -10px;
  left: 1px;
  content: " ";
  border-right-color: #fff;
  border-left-width: 0;
  }
.popover.bottom .arrow {
  top: -11px;
  left: 50%;
  margin-left: -11px;
  border-top-width: 0;
  border-bottom-color: #999;
  border-bottom-color: rgba(0, 0, 0, .25);
  }
.popover.bottom .arrow:after {
  top: 1px;
  margin-left: -10px;
  content: " ";
  border-top-width: 0;
  border-bottom-color: #fff;
  }
.popover.left .arrow {
  top: 50%;
  right: -11px;
  margin-top: -11px;
  border-right-width: 0;
  border-left-color: #999;
  border-left-color: rgba(0, 0, 0, .25);
  }
.popover.left .arrow:after {
  right: 1px;
  bottom: -10px;
  content: " ";
  border-right-width: 0;
  border-left-color: #fff;
  }
.caret {
  display: inline-block;
  width: 0;
  height: 0;
  margin-bottom: 2px;
  margin-left: 2px;
  vertical-align: middle;
  border-top: 4px dashed;
  border-top: 4px solid \9;
  border-right: 4px solid transparent;
  border-left: 4px solid transparent;
  }
.dropup,
.dropdown {
  position: relative;
  }
.dropdown-toggle:focus {
  outline: 0;
  }
.dropdown-menu {
  position: absolute;
  top: 100%;
  left: 0;
  z-index: 1000;
  display: none;
  float: left;
  min-width: 160px;
  padding: 5px 0;
  margin: 2px 0 0;
  font-size: 13px;
  list-style: none;
  background-color: #fff;
  -webkit-background-clip: padding-box;
          background-clip: padding-box;
  border: 1px solid #cbcbcb;
  border: 1px solid rgba(0, 0, 0, .15);
  border-radius: 4px;
  -webkit-box-shadow: 0 6px 12px rgba(0, 0, 0, .175);
          box-shadow: 0 6px 12px rgba(0, 0, 0, .175);
  }
.dropdown-menu.pull-right {
  right: 0;
  left: auto;
  }
.dropdown-menu .divider {
  height: 1px;
  margin: 9px 0;
  overflow: hidden;
  background-color: #e5e5e5;
  }
.dropdown-menu > li > a {
  display: block;
  padding: 3px 20px;
  clear: both;
  font-weight: normal;
  line-height: 1.53846154;
  color: #353535;
  white-space: nowrap;
  }
.dropdown-menu > li > a:hover,
.dropdown-menu > li > a:focus {
  color: #fff;
  text-decoration: none;
  background-color: #3280fc;
  }
.dropdown-menu > .active > a,
.dropdown-menu > .active > a:hover,
.dropdown-menu > .active > a:focus {
  color: #fff;
  text-decoration: none;
  background-color: #3280fc;
  outline: 0;
  }
.dropdown-menu > .disabled > a,
.dropdown-menu > .disabled > a:hover,
.dropdown-menu > .disabled > a:focus {
  color: #ddd;
  }
.dropdown-menu > .disabled > a:hover,
.dropdown-menu > .disabled > a:focus {
  text-decoration: none;
  cursor: not-allowed;
  background-color: transparent;
  background-image: none;
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  }
.open > .dropdown-menu {
  display: block;
  }
.open > a {
  outline: 0;
  }
.dropdown-header {
  display: block;
  padding: 3px 20px;
  font-size: 12px;
  font-weight: bold;
  line-height: 1.53846154;
  color: #808080;
  }
.dropdown-backdrop {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 990;
  }
.pull-right > .dropdown-menu {
  right: 0;
  left: auto;
  }
.dropup .caret,
.navbar-fixed-bottom .dropdown .caret {
  content: "";
  border-top: 0 dotted;
  border-bottom: 4px solid;
  }
.dropup .dropdown-menu,
.navbar-fixed-bottom .dropdown .dropdown-menu {
  top: auto;
  bottom: 100%;
  margin-bottom: 1px;
  }
@media (min-width: 768px) {
  .navbar-right .dropdown-menu {
    right: 0;
    left: auto;
    }
  }
.dropdown-submenu {
  position: relative;
  }
.dropdown-submenu > .dropdown-menu {
  top: 0;
  left: 100%;
  margin-top: -6px;
  margin-left: -1px;
  border-radius: 4px;
  }
.dropdown-submenu.open > .dropdown-menu,
.dropdown-submenu:hover > .dropdown-menu {
  display: block;
  }
.dropup .dropdown-submenu > .dropdown-menu {
  top: auto;
  bottom: 0;
  margin-top: 0;
  margin-bottom: -2px;
  border-radius: 4px;
  }
.dropdown-submenu > a:after {
  display: block;
  float: right;
  width: 0;
  height: 0;
  margin-top: 5px;
  margin-right: -10px;
  content: " ";
  border-color: transparent;
  border-style: solid;
  border-width: 5px 0 5px 5px;
  border-left-color: #ccc;
  }
.dropdown-submenu:hover > a:after {
  border-left-color: #fff;
  }
.dropdown-submenu > a {
  min-width: 160px;
  }
.dropdown-submenu > .dropdown-menu.pull-left {
  left: -100%;
  }
.dropdown-submenu:hover > a,
.dropdown-submenu:focus > a {
  color: #fff;
  text-decoration: none;
  background-color: #3280fc;
  }
.carousel {
  position: relative;
  }
.carousel-inner {
  position: relative;
  width: 100%;
  overflow: hidden;
  }
.carousel-inner > .item {
  position: relative;
  display: none;
  -webkit-transition: .6s ease-in-out left;
       -o-transition: .6s ease-in-out left;
          transition: .6s ease-in-out left;
  }
.carousel-inner > .item > img,
.carousel-inner > .item > a > img {
  line-height: 1;
  }
.carousel-inner > .active,
.carousel-inner > .next,
.carousel-inner > .prev {
  display: block;
  }
.carousel-inner > .active {
  left: 0;
  }
.carousel-inner > .next,
.carousel-inner > .prev {
  position: absolute;
  top: 0;
  width: 100%;
  }
.carousel-inner > .next {
  left: 100%;
  }
.carousel-inner > .prev {
  left: -100%;
  }
.carousel-inner > .next.left,
.carousel-inner > .prev.right {
  left: 0;
  }
.carousel-inner > .active.left {
  left: -100%;
  }
.carousel-inner > .active.right {
  left: 100%;
  }
.carousel-control {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  width: 10%;
  color: #fff;
  text-align: center;
  text-shadow: 0 1px 2px rgba(0, 0, 0, .6);
  filter: alpha(opacity=40);
  outline: none;
  opacity: .4;
  }
.carousel-control > .icon {
  font-size: 20px;
  }
.carousel-control.left {
  background-image: -webkit-gradient(linear, left top, right top, from(rgba(0, 0, 0, .3)), to(rgba(0, 0, 0, .0001)));
  background-image: -webkit-linear-gradient(left, rgba(0, 0, 0, .3) 0%, rgba(0, 0, 0, .0001) 100%);
  background-image:      -o-linear-gradient(left, rgba(0, 0, 0, .3) 0%, rgba(0, 0, 0, .0001) 100%);
  background-image:         linear-gradient(to right, rgba(0, 0, 0, .3) 0%, rgba(0, 0, 0, .0001) 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#4d000000', endColorstr='#00000000', GradientType=1);
  background-repeat: repeat-x;
  }
.carousel-control.right {
  right: 0;
  left: auto;
  background-image: -webkit-gradient(linear, left top, right top, from(rgba(0, 0, 0, .0001)), to(rgba(0, 0, 0, .3)));
  background-image: -webkit-linear-gradient(left, rgba(0, 0, 0, .0001) 0%, rgba(0, 0, 0, .3) 100%);
  background-image:      -o-linear-gradient(left, rgba(0, 0, 0, .0001) 0%, rgba(0, 0, 0, .3) 100%);
  background-image:         linear-gradient(to right, rgba(0, 0, 0, .0001) 0%, rgba(0, 0, 0, .3) 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00000000', endColorstr='#4d000000', GradientType=1);
  background-repeat: repeat-x;
  }
.carousel-control:hover,
.carousel-control:focus {
  color: #fff;
  text-decoration: none;
  filter: alpha(opacity=100);
  outline: none;
  opacity: 1;
  }
.carousel-control .icon-prev,
.carousel-control .icon-next,
.carousel-control .icon-chevron-left,
.carousel-control .icon-chevron-right {
  position: absolute;
  top: 50%;
  z-index: 5;
  display: inline-block;
  }
.carousel-control .icon-prev,
.carousel-control .icon-chevron-left {
  left: 50%;
  }
.carousel-control .icon-next,
.carousel-control .icon-chevron-right {
  right: 50%;
  }
.carousel-control .icon-prev,
.carousel-control .icon-next {
  width: 20px;
  height: 20px;
  margin-top: -10px;
  margin-left: -10px;
  font-family: serif;
  }
.carousel-control .icon-prev:before {
  content: '\2039';
  }
.carousel-control .icon-next:before {
  content: '\203a';
  }
.carousel-caption {
  position: absolute;
  right: 15%;
  bottom: 20px;
  left: 15%;
  z-index: 10;
  padding-top: 20px;
  padding-bottom: 20px;
  color: #fff;
  text-align: center;
  text-shadow: 0 1px 2px rgba(0, 0, 0, .6);
  }
.carousel-caption .btn {
  text-shadow: none;
  }
@media screen and (min-width: 768px) {
  .carousel-control .icon-prev,
  .carousel-control .icon-next {
    top: 40%;
    width: 30px;
    height: 30px;
    margin-top: -15px;
    margin-left: -15px;
    font-size: 80px;
    }
  .carousel-control .icon-prev {
    left: 30%;
    }
  .carousel-control .icon-next {
    right: 25%;
    }
  .carousel-caption {
    right: 20%;
    left: 20%;
    padding-bottom: 30px;
    }
  .carousel-indicators {
    bottom: 20px;
    }
  }
.carousel-indicators {
  position: absolute;
  bottom: 10px;
  left: 50%;
  z-index: 15;
  width: 60%;
  padding-left: 0;
  margin-left: -30%;
  text-align: center;
  list-style: none;
  }
.carousel-indicators li {
  display: inline-block;
  width: 10px;
  height: 10px;
  margin: 1px;
  text-indent: -999px;
  cursor: pointer;
  border: 1px solid #fff;
  border-radius: 10px;
  }
.carousel-indicators .active {
  width: 12px;
  height: 12px;
  margin: 0;
  background-color: #fff;
  }
[data-toggle="lightbox"] {
  cursor: pointer;
  }
.modal-lightbox .close {
  position: absolute;
  top: 0;
  right: 0;
  z-index: 10;
  display: block;
  width: 40px;
  height: 40px;
  font-size: 14px;
  color: #fff;
  text-align: center;
  background-color: #353535;
  background-color: rgba(53, 53, 53, .2);
  filter: alpha(opacity=80);
  opacity: .8;
  -webkit-transition: opacity .2s cubic-bezier(.175, .885, .32, 1), background-color .2s cubic-bezier(.175, .885, .32, 1);
       -o-transition: opacity .2s cubic-bezier(.175, .885, .32, 1), background-color .2s cubic-bezier(.175, .885, .32, 1);
          transition: opacity .2s cubic-bezier(.175, .885, .32, 1), background-color .2s cubic-bezier(.175, .885, .32, 1);
  }
.modal-lightbox .controller {
  position: absolute;
  top: 0;
  display: none;
  height: 100%;
  padding: 0;
  line-height: 100%;
  color: #fff;
  cursor: pointer;
  background-color: transparent;
  border: none;
  outline: none;
  -webkit-transition: background .2s cubic-bezier(.175, .885, .32, 1);
       -o-transition: background .2s cubic-bezier(.175, .885, .32, 1);
          transition: background .2s cubic-bezier(.175, .885, .32, 1);
  }
.modal-lightbox .controller.show {
  display: block;
  }
.modal-lightbox .controller > .icon {
  display: inline-block;
  width: 60px;
  height: 50px;
  line-height: 50px;
  text-shadow: 0 1px 2px rgba(0, 0, 0, .6);
  background-color: transparent;
  -webkit-transition: background .2s cubic-bezier(.175, .885, .32, 1);
       -o-transition: background .2s cubic-bezier(.175, .885, .32, 1);
          transition: background .2s cubic-bezier(.175, .885, .32, 1);
  }
.modal-lightbox .controller > .icon:before {
  font-size: 20px;
  }
.modal-lightbox .controller.prev {
  left: 0;
  }
.modal-lightbox .controller.next {
  right: 0;
  }
.modal-lightbox .modal-dialog {
  position: relative;
  max-width: 100%;
  max-height: 100%;
  margin-bottom: 0;
  background: none;
  border: none;
  -webkit-box-shadow: none;
          box-shadow: none;
  -webkit-transition: all .4s cubic-bezier(.175, .885, .32, 1);
       -o-transition: all .4s cubic-bezier(.175, .885, .32, 1);
          transition: all .4s cubic-bezier(.175, .885, .32, 1);
  }
.modal-lightbox .modal-dialog:hover .close,
.modal-lightbox .modal-dialog:focus .close {
  background-color: rgba(53, 53, 53, .5);
  filter: alpha(opacity=100);
  opacity: 1;
  }
.modal-lightbox .modal-dialog:hover .close:hover,
.modal-lightbox .modal-dialog:focus .close:hover {
  background-color: rgba(53, 53, 53, .9);
  }
.modal-lightbox .modal-dialog:hover .controller > .icon,
.modal-lightbox .modal-dialog:focus .controller > .icon {
  text-shadow: none;
  background-color: #353535;
  background-color: rgba(53, 53, 53, .5);
  }
.modal-lightbox .modal-dialog:hover .controller:hover > .icon,
.modal-lightbox .modal-dialog:focus .controller:hover > .icon {
  background-color: #353535;
  background-color: rgba(53, 53, 53, .9);
  }
.modal-lightbox .caption {
  display: none;
  }
.modal-lightbox.lightbox-with-caption .caption {
  position: absolute;
  bottom: 0;
  display: block;
  width: 100%;
  padding: 10px 15px;
  color: #fff;
  text-align: center;
  text-shadow: 1px 1px 0 rgba(0, 0, 0, .3);
  background: rgba(0, 0, 0, .15);
  opacity: .5;
  -webkit-transition: all .4s cubic-bezier(.175, .885, .32, 1);
       -o-transition: all .4s cubic-bezier(.175, .885, .32, 1);
          transition: all .4s cubic-bezier(.175, .885, .32, 1);
  }
.modal-lightbox.lightbox-with-caption .modal-dialog:hover .caption {
  background: rgba(0, 0, 0, .6);
  opacity: 1;
  }
.lightbox-img {
  display: block;
  width: inherit;
  max-width: 100%;
  height: auto;
  padding: 0;
  margin: 0 auto;
  cursor: pointer;
  -webkit-box-shadow: 0 5px 15px rgba(0, 0, 0, .5);
          box-shadow: 0 5px 15px rgba(0, 0, 0, .5);
  -webkit-transition: all .4s cubic-bezier(.175, .885, .32, 1);
       -o-transition: all .4s cubic-bezier(.175, .885, .32, 1);
          transition: all .4s cubic-bezier(.175, .885, .32, 1);
  }
.messager {
  display: table;
  margin: 10px;
  overflow: hidden;
  color: #fff;
  pointer-events: auto;
  background-color: #353535;
  background-color: rgba(0, 0, 0, .8);
  border-radius: 20px;
  }
.messager-content {
  display: table-cell;
  padding: 10px 15px;
  vertical-align: top;
  }
.messager-content > [class^='icon-'] {
  display: inline-block;
  margin-right: 8px;
  }
.messager-actions {
  display: table-cell;
  vertical-align: top;
  }
.messager-actions > .action {
  min-width: 40px;
  height: 40px;
  padding: 0 12px;
  color: #fafafa;
  color: rgba(255, 255, 255, .6);
  text-align: center;
  text-shadow: none;
  background: none;
  border: none;
  }
.messager-actions > .action.close {
  padding-bottom: 5px;
  font-size: 20px;
  font-weight: normal;
  opacity: 1;
  }
.messager-actions > .action:hover {
  color: #fff;
  background: rgba(0, 0, 0, .1);
  }
.messager-actions .action-icon + .action-text {
  margin-left: 8px;
  }
.messagers-holder {
  position: fixed;
  z-index: 99999;
  padding: 10px;
  pointer-events: none;
  -webkit-transition: top .2s cubic-bezier(.175, .885, .32, 1);
       -o-transition: top .2s cubic-bezier(.175, .885, .32, 1);
          transition: top .2s cubic-bezier(.175, .885, .32, 1);
  }
.messagers-holder.top {
  top: 0;
  }
.messagers-holder.top-left {
  top: 0;
  left: 0;
  }
.messagers-holder.top-right {
  top: 0;
  right: 0;
  }
.messagers-holder.bottom {
  bottom: 0;
  }
.messagers-holder.bottom-left {
  bottom: 0;
  left: 0;
  }
.messagers-holder.bottom-right {
  right: 0;
  bottom: 0;
  }
.messagers-holder.top-right .messager,
.messagers-holder.bottom-right .messager {
  margin-left: auto;
  }
.messagers-holder.center {
  top: 0;
  }
.messagers-holder.top,
.messagers-holder.bottom,
.messagers-holder.center {
  right: 0;
  left: 0;
  }
.messagers-holder.top .messager,
.messagers-holder.bottom .messager,
.messagers-holder.center .messager {
  margin: 10px auto;
  }
.messager-primary {
  background-color: #3280fc;
  }
.messager-success {
  background-color: #38b03f;
  }
.messager-info {
  background-color: #03b8cf;
  }
.messager-warning {
  background-color: #f1a325;
  }
.messager-danger {
  background-color: #ea644a;
  }
.messager-important {
  background-color: #bd7b46;
  }
.messager-special {
  background-color: #8666b8;
  }
.menu > .btn {
  display: block;
  width: 100%;
  padding-right: 0;
  padding-left: 0;
  margin-bottom: 5px;
  }
.menu > .btn + .nav {
  margin-top: 15px;
  }
.menu > .nav > li {
  float: none;
  }
.menu > .nav > li.nav-parent > a > .nav-parent-fold-icon {
  position: absolute;
  top: 11px;
  right: 10px;
  display: block;
  filter: alpha(opacity=45);
  opacity: .45;
  -webkit-transition: all .5s;
       -o-transition: all .5s;
          transition: all .5s;
  }
.menu > .nav > li.nav-parent > a:hover > .nav-parent-fold-icon {
  filter: alpha(opacity=75);
  opacity: .75;
  }
.menu > .nav > li > .nav {
  display: none;
  background-color: #f6f6f6;
  }
.menu > .nav > li > .nav > li > a {
  padding-left: 35px;
  margin-top: -1px;
  border: 1px solid #ddd;
  }
.menu > .nav > li > .nav > li > a:hover,
.menu > .nav > li > .nav > li > a:focus {
  background-color: #e4e4e4;
  }
.menu > .nav > li > .nav > li.active > a,
.menu > .nav > li > .nav > li.active > a:hover,
.menu > .nav > li > .nav > li.active > a:focus {
  color: #fff;
  background-color: #3280fc;
  border-color: #3280fc;
  }
.menu > .nav > li > .nav > li.active > a [class*='icon-'],
.menu > .nav > li > .nav > li.active > a:hover [class*='icon-'],
.menu > .nav > li > .nav > li.active > a:focus [class*='icon-'] {
  color: #fff;
  }
.menu > .nav > li > a > [class*='icon-'],
.menu > .nav > li > .nav > li > a > [class*='icon-'] {
  display: inline-block;
  margin-right: 5px;
  color: #808080;
  }
.menu > .nav > li + li {
  margin-top: -1px;
  margin-left: 0;
  }
.menu > .nav > li,
.menu > .nav > li > a {
  margin-left: 0;
  }
.menu > .nav > li:first-child {
  margin-top: 0;
  }
.menu > .nav > li:first-child > a,
.menu > .nav > li:first-child.nav-heading {
  margin-left: 0;
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
  }
.menu > .nav > li:last-child > a {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  border-bottom-right-radius: 4px;
  border-bottom-left-radius: 4px;
  }
.menu > .nav > li:first-child > a,
.menu > .nav > li:first-child.nav-heading {
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
  }
.menu > .nav > li.active > a [class*='icon-'],
.menu > .nav > li.active > a:hover [class*='icon-'],
.menu > .nav > li.active > a:focus [class*='icon-'] {
  color: #fff;
  }
.menu > .nav > li.show > a,
.menu > .nav > li.show > a:hover,
.menu > .nav > li.show > a:focus {
  color: #353535;
  background-color: #fff;
  border-color: #ddd;
  }
.menu > .nav > li.show > a > [class*='icon-'],
.menu > .nav > li.show > a:hover > [class*='icon-'],
.menu > .nav > li.show > a:focus > [class*='icon-'] {
  color: #353535;
  }
.menu > .nav > li.show > a:hover {
  background-color: #f1f1f1;
  }
.menu > .nav > li.show:last-child > a {
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
  }
.menu > .nav > li.show:last-child > .nav > li:last-child > a {
  border-bottom-right-radius: 4px;
  border-bottom-left-radius: 4px;
  }
.menu > .nav > li.show > .nav {
  display: block;
  }
.menu > .nav > li.nav-heading {
  background-color: #f1f1f1;
  border: 1px solid #ddd;
  }
.article {
  padding: 20px;
  }
.article > header h1,
.article > header h2,
.article > header h3 {
  margin-bottom: 20px;
  line-height: 1.5;
  }
.article > header > .abstract,
.article > header > dl {
  padding: 10px 15px;
  font-size: 12px;
  color: #686868;
  background-color: #f1f1f1;
  }
.article > header > .abstract > p:last-child,
.article > header > dl > p:last-child {
  margin-bottom: 0;
  }
.article > header > dl {
  margin: 0;
  border-bottom: 1px solid #e9e9e9;
  }
.article > header > dl.pull-right {
  background-color: transparent;
  border: none;
  }
.article > footer {
  border-top: 1px dashed #d7d7d7;
  }
.article > footer > p {
  padding: 10px 15px;
  }
.article > .content,
.article-content {
  padding: 20px 0;
  font-size: 14px;
  line-height: 1.78571429;
  }
.article > .content h1,
.article-content h1 {
  font-size: 20px;
  }
.article > .content h2,
.article-content h2 {
  font-size: 18px;
  }
.article > .content h3,
.article-content h3 {
  font-size: 16px;
  }
.article > .content h4,
.article-content h4 {
  margin-top: 15px;
  font-size: 14px;
  }
.article > .content h5,
.article-content h5 {
  margin-top: 15px;
  font-size: 13px;
  }
.article > .content h6,
.article-content h6 {
  margin-top: 15px;
  font-size: 11px;
  }
.article > .content img,
.article-content img {
  margin: 10px 0;
  }
.article > .content p > img,
.article-content p > img {
  margin-right: 10px;
  }
.article > .content p > img[align='right'],
.article-content p > img[align='right'] {
  margin-left: 10px;
  }
.article > .content dl,
.article-content dl {
  padding-right: 2em;
  padding-left: 2em;
  }
.article > .content table,
.article-content table {
  margin-bottom: 20px;
  }
.article > .content table th,
.article-content table th,
.article > .content table td,
.article-content table td {
  padding: 8px;
  line-height: 1.53846154;
  vertical-align: top;
  border-bottom: 1px solid #ddd;
  }
.article > .content table > thead > tr > th,
.article-content table > thead > tr > th {
  vertical-align: bottom;
  background-color: #f1f1f1;
  border-bottom: 1px solid #ddd;
  }
.article-content p {
  margin-bottom: 0;
  }
.article-content table {
  width: 100%;
  }
.article > .content table th,
.article > .content table td,
.article > .content table > thead > tr > th {
  border: 1px solid #ddd;
  }
body.article-content {
  padding: 8px;
  }
.article-condensed {
  padding: 20px 0;
  }
.article-condensed > header {
  padding: 0 20px;
  }
.article-condensed > header > .abstract,
.article-condensed > header > dl {
  padding: 10px 15px;
  margin: 0 -20px;
  }
.article-condensed > .content,
.article-condensed > .article-content {
  padding: 20px;
  }
.article-condensed > .content > img,
.article-condensed > .article-content > img,
.article-condensed > .content > pre,
.article-condensed > .article-content > pre {
  margin-right: -20px;
  margin-left: -20px;
  border-radius: 0;
  }
.article-condensed > .content > pre,
.article-condensed > .article-content > pre {
  border-right: none;
  border-left: none;
  }
.article-condensed > footer {
  border-top: 1px dashed #d7d7d7;
  }
.article-condensed > footer > p {
  padding: 10px 15px;
  }
.article-condensed > footer > .pager-justify > .previous > a {
  border-left: none;
  border-radius: 0;
  }
.article-condensed > footer > .pager-justify > .next > a {
  border-right: none;
  border-radius: 0;
  }
.comments > header {
  border-bottom: 1px solid #e5e5e5;
  }
.comments > header > .alert {
  padding: 7.5px 15px;
  margin-bottom: -10px;
  }
.comments > header h1,
.comments > header h2,
.comments > header h3 {
  padding: 10px 0;
  margin: 10px 0;
  }
.comments > footer {
  padding-top: 10px;
  }
.comments > footer > .reply-form > .avatar {
  display: block;
  float: left;
  width: 40px;
  height: 40px;
  margin-top: 10px;
  }
.comments > footer > .reply-form > .avatar + .form {
  padding-left: 50px;
  }
.comment {
  padding: 10px 0;
  border-bottom: 1px solid #e5e5e5;
  }
.comment:before,
.comment:after {
  /* 1 */
  display: table;
  content: " ";
  /* 2 */
  }
.comment:after {
  clear: both;
  }
.comment:before,
.comment:after {
  /* 1 */
  display: table;
  content: " ";
  /* 2 */
  }
.comment:after {
  clear: both;
  }
.comment > .avatar,
.comment > .content {
  display: block;
  }
.comment > .avatar {
  float: left;
  width: 40px;
  height: 40px;
  margin-top: 10px;
  }
.comment > .avatar + .content {
  padding-left: 50px;
  }
.comment > .content > .text {
  margin-top: 5px;
  }
.comment > .content > .actions {
  margin-top: 4px;
  }
.comment > .content > .actions > a {
  display: inline-block;
  color: #808080;
  }
.comment > .content > .actions > a + a {
  margin-left: 5px;
  }
.comment:hover > .content > .actions > a {
  color: #145ccd;
  }
.comment > .comments-list {
  padding-top: 10px;
  padding-bottom: 0;
  padding-left: 30px;
  margin-left: 20px;
  border-left: 1px dashed #e5e5e5;
  }
.comment > .comments-list > .comment {
  border: none;
  border-top: 1px solid #e5e5e5;
  }
.comment > .comments-list > .comment:last-child {
  padding-bottom: 0;
  }
.list {
  padding: 0 15px;
  }
.list > header {
  padding-bottom: 10px;
  border-bottom: 1px solid #e5e5e5;
  }
.items .item {
  padding: 10px 0;
  border-bottom: 1px solid #e5e5e5;
  -webkit-transition: all .4s cubic-bezier(.175, .885, .32, 1);
       -o-transition: all .4s cubic-bezier(.175, .885, .32, 1);
          transition: all .4s cubic-bezier(.175, .885, .32, 1);
  }
.items .item-heading > h6,
.items .item-heading h5,
.items .item-heading h4,
.items .item-heading h3,
.items .item-heading h2,
.items .item-heading h1 {
  margin-top: 5px;
  }
.items .item-content:before,
.items .item-content:after {
  /* 1 */
  display: table;
  content: " ";
  /* 2 */
  }
.items .item-content:after {
  clear: both;
  }
.items .item-content:before,
.items .item-content:after {
  /* 1 */
  display: table;
  content: " ";
  /* 2 */
  }
.items .item-content:after {
  clear: both;
  }
.items .item-content > .media {
  max-width: 100%;
  margin: 5px 0;
  }
.items .item-content > .media.pull-left {
  max-width: 150px;
  margin: 0;
  margin-right: 8px;
  }
.items .item-content > .media.pull-right {
  max-width: 150px;
  margin: 0;
  margin-left: 8px;
  }
.items .item-footer {
  padding-top: 5px;
  }
.items .item-footer > a {
  color: #808080;
  }
.items-hover .item:hover {
  background-color: #f5f5f5;
  }
.list-condensed {
  padding: 0;
  }
.list-condensed > header,
.list-condensed > footer,
.list-condensed > .items > .item {
  padding-right: 15px;
  padding-left: 15px;
  }
.cards {
  padding-top: 10px;
  padding-bottom: 10px;
  margin-right: -10px;
  margin-left: -10px;
  }
.card {
  position: relative;
  display: block;
  padding: 0;
  margin-bottom: 20px;
  overflow: hidden;
  border: 1px solid #ddd;
  border-radius: 4px;
  -webkit-box-shadow: 0 1px 2px rgba(0, 0, 0, .075);
          box-shadow: 0 1px 2px rgba(0, 0, 0, .075);
  -webkit-transition: all .4s cubic-bezier(.175, .885, .32, 1);
       -o-transition: all .4s cubic-bezier(.175, .885, .32, 1);
          transition: all .4s cubic-bezier(.175, .885, .32, 1);
  }
.card > img {
  display: block;
  max-width: 100%;
  height: auto;
  filter: alpha(opacity=100);
  opacity: 1;
  }
.card > .media-wrapper {
  display: block;
  width: 100%;
  overflow: hidden;
  text-align: center;
  background-color: #f1f1f1;
  filter: alpha(opacity=100);
  opacity: 1;
  -webkit-transition: all .4s cubic-bezier(.175, .885, .32, 1);
       -o-transition: all .4s cubic-bezier(.175, .885, .32, 1);
          transition: all .4s cubic-bezier(.175, .885, .32, 1);
  }
.card > .media-wrapper > img {
  max-width: 100%;
  vertical-align: middle;
  }
.card .card-heading {
  display: block;
  padding: 10px;
  margin: 0;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  }
.card .card-content,
.card .card-actions {
  padding: 0 10px 10px 10px;
  overflow: hidden;
  text-overflow: ellipsis;
  }
.card .card-actions .btn + .pull-right {
  padding: 6px 0;
  line-height: 20px;
  }
.card:hover {
  text-decoration: none;
  -webkit-box-shadow: 0 1px 5px rgba(0, 0, 0, .175);
          box-shadow: 0 1px 5px rgba(0, 0, 0, .175);
  }
.card:hover > img,
.card:hover > .media-wrapper {
  background-color: #e5e5e5;
  filter: alpha(opacity=90);
  opacity: .9;
  }
.card:hover > .card-reveal {
  top: 0;
  }
.cards-borderless .card {
  border: none;
  border-radius: 0;
  -webkit-box-shadow: none;
          box-shadow: none;
  }
.cards-borderless .card > img,
.cards-borderless .card > .media-wrapper {
  overflow: hidden;
  border-radius: 4px;
  }
.cards-borderless .card > .card-heading,
.cards-borderless .card > .card-actions,
.cards-borderless .card > .card-content {
  padding-right: 0;
  padding-left: 0;
  }
.card > .caption {
  position: absolute;
  top: -100%;
  left: 0;
  display: block;
  width: 100%;
  padding: 5px 10px;
  overflow: hidden;
  color: #fff;
  text-align: center;
  background-color: #666;
  background-color: rgba(0, 0, 0, .7);
  filter: alpha(opacity=0);
  opacity: 0;
  -webkit-transition: all .8s cubic-bezier(.175, .885, .32, 1);
       -o-transition: all .8s cubic-bezier(.175, .885, .32, 1);
          transition: all .8s cubic-bezier(.175, .885, .32, 1);
  }
.card:hover > .caption {
  top: 0;
  filter: alpha(opacity=100);
  opacity: 1;
  }
.cards-condensed {
  padding: 0;
  border: 1px solid #ddd;
  border-top: 0;
  border-left: 0;
  }
.cards-condensed > [class^="col-"],
.cards-condensed > [class*=" col-"] {
  padding: 0;
  }
.cards-condensed .card {
  padding: 10px;
  margin: 0;
  border-right: 0;
  border-bottom: 0;
  border-radius: 0;
  -webkit-box-shadow: 0 1px 2px rgba(0, 0, 0, .015);
          box-shadow: 0 1px 2px rgba(0, 0, 0, .015);
  }
.card > .card-reveal {
  position: absolute;
  top: 100%;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: #f1f1f1;
  -webkit-transition: all .8s cubic-bezier(.175, .885, .32, 1);
       -o-transition: all .8s cubic-bezier(.175, .885, .32, 1);
          transition: all .8s cubic-bezier(.175, .885, .32, 1);
  }
.card > .card-reveal > .card-heading {
  padding: 20px 10px;
  }
.card:hover > .card-reveal {
  top: 0;
  }
.tree {
  padding-left: 0;
  }
.tree ul {
  position: relative;
  display: none;
  padding-left: 0;
  }
.tree li {
  position: relative;
  padding: 2px 0 2px 20px;
  list-style: none;
  }
.tree li:before {
  position: absolute;
  top: 10px;
  left: 8px;
  display: block;
  width: 3px;
  height: 3px;
  content: ' ';
  background-color: #999;
  }
.tree li.has-list:before {
  display: none;
  }
.tree li > .list-toggle {
  position: absolute;
  top: -1px;
  left: 0;
  z-index: 10;
  width: 20px;
  line-height: 24px;
  color: #808080;
  text-align: center;
  cursor: pointer;
  }
.tree li > .list-toggle:before {
  content: '\e6f1';
  }
.tree li > .list-toggle:hover,
.tree li > .list-toggle:active {
  color: #0d3d88;
  }
.tree li.open > ul {
  display: block;
  }
.tree li.open > .list-toggle:before {
  content: '\e6f2';
  }
.tree-actions {
  display: inline-block;
  margin-left: 5px;
  opacity: 0;
  -webkit-transition: opacity .1s;
       -o-transition: opacity .1s;
          transition: opacity .1s;
  }
.tree-action {
  display: inline-block;
  margin-left: 5px;
  color: #808080;
  }
.tree-action:hover,
.tree-action:active {
  text-decoration: none;
  }
.tree li:hover > .tree-actions,
.tree-item-wrapper:hover > .tree-actions {
  opacity: 1;
  }
.tree-drag-holder {
  background-color: #ebf2f9;
  opacity: .4;
  }
.tree .sort-handler {
  cursor: move;
  }
.tree-animate ul {
  opacity: 0;
  -webkit-transition: opacity .2s cubic-bezier(.175, .885, .32, 1), -webkit-transform .2s cubic-bezier(.175, .885, .32, 1);
       -o-transition: opacity .2s cubic-bezier(.175, .885, .32, 1), -o-transform .2s cubic-bezier(.175, .885, .32, 1);
          transition: opacity .2s cubic-bezier(.175, .885, .32, 1), -webkit-transform .2s cubic-bezier(.175, .885, .32, 1);
          transition: opacity .2s cubic-bezier(.175, .885, .32, 1), transform .2s cubic-bezier(.175, .885, .32, 1);
          transition: opacity .2s cubic-bezier(.175, .885, .32, 1), transform .2s cubic-bezier(.175, .885, .32, 1), -webkit-transform .2s cubic-bezier(.175, .885, .32, 1), -o-transform .2s cubic-bezier(.175, .885, .32, 1);
  -webkit-transform: scale(1, .5);
      -ms-transform: scale(1, .5);
       -o-transform: scale(1, .5);
          transform: scale(1, .5);
  }
.tree-animate li.open.in > ul {
  opacity: 1;
  -webkit-transform: scale(1, 1);
      -ms-transform: scale(1, 1);
       -o-transform: scale(1, 1);
          transform: scale(1, 1);
  }
.tree-animate.tree-lines li.has-list.open > ul:after {
  top: -5px;
  bottom: 12px;
  left: -11px;
  }
.tree-lines ul > li:after {
  position: absolute;
  top: 11px;
  left: -10px;
  z-index: 1;
  display: block;
  width: 18px;
  content: ' ';
  border-top: 1px dotted #999;
  }
.tree-lines ul > li:before,
.tree-lines ul > li.has-list:before {
  position: absolute;
  top: -12px;
  bottom: 13px;
  left: -11px;
  display: block;
  width: auto;
  height: auto;
  content: ' ';
  background: none;
  border: none;
  border-left: 1px dotted #999;
  }
.tree-lines ul > li:last-child:before {
  bottom: auto;
  height: 23px;
  }
.tree-lines ul > li:first-child:before {
  top: -7px;
  }
.tree-lines ul > li.has-list:after {
  width: 14px;
  }
.tree-lines ul > li.drag-shadow:after {
  display: none;
  }
.tree-folders li > .list-toggle:before {
  content: '\e6ef';
  }
.tree-folders li.open > .list-toggle:before {
  content: '\e6f0';
  }
.tree-folders.tree-lines ul > li:first-child:before {
  top: -6px;
  }
.tree-folders.tree-lines li.has-list.open > ul:after {
  top: 16px;
  }
.tree-folders ul > li.has-list:after {
  width: 13px;
  }
.tree-folders ul > li.has-list.open:after {
  width: 15px;
  }
.tree-chevrons li > .list-toggle:before {
  content: '\e710';
  }
.tree-chevrons li.open > .list-toggle:before {
  content: '\e712';
  }
.tree-chevrons li:before {
  top: 6px;
  left: 4px;
  width: 10px;
  height: 10px;
  background-color: #ddd;
  border-radius: 5px;
  }
.tree-chevrons ul > li:after {
  width: 13px;
  }
.tree-angles li > .list-toggle:before {
  content: '\e6e1';
  }
.tree-angles li.open > .list-toggle:before {
  content: '\e6e3';
  }
.tree-angles ul > li.has-list:after {
  width: 15px;
  }
